@@ -14,6 +14,7 @@ from ixnetwork_restpy.testplatform.testplatform import TestPlatform
 from ixnetwork_restpy.assistants.statistics.statviewassistant import StatViewAssistant
 from ixnetwork_restpy.assistants.ports.portmapassistant import PortMapAssistant
 from ixnetwork_restpy.assistants.watch.watchassistant import WatchAssistant
+from ixnetwork_restpy.assistants.config.configassistant import ConfigAssistant
 
 
 class SessionAssistant(object):
@@ -124,4 +125,8 @@ class SessionAssistant(object):
             prints received messages to the console
         """
         return WatchAssistant(self._ixnetwork, Callback)
-        
\ No newline at end of file
+
+    def ConfigAssistant(self):
+        """Get an instance of the ConfigAssistant class
+        """
+        return ConfigAssistant(self._ixnetwork)
