@@ -1,14 +1,13 @@
 """ Demonstrates standalone IxNetwork Windows GUI session management
 """
-
-from ixnetwork_restpy.testplatform.testplatform import TestPlatform
+from ixnetwork_restpy import SessionAssistant
 
 
-# setup the connection information to a standalone windows gui test platform
-# the session will always be defaulted to session id 1
-# the session state is always active
-test_platform=TestPlatform('127.0.0.1', rest_port=11009, platform='windows')
-test_platform.Trace = 'request_response'
+session_assistant = SessionAssistant(IpAddress='127.0.0.1', 
+    UserName='admin', Password='admin',
+    LogLevel=SessionAssistant.LOGLEVEL_INFO, 
+    ClearConfig=True)
+test_platform = session_assistant.TestPlatform
 
 # get a list of sessions
 for session in test_platform.Sessions.find():
