@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class IxVmCard(Base):
@@ -59,10 +61,10 @@ class IxVmCard(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.availablehardware.virtualchassis.ixvmcard.ixvmport.ixvmport import IxVmPort
-        if self._properties.get('IxVmPort', None) is not None:
-            return self._properties.get('IxVmPort')
-        else:
-            return IxVmPort(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('IxVmPort', None) is not None:
+                return self._properties.get('IxVmPort')
+        return IxVmPort(self)
 
     @property
     def CardId(self):
