@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Error(Base):
@@ -62,10 +64,10 @@ class Error(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.apperrors.error.instance.instance import Instance
-        if self._properties.get('Instance', None) is not None:
-            return self._properties.get('Instance')
-        else:
-            return Instance(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Instance', None) is not None:
+                return self._properties.get('Instance')
+        return Instance(self)
 
     @property
     def Description(self):
