@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class AncpDslProfile(Base):
@@ -55,10 +57,10 @@ class AncpDslProfile(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.protocolstack.ancpglobals.ancpdslprofile.ancpdsltlv.ancpdsltlv import AncpDslTlv
-        if self._properties.get('AncpDslTlv', None) is not None:
-            return self._properties.get('AncpDslTlv')
-        else:
-            return AncpDslTlv(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('AncpDslTlv', None) is not None:
+                return self._properties.get('AncpDslTlv')
+        return AncpDslTlv(self)
 
     @property
     def Name(self):
