@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Dhcpv6PdClientGlobals(Base):
@@ -81,10 +83,10 @@ class Dhcpv6PdClientGlobals(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.protocolstack.dhcpv6pdclientglobals.dhcpv6pdoptionset.dhcpv6pdoptionset import Dhcpv6PdOptionSet
-        if self._properties.get('Dhcpv6PdOptionSet', None) is not None:
-            return self._properties.get('Dhcpv6PdOptionSet')
-        else:
-            return Dhcpv6PdOptionSet(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Dhcpv6PdOptionSet', None) is not None:
+                return self._properties.get('Dhcpv6PdOptionSet')
+        return Dhcpv6PdOptionSet(self)
 
     @property
     def AcceptPartialConfig(self):
