@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class NacSettings(Base):
@@ -52,10 +54,10 @@ class NacSettings(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.protocolstack.eapoudpglobals.nacsettings.nacposture.nacposture import NacPosture
-        if self._properties.get('NacPosture', None) is not None:
-            return self._properties.get('NacPosture')
-        else:
-            return NacPosture(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('NacPosture', None) is not None:
+                return self._properties.get('NacPosture')
+        return NacPosture(self)
 
     @property
     def NacSequence(self):
@@ -69,10 +71,10 @@ class NacSettings(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.protocolstack.eapoudpglobals.nacsettings.nacsequence.nacsequence import NacSequence
-        if self._properties.get('NacSequence', None) is not None:
-            return self._properties.get('NacSequence')
-        else:
-            return NacSequence(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('NacSequence', None) is not None:
+                return self._properties.get('NacSequence')
+        return NacSequence(self)
 
     @property
     def NacTlv(self):
@@ -86,10 +88,10 @@ class NacSettings(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.protocolstack.eapoudpglobals.nacsettings.nactlv.nactlv import NacTlv
-        if self._properties.get('NacTlv', None) is not None:
-            return self._properties.get('NacTlv')
-        else:
-            return NacTlv(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('NacTlv', None) is not None:
+                return self._properties.get('NacTlv')
+        return NacTlv(self)
 
     @property
     def NacVendors(self):
@@ -103,10 +105,10 @@ class NacSettings(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.protocolstack.eapoudpglobals.nacsettings.nacvendors.nacvendors import NacVendors
-        if self._properties.get('NacVendors', None) is not None:
-            return self._properties.get('NacVendors')
-        else:
-            return NacVendors(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('NacVendors', None) is not None:
+                return self._properties.get('NacVendors')
+        return NacVendors(self)
 
     @property
     def ObjectId(self):
@@ -117,3 +119,43 @@ class NacSettings(Base):
         - str: Unique identifier for this object
         """
         return self._get_attribute(self._SDM_ATT_MAP['ObjectId'])
+
+    def find(self, ObjectId=None):
+        # type: (str) -> NacSettings
+        """Finds and retrieves nacSettings resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve nacSettings resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all nacSettings resources from the server.
+
+        Args
+        ----
+        - ObjectId (str): Unique identifier for this object
+
+        Returns
+        -------
+        - self: This instance with matching nacSettings resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of nacSettings data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the nacSettings resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
