@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class VendorRef(Base):
@@ -54,10 +56,10 @@ class VendorRef(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.protocolstack.eapoudpglobals.nacsettings.nactlv.vendorref.nactypes.nactypes import NacTypes
-        if self._properties.get('NacTypes', None) is not None:
-            return self._properties.get('NacTypes')
-        else:
-            return NacTypes(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('NacTypes', None) is not None:
+                return self._properties.get('NacTypes')
+        return NacTypes(self)
 
     @property
     def Name(self):
@@ -111,3 +113,45 @@ class VendorRef(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def find(self, Name=None, ObjectId=None, Value=None):
+        # type: (str, str, int) -> VendorRef
+        """Finds and retrieves vendorRef resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve vendorRef resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all vendorRef resources from the server.
+
+        Args
+        ----
+        - Name (str): Vendor Name.
+        - ObjectId (str): Unique identifier for this object
+        - Value (number): Vendor ID.
+
+        Returns
+        -------
+        - self: This instance with matching vendorRef resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of vendorRef data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the vendorRef resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
