@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class EgtpS5S8SgwGlobals(Base):
@@ -67,10 +69,10 @@ class EgtpS5S8SgwGlobals(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.protocolstack.egtps5s8sgwglobals.globalegtpapns5s8.globalegtpapns5s8 import GlobalEgtpApnS5S8
-        if self._properties.get('GlobalEgtpApnS5S8', None) is not None:
-            return self._properties.get('GlobalEgtpApnS5S8')
-        else:
-            return GlobalEgtpApnS5S8(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('GlobalEgtpApnS5S8', None) is not None:
+                return self._properties.get('GlobalEgtpApnS5S8')
+        return GlobalEgtpApnS5S8(self)
 
     @property
     def GlobalTrafficProfileS5S8(self):
@@ -84,10 +86,10 @@ class EgtpS5S8SgwGlobals(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.protocolstack.egtps5s8sgwglobals.globaltrafficprofiles5s8.globaltrafficprofiles5s8 import GlobalTrafficProfileS5S8
-        if self._properties.get('GlobalTrafficProfileS5S8', None) is not None:
-            return self._properties.get('GlobalTrafficProfileS5S8')
-        else:
-            return GlobalTrafficProfileS5S8(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('GlobalTrafficProfileS5S8', None) is not None:
+                return self._properties.get('GlobalTrafficProfileS5S8')
+        return GlobalTrafficProfileS5S8(self)
 
     @property
     def EnableDynamicQosCtrl(self):
