@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class MatchTemplate(Base):
@@ -57,10 +59,10 @@ class MatchTemplate(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.topology.openflowchannel.matchcriteria_9aa9789751ef3a19fec75c76015a02c0 import MatchCriteria
-        if self._properties.get('MatchCriteria', None) is not None:
-            return self._properties.get('MatchCriteria')
-        else:
-            return MatchCriteria(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('MatchCriteria', None) is not None:
+                return self._properties.get('MatchCriteria')
+        return MatchCriteria(self)
 
     @property
     def Count(self):
