@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class OpenFlowChannel(Base):
@@ -55,10 +57,10 @@ class OpenFlowChannel(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.topology.openflowchannel.flowaggrmatchtemplate_92a54a687c7573d5dcbe6197e7acd7a5 import FlowAggrMatchTemplate
-        if self._properties.get('FlowAggrMatchTemplate', None) is not None:
-            return self._properties.get('FlowAggrMatchTemplate')
-        else:
-            return FlowAggrMatchTemplate(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('FlowAggrMatchTemplate', None) is not None:
+                return self._properties.get('FlowAggrMatchTemplate')
+        return FlowAggrMatchTemplate(self)._select()
 
     @property
     def FlowStatMatchTemplate(self):
@@ -72,10 +74,10 @@ class OpenFlowChannel(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.topology.openflowchannel.flowstatmatchtemplate_9d0efda6a234c80e8ec5d25dbc49e75b import FlowStatMatchTemplate
-        if self._properties.get('FlowStatMatchTemplate', None) is not None:
-            return self._properties.get('FlowStatMatchTemplate')
-        else:
-            return FlowStatMatchTemplate(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('FlowStatMatchTemplate', None) is not None:
+                return self._properties.get('FlowStatMatchTemplate')
+        return FlowStatMatchTemplate(self)._select()
 
     @property
     def PacketOutActionTemplate(self):
@@ -89,10 +91,10 @@ class OpenFlowChannel(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.topology.openflowchannel.packetoutactiontemplate_655055ae6e6b8535ff5754b84cd6d7dd import PacketOutActionTemplate
-        if self._properties.get('PacketOutActionTemplate', None) is not None:
-            return self._properties.get('PacketOutActionTemplate')
-        else:
-            return PacketOutActionTemplate(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('PacketOutActionTemplate', None) is not None:
+                return self._properties.get('PacketOutActionTemplate')
+        return PacketOutActionTemplate(self)._select()
 
     @property
     def Count(self):
@@ -151,3 +153,46 @@ class OpenFlowChannel(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def find(self, Count=None, DescriptiveName=None, Name=None, RowNames=None):
+        # type: (int, str, str, List[str]) -> OpenFlowChannel
+        """Finds and retrieves openFlowChannel resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve openFlowChannel resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all openFlowChannel resources from the server.
+
+        Args
+        ----
+        - Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group.
+        - DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but may offer more context.
+        - Name (str): Name of NGPF element, guaranteed to be unique in Scenario
+        - RowNames (list(str)): Name of rows
+
+        Returns
+        -------
+        - self: This instance with matching openFlowChannel resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of openFlowChannel data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the openFlowChannel resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
