@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Vxlan(Base):
@@ -59,10 +61,10 @@ class Vxlan(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.topology.ipv6autoconfiguration.startrate.startrate_1bba90e9b5242a924a45ce8454358006 import StartRate
-        if self._properties.get('StartRate', None) is not None:
-            return self._properties.get('StartRate')
-        else:
-            return StartRate(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('StartRate', None) is not None:
+                return self._properties.get('StartRate')
+        return StartRate(self)._select()
 
     @property
     def StopRate(self):
@@ -76,10 +78,10 @@ class Vxlan(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.topology.ipv6autoconfiguration.stoprate.stoprate_e57c921a314c7c4a39ab432f5e2970a0 import StopRate
-        if self._properties.get('StopRate', None) is not None:
-            return self._properties.get('StopRate')
-        else:
-            return StopRate(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('StopRate', None) is not None:
+                return self._properties.get('StopRate')
+        return StopRate(self)._select()
 
     @property
     def Count(self):
@@ -186,6 +188,49 @@ class Vxlan(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, Count=None, DescriptiveName=None, Name=None, RowNames=None):
+        # type: (int, str, str, List[str]) -> Vxlan
+        """Finds and retrieves vxlan resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve vxlan resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all vxlan resources from the server.
+
+        Args
+        ----
+        - Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group.
+        - DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but may offer more context.
+        - Name (str): Name of NGPF element, guaranteed to be unique in Scenario
+        - RowNames (list(str)): Name of rows
+
+        Returns
+        -------
+        - self: This instance with matching vxlan resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of vxlan data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the vxlan resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def get_device_ids(self, PortNames=None, IgmpMode=None, InnerFrameMinimumSize=None, OuterIpDestMode=None, Udp_dest=None):
         """Base class infrastructure that gets a list of vxlan device ids encapsulated by this object.
 
