@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class RxRateLimit(Base):
@@ -149,3 +151,48 @@ class RxRateLimit(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def find(self, BufferSizeEnabled=None, BufferSizeUnits=None, BufferSizeValue=None, Enabled=None, Units=None, Value=None):
+        # type: (bool, str, int, bool, str, int) -> RxRateLimit
+        """Finds and retrieves rxRateLimit resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve rxRateLimit resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all rxRateLimit resources from the server.
+
+        Args
+        ----
+        - BufferSizeEnabled (bool): Allows user to specify a custom buffer size. Default false
+        - BufferSizeUnits (str(kilobytes | kKilobytes | kMegabytes | megabytes)): Units (Kilobytes, Megabytes). Default: Kilobytes
+        - BufferSizeValue (number): Burst tolerance buffer size. Default value is 32 KB
+        - Enabled (bool): Enable or disable the receive rate limit impairment.
+        - Units (str(kilobitsPerSecond | kKilobitsPerSecond | kMegabitsPerSecond | megabitsPerSecond)): Specify the units for the receive rate limit value.
+        - Value (number): Specify the value of the receive rate limit.
+
+        Returns
+        -------
+        - self: This instance with matching rxRateLimit resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of rxRateLimit data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the rxRateLimit resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
