@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class CustomDelayVariation(Base):
@@ -53,10 +55,10 @@ class CustomDelayVariation(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.impairment.profile.customdelayvariation.customvalue.customvalue import CustomValue
-        if self._properties.get('CustomValue', None) is not None:
-            return self._properties.get('CustomValue')
-        else:
-            return CustomValue(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('CustomValue', None) is not None:
+                return self._properties.get('CustomValue')
+        return CustomValue(self)
 
     @property
     def Enabled(self):
@@ -100,3 +102,44 @@ class CustomDelayVariation(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def find(self, Enabled=None, Name=None):
+        # type: (bool, str) -> CustomDelayVariation
+        """Finds and retrieves customDelayVariation resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve customDelayVariation resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all customDelayVariation resources from the server.
+
+        Args
+        ----
+        - Enabled (bool): If true, vary the packet delay.
+        - Name (str): Descriptive name of custom value list.
+
+        Returns
+        -------
+        - self: This instance with matching customDelayVariation resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of customDelayVariation data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the customDelayVariation resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
