@@ -19,8 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Vlan(Base):
@@ -39,12 +42,15 @@ class Vlan(Base):
         'Tpid': 'tpid',
         'VlanId': 'vlanId',
     }
+    _SDM_ENUM_MAP = {
+    }
 
-    def __init__(self, parent):
-        super(Vlan, self).__init__(parent)
+    def __init__(self, parent, list_op=False):
+        super(Vlan, self).__init__(parent, list_op)
 
     @property
     def Count(self):
+        # type: () -> int
         """
         Returns
         -------
@@ -54,6 +60,7 @@ class Vlan(Base):
 
     @property
     def DescriptiveName(self):
+        # type: () -> str
         """
         Returns
         -------
@@ -63,6 +70,7 @@ class Vlan(Base):
 
     @property
     def Name(self):
+        # type: () -> str
         """
         Returns
         -------
@@ -71,10 +79,12 @@ class Vlan(Base):
         return self._get_attribute(self._SDM_ATT_MAP['Name'])
     @Name.setter
     def Name(self, value):
+        # type: (str) -> None
         self._set_attribute(self._SDM_ATT_MAP['Name'], value)
 
     @property
     def Priority(self):
+        # type: () -> 'Multivalue'
         """
         Returns
         -------
@@ -85,6 +95,7 @@ class Vlan(Base):
 
     @property
     def Tpid(self):
+        # type: () -> 'Multivalue'
         """
         Returns
         -------
@@ -95,6 +106,7 @@ class Vlan(Base):
 
     @property
     def VlanId(self):
+        # type: () -> 'Multivalue'
         """
         Returns
         -------
@@ -104,6 +116,7 @@ class Vlan(Base):
         return Multivalue(self, self._get_attribute(self._SDM_ATT_MAP['VlanId']))
 
     def update(self, Name=None):
+        # type: (str) -> Vlan
         """Updates vlan resource on the server.
 
         This method has some named parameters with a type: obj (Multivalue).
@@ -119,7 +132,26 @@ class Vlan(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def add(self, Name=None):
+        # type: (str) -> Vlan
+        """Adds a new vlan resource on the json, only valid with config assistant
+
+        Args
+        ----
+        - Name (str): Name of NGPF element, guaranteed to be unique in Scenario
+
+        Returns
+        -------
+        - self: This instance with all currently retrieved vlan resources using find and the newly added vlan resources available through an iterator or index
+
+        Raises
+        ------
+        - Exception: if this function is not being used with config assistance
+        """
+        return self._add_xpath(self._map_locals(self._SDM_ATT_MAP, locals()))
+
     def find(self, Count=None, DescriptiveName=None, Name=None):
+        # type: (int, str, str) -> Vlan
         """Finds and retrieves vlan resources from the server.
 
         All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve vlan resources from the server.
