@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class LearnFrames(Base):
@@ -229,6 +231,56 @@ class LearnFrames(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, FastPathEnable=None, FastPathNumFrames=None, FastPathRate=None, LearnFrameSize=None, LearnFrequency=None, LearnNumFrames=None, LearnRate=None, LearnSendMacOnly=None, LearnSendRouterSolicitation=None, LearnWaitTime=None, LearnWaitTimeBeforeTransmit=None):
+        # type: (bool, int, int, int, str, int, int, bool, bool, int, int) -> LearnFrames
+        """Finds and retrieves learnFrames resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve learnFrames resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all learnFrames resources from the server.
+
+        Args
+        ----
+        - FastPathEnable (bool): If true, the fast path is enabled.
+        - FastPathNumFrames (number): The learnt information on the number of frames to be tramsferred.
+        - FastPathRate (number): The learnt inofrmation on the rate the data is to be transferred.
+        - LearnFrameSize (number): The learnt information on frame size.
+        - LearnFrequency (str(never | oncePerFefTest | oncePerFramesize | oncePerTest | onTrial)): Allows to choose how frequently IxNetwork sends learning frames during the test.
+        - LearnNumFrames (number): The frequency at which number of frames are to be learnt.
+        - LearnRate (number): The rate at which the data is to be learnt.
+        - LearnSendMacOnly (bool): The learnt information on the MAC address sent.
+        - LearnSendRouterSolicitation (bool): The learnt information on the router sent solicitation.
+        - LearnWaitTime (number): The learnt information on the wait time.
+        - LearnWaitTimeBeforeTransmit (number): The learnt wait time before transmitting.
+
+        Returns
+        -------
+        - self: This instance with matching learnFrames resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of learnFrames data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the learnFrames resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def Apply(self, *args, **kwargs):
         # type: (*Any, **Any) -> None
         """Executes the apply operation on the server.
