@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class LearnFrames(Base):
@@ -294,6 +296,60 @@ class LearnFrames(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, LearnFrameSize=None, LearnFrequency=None, LearnNumFrames=None, LearnRate=None, LearnWaitTime=None, LearnWaitTimeBeforeTransmit=None, LearningCountRandomFrameSize=None, LearningFrameSizeMode=None, LearningFramesizeFixedValue=None, LearningFramesizeList=None, LearningMaxIncrementFrameSize=None, LearningMaxRandomFrameSize=None, LearningMinIncrementFrameSize=None, LearningMinRandomFrameSize=None, LearningStepIncrementFrameSize=None):
+        # type: (int, str, int, int, int, int, str, str, int, str, str, str, str, str, str) -> LearnFrames
+        """Finds and retrieves learnFrames resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve learnFrames resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all learnFrames resources from the server.
+
+        Args
+        ----
+        - LearnFrameSize (number): Specifies the size of the learning frames.
+        - LearnFrequency (str(onBinaryIteration)): Allows to choose how frequently IxNetwork sends learning frames during the test.
+        - LearnNumFrames (number): Specifies the number of learning frames that IxNetwork sends for each address.
+        - LearnRate (number): Specifies the rate at which IxNetwork sends learn frames to the DUT.
+        - LearnWaitTime (number): Specifies the length of time in ms that IxNetwork pauses before sending all the learning frames from all the ports.
+        - LearnWaitTimeBeforeTransmit (number): The time in ms that IxNetwork waits before sending all the learning frames from all the ports.
+        - LearningCountRandomFrameSize (str): NOT DEFINED
+        - LearningFrameSizeMode (str(custom | fixed | increment | random)): NOT DEFINED
+        - LearningFramesizeFixedValue (number): NOT DEFINED
+        - LearningFramesizeList (str): NOT DEFINED
+        - LearningMaxIncrementFrameSize (str): NOT DEFINED
+        - LearningMaxRandomFrameSize (str): NOT DEFINED
+        - LearningMinIncrementFrameSize (str): NOT DEFINED
+        - LearningMinRandomFrameSize (str): NOT DEFINED
+        - LearningStepIncrementFrameSize (str): NOT DEFINED
+
+        Returns
+        -------
+        - self: This instance with matching learnFrames resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of learnFrames data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the learnFrames resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def Apply(self, *args, **kwargs):
         # type: (*Any, **Any) -> None
         """Executes the apply operation on the server.
