@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class PassCriteria(Base):
@@ -348,6 +350,63 @@ class PassCriteria(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, DataErrorThresholdMode=None, DataErrorThresholdValue=None, EnableDataIntegrityPassFail=None, EnablePassFail=None, EnableRatePassFail=None, EnableSequenceErrorsPassFail=None, EnableStandardDeviationPassFail=None, LatencyThresholdMode=None, LatencyThresholdScale=None, LatencyThresholdValue=None, LatencyVarThresholdMode=None, LatencyVariationThresholdScale=None, LatencyVariationThresholdValue=None, PassCriteriaLoadRateMode=None, PassCriteriaLoadRateScale=None, PassCriteriaLoadRateValue=None, SeqErrorsThresholdMode=None, SeqErrorsThresholdValue=None):
+        # type: (str, int, bool, bool, bool, bool, bool, str, str, int, str, str, int, str, str, int, str, int) -> PassCriteria
+        """Finds and retrieves passCriteria resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve passCriteria resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all passCriteria resources from the server.
+
+        Args
+        ----
+        - DataErrorThresholdMode (str(average | maximum)): It provides details about the data error in threshold mode
+        - DataErrorThresholdValue (number): If true, it provides the data error threshold value for the pass criteria
+        - EnableDataIntegrityPassFail (bool): If true, it enables the data integrity of pass fail
+        - EnablePassFail (bool): If true, it enables the pass fail criterion
+        - EnableRatePassFail (bool): If true, it enables the pass fail rate
+        - EnableSequenceErrorsPassFail (bool): If True, it enables the sequence errors of pass fail
+        - EnableStandardDeviationPassFail (bool): If true, it enables the standard deviation of pass fail
+        - LatencyThresholdMode (str(average | maximum)): If true, it provides the latency threshold mode of the pass criteria
+        - LatencyThresholdScale (str(ms | ns | us)): If true, it provides the latency threshold scale
+        - LatencyThresholdValue (number): If true, it provides the latency pass fail value
+        - LatencyVarThresholdMode (str(average | maximum)): If true, it provides the latency threshold mode of the pass criteria
+        - LatencyVariationThresholdScale (str(ms | ns | us)): If true, it provides the pass criteria for latency variation threshold scale
+        - LatencyVariationThresholdValue (number): If true, it provides the pass criteria for latency variation threshold value
+        - PassCriteriaLoadRateMode (str(average | minimum)): If true, it provides the details of the pass criteria of the load rate
+        - PassCriteriaLoadRateScale (str(fps | gbps | kbps | mbps | percent)): If true, it provides the pass criteria load rate scale
+        - PassCriteriaLoadRateValue (number): If true, it provides the pass criteria load rate value
+        - SeqErrorsThresholdMode (str(average | maximum)): It provides the sequence error threshold mode
+        - SeqErrorsThresholdValue (number): It provides the sequence error threshold value
+
+        Returns
+        -------
+        - self: This instance with matching passCriteria resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of passCriteria data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the passCriteria resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def Apply(self, *args, **kwargs):
         # type: (*Any, **Any) -> None
         """Executes the apply operation on the server.
