@@ -19,13 +19,15 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Generate(Base):
-    """This object specifies the properties of the generated report.
+    """This node specifies the properties of the generated report.
     The Generate class encapsulates a required generate resource which will be retrieved from the server every time the property is accessed.
     """
 
@@ -113,11 +115,54 @@ class Generate(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, OutputFormat=None, OutputPath=None, State=None, TemplatePath=None):
+        # type: (str, str, str, str) -> Generate
+        """Finds and retrieves generate resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve generate resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all generate resources from the server.
+
+        Args
+        ----
+        - OutputFormat (str(html | pdf)): The format of the generated report, either PDF or HTML.
+        - OutputPath (str): The location where the generated report is saved.
+        - State (str(done | failed | inProgress | none)): The state of the generated report.
+        - TemplatePath (str): The location of the template used to generate a report.
+
+        Returns
+        -------
+        - self: This instance with matching generate resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of generate data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the generate resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def GenerateReport(self, *args, **kwargs):
         # type: (*Any, **Any) -> None
         """Executes the generateReport operation on the server.
 
-        NOT DEFINED
+        Generates the Test report.
 
         generateReport(async_operation=bool)
         ------------------------------------
