@@ -19,15 +19,15 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class SaveResults(Base):
-    """This object specifies the properties of the results. There are two execs - saveSummaryResults
-
-and saveDetailedResults. The execs are used to save the summary and detailed results respectively.
+    """This node specifies the properties of the results. There are two execs - saveSummaryResults and saveDetailedResults. The execs are used to save the summary and detailed results respectively.
     The SaveResults class encapsulates a required saveResults resource which will be retrieved from the server every time the property is accessed.
     """
 
@@ -82,11 +82,52 @@ and saveDetailedResults. The execs are used to save the summary and detailed res
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, EnableAllResults=None, State=None):
+        # type: (bool, str) -> SaveResults
+        """Finds and retrieves saveResults resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve saveResults resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all saveResults resources from the server.
+
+        Args
+        ----
+        - EnableAllResults (bool): If true, all the results are enabled.
+        - State (str(done | failed | inProgress | none)): The state of the results.
+
+        Returns
+        -------
+        - self: This instance with matching saveResults resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of saveResults data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the saveResults resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def SaveDetailedResults(self, *args, **kwargs):
         # type: (*Any, **Any) -> None
         """Executes the saveDetailedResults operation on the server.
 
-        NOT DEFINED
+        Saves detailed test results.
 
         saveDetailedResults(async_operation=bool)
         -----------------------------------------
@@ -106,7 +147,7 @@ and saveDetailedResults. The execs are used to save the summary and detailed res
         # type: (*Any, **Any) -> None
         """Executes the saveFile operation on the server.
 
-        NOT DEFINED
+        Saves result file.
 
         saveFile(Arg2=enum, Arg3=string, async_operation=bool)
         ------------------------------------------------------
@@ -128,7 +169,7 @@ and saveDetailedResults. The execs are used to save the summary and detailed res
         # type: (*Any, **Any) -> None
         """Executes the saveSummaryResults operation on the server.
 
-        NOT DEFINED
+        Saves Test summary results.
 
         saveSummaryResults(async_operation=bool)
         ----------------------------------------
