@@ -19,13 +19,15 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class TestParameters(Base):
-    """This object specifies the test parameters.
+    """This node specifies the test parameters.
     The TestParameters class encapsulates a required testParameters resource which will be retrieved from the server every time the property is accessed.
     """
 
@@ -158,3 +160,49 @@ class TestParameters(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def find(self, TestCategory=None, TestDUTName=None, TestHighlights=None, TestId=None, TestName=None, TestObjectives=None, TesterName=None):
+        # type: (str, str, str, int, str, str, str) -> TestParameters
+        """Finds and retrieves testParameters resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve testParameters resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all testParameters resources from the server.
+
+        Args
+        ----
+        - TestCategory (str): The category of the test.
+        - TestDUTName (str): The name of the DUT.
+        - TestHighlights (str): The test highlights that are relevant.
+        - TestId (number): The unique identifier of the test.
+        - TestName (str): The name of the test for which the report is generated.
+        - TestObjectives (str): The objective of running the test.
+        - TesterName (str): The name of the tester.
+
+        Returns
+        -------
+        - self: This instance with matching testParameters resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of testParameters data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the testParameters resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
