@@ -19,13 +19,15 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Ixreporter(Base):
-    """Specifies the statistics for IxReporter.
+    """DEPRECATED Root node for IxReporter statistics.
     The Ixreporter class encapsulates a required ixreporter resource which will be retrieved from the server every time the property is accessed.
     """
 
@@ -51,10 +53,10 @@ class Ixreporter(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.statistics.ixreporter.datacollection.datacollection import DataCollection
-        if self._properties.get('DataCollection', None) is not None:
-            return self._properties.get('DataCollection')
-        else:
-            return DataCollection(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('DataCollection', None) is not None:
+                return self._properties.get('DataCollection')
+        return DataCollection(self)._select()
 
     @property
     def ReportGeneration(self):
@@ -68,7 +70,42 @@ class Ixreporter(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.statistics.ixreporter.reportgeneration.reportgeneration import ReportGeneration
-        if self._properties.get('ReportGeneration', None) is not None:
-            return self._properties.get('ReportGeneration')
-        else:
-            return ReportGeneration(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('ReportGeneration', None) is not None:
+                return self._properties.get('ReportGeneration')
+        return ReportGeneration(self)._select()
+
+    def find(self):
+        """Finds and retrieves ixreporter resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve ixreporter resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all ixreporter resources from the server.
+
+        Returns
+        -------
+        - self: This instance with matching ixreporter resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of ixreporter data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the ixreporter resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
