@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class ReportGeneration(Base):
@@ -47,10 +49,10 @@ class ReportGeneration(Base):
     @property
     def OutputFile(self):
         # type: () -> str
-        """
+        """DEPRECATED 
         Returns
         -------
-        - str: Signifies the output file
+        - str: Signifies the output file.
         """
         return self._get_attribute(self._SDM_ATT_MAP['OutputFile'])
     @OutputFile.setter
@@ -61,10 +63,10 @@ class ReportGeneration(Base):
     @property
     def OutputType(self):
         # type: () -> str
-        """
+        """DEPRECATED 
         Returns
         -------
-        - str(Html | Pdf): Signifies the output type
+        - str(Html | Pdf): Signifies the output type: HTML, PDF.
         """
         return self._get_attribute(self._SDM_ATT_MAP['OutputType'])
     @OutputType.setter
@@ -75,10 +77,10 @@ class ReportGeneration(Base):
     @property
     def Template(self):
         # type: () -> str
-        """
+        """DEPRECATED 
         Returns
         -------
-        - str: Signifies the template for IxReporter
+        - str: Signifies the template for IxReporter.
         """
         return self._get_attribute(self._SDM_ATT_MAP['Template'])
     @Template.setter
@@ -89,10 +91,10 @@ class ReportGeneration(Base):
     @property
     def TestRunId(self):
         # type: () -> int
-        """
+        """DEPRECATED 
         Returns
         -------
-        - number: Signifies the identifier for the test run
+        - number: Signifies the identifier for the test run.
         """
         return self._get_attribute(self._SDM_ATT_MAP['TestRunId'])
     @TestRunId.setter
@@ -106,10 +108,10 @@ class ReportGeneration(Base):
 
         Args
         ----
-        - OutputFile (str): Signifies the output file
-        - OutputType (str(Html | Pdf)): Signifies the output type
-        - Template (str): Signifies the template for IxReporter
-        - TestRunId (number): Signifies the identifier for the test run
+        - OutputFile (str): Signifies the output file.
+        - OutputType (str(Html | Pdf)): Signifies the output type: HTML, PDF.
+        - Template (str): Signifies the template for IxReporter.
+        - TestRunId (number): Signifies the identifier for the test run.
 
         Raises
         ------
@@ -117,6 +119,49 @@ class ReportGeneration(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, OutputFile=None, OutputType=None, Template=None, TestRunId=None):
+        # type: (str, str, str, int) -> ReportGeneration
+        """Finds and retrieves reportGeneration resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve reportGeneration resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all reportGeneration resources from the server.
+
+        Args
+        ----
+        - OutputFile (str): Signifies the output file.
+        - OutputType (str(Html | Pdf)): Signifies the output type: HTML, PDF.
+        - Template (str): Signifies the template for IxReporter.
+        - TestRunId (number): Signifies the identifier for the test run.
+
+        Returns
+        -------
+        - self: This instance with matching reportGeneration resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of reportGeneration data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the reportGeneration resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def Start(self, *args, **kwargs):
         # type: (*Any, **Any) -> None
         """Executes the start operation on the server.
