@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Statistics(Base):
@@ -58,7 +60,7 @@ class Statistics(Base):
 
     @property
     def AutoRefresh(self):
-        """
+        """DEPRECATED 
         Returns
         -------
         - obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.statistics.autorefresh.autorefresh.AutoRefresh): An instance of the AutoRefresh class
@@ -68,10 +70,10 @@ class Statistics(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.statistics.autorefresh.autorefresh import AutoRefresh
-        if self._properties.get('AutoRefresh', None) is not None:
-            return self._properties.get('AutoRefresh')
-        else:
-            return AutoRefresh(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('AutoRefresh', None) is not None:
+                return self._properties.get('AutoRefresh')
+        return AutoRefresh(self)._select()
 
     @property
     def CsvSnapshot(self):
@@ -85,14 +87,14 @@ class Statistics(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.statistics.csvsnapshot.csvsnapshot import CsvSnapshot
-        if self._properties.get('CsvSnapshot', None) is not None:
-            return self._properties.get('CsvSnapshot')
-        else:
-            return CsvSnapshot(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('CsvSnapshot', None) is not None:
+                return self._properties.get('CsvSnapshot')
+        return CsvSnapshot(self)._select()
 
     @property
     def Ixreporter(self):
-        """
+        """DEPRECATED 
         Returns
         -------
         - obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.statistics.ixreporter.ixreporter.Ixreporter): An instance of the Ixreporter class
@@ -102,10 +104,10 @@ class Statistics(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.statistics.ixreporter.ixreporter import Ixreporter
-        if self._properties.get('Ixreporter', None) is not None:
-            return self._properties.get('Ixreporter')
-        else:
-            return Ixreporter(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Ixreporter', None) is not None:
+                return self._properties.get('Ixreporter')
+        return Ixreporter(self)._select()
 
     @property
     def MeasurementMode(self):
@@ -119,10 +121,10 @@ class Statistics(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.statistics.measurementmode.measurementmode import MeasurementMode
-        if self._properties.get('MeasurementMode', None) is not None:
-            return self._properties.get('MeasurementMode')
-        else:
-            return MeasurementMode(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('MeasurementMode', None) is not None:
+                return self._properties.get('MeasurementMode')
+        return MeasurementMode(self)._select()
 
     @property
     def RawData(self):
@@ -136,10 +138,10 @@ class Statistics(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.statistics.rawdata.rawdata import RawData
-        if self._properties.get('RawData', None) is not None:
-            return self._properties.get('RawData')
-        else:
-            return RawData(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('RawData', None) is not None:
+                return self._properties.get('RawData')
+        return RawData(self)._select()
 
     @property
     def View(self):
@@ -153,15 +155,15 @@ class Statistics(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.statistics.view.view import View
-        if self._properties.get('View', None) is not None:
-            return self._properties.get('View')
-        else:
-            return View(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('View', None) is not None:
+                return self._properties.get('View')
+        return View(self)
 
     @property
     def AdditionalFcoeStat1(self):
         # type: () -> str
-        """
+        """DEPRECATED 
         Returns
         -------
         - str(fcoeInvalidDelimiter | fcoeInvalidFrames | fcoeInvalidSize | fcoeNormalSizeBadFcCRC | fcoeNormalSizeGoodFcCRC | fcoeUndersizeBadFcCRC | fcoeUndersizeGoodFcCRC | fcoeValidFrames): Signifies additional FCOE stat 1
@@ -175,7 +177,7 @@ class Statistics(Base):
     @property
     def AdditionalFcoeStat2(self):
         # type: () -> str
-        """
+        """DEPRECATED 
         Returns
         -------
         - str(fcoeInvalidDelimiter | fcoeInvalidFrames | fcoeInvalidSize | fcoeNormalSizeBadFcCRC | fcoeNormalSizeGoodFcCRC | fcoeUndersizeBadFcCRC | fcoeUndersizeGoodFcCRC | fcoeValidFrames): Sets the additional FCoE shared stats.
@@ -189,7 +191,7 @@ class Statistics(Base):
     @property
     def CsvFilePath(self):
         # type: () -> str
-        """
+        """DEPRECATED 
         Returns
         -------
         - str: Sets the CSV file path.
@@ -203,7 +205,7 @@ class Statistics(Base):
     @property
     def CsvLogPollIntervalMultiplier(self):
         # type: () -> int
-        """
+        """DEPRECATED 
         Returns
         -------
         - number: Used to specify the time interval between log polling events.
@@ -217,7 +219,7 @@ class Statistics(Base):
     @property
     def DataStorePollingIntervalMultiplier(self):
         # type: () -> int
-        """
+        """DEPRECATED 
         Returns
         -------
         - number: The data store polling interval value is the result of the data store polling interval multiplier value multiplied by the polling interval value set for the test.
@@ -231,7 +233,7 @@ class Statistics(Base):
     @property
     def EnableAutoDataStore(self):
         # type: () -> bool
-        """
+        """DEPRECATED 
         Returns
         -------
         - bool: If this option is enabled, StatViewer writes the statistical values in binary format for all test results in a view. The test results is converted into a binary array and written to a file.
@@ -245,7 +247,7 @@ class Statistics(Base):
     @property
     def EnableCsvLogging(self):
         # type: () -> bool
-        """
+        """DEPRECATED 
         Returns
         -------
         - bool: If this option is enabled, StatViewer writes the statistical values in comma separated value format for all test results in a view.
@@ -259,7 +261,7 @@ class Statistics(Base):
     @property
     def EnableDataCenterSharedStats(self):
         # type: () -> bool
-        """
+        """DEPRECATED 
         Returns
         -------
         - bool: If true, enables statistics for Data Center.
@@ -273,7 +275,7 @@ class Statistics(Base):
     @property
     def GuardrailEnabled(self):
         # type: () -> bool
-        """
+        """DEPRECATED 
         Returns
         -------
         - bool: NOT DEFINED
@@ -287,7 +289,7 @@ class Statistics(Base):
     @property
     def MaxNumberOfStatsPerCustomGraph(self):
         # type: () -> int
-        """
+        """DEPRECATED 
         Returns
         -------
         - number: The data store polling interval value is the result of the data store polling interval multiplier value multiplied by the polling interval value set for the test.
@@ -301,7 +303,7 @@ class Statistics(Base):
     @property
     def PollInterval(self):
         # type: () -> int
-        """
+        """DEPRECATED 
         Returns
         -------
         - number: The multiplier used with the frequency (2 seconds), to set the time interval between polling events. The default is 1 (1 times 2 seconds = 2 seconds).
@@ -315,7 +317,7 @@ class Statistics(Base):
     @property
     def TimeSynchronization(self):
         # type: () -> str
-        """
+        """DEPRECATED 
         Returns
         -------
         - str(syncTimeToSystemClock | syncTimeToTestStart): The statistics polling time can be configured to get synchronized with the system clock or reset it to 0 when the test starts. The time synchronization behavior can be changed only before the test starts and does not apply during test run.
@@ -329,7 +331,7 @@ class Statistics(Base):
     @property
     def TimestampPrecision(self):
         # type: () -> int
-        """
+        """DEPRECATED 
         Returns
         -------
         - number: The timestamp precision allows you to change the timestamp precision from microseconds to nanoseconds for specific StatViewer statistics and features. The timestamp precision can be set to have the fstatistics display values with decimals ranging from 0 to 9.
@@ -376,6 +378,59 @@ class Statistics(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, AdditionalFcoeStat1=None, AdditionalFcoeStat2=None, CsvFilePath=None, CsvLogPollIntervalMultiplier=None, DataStorePollingIntervalMultiplier=None, EnableAutoDataStore=None, EnableCsvLogging=None, EnableDataCenterSharedStats=None, GuardrailEnabled=None, MaxNumberOfStatsPerCustomGraph=None, PollInterval=None, TimeSynchronization=None, TimestampPrecision=None, UgsTcpPort=None):
+        # type: (str, str, str, int, int, bool, bool, bool, bool, int, int, str, int, int) -> Statistics
+        """Finds and retrieves statistics resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve statistics resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all statistics resources from the server.
+
+        Args
+        ----
+        - AdditionalFcoeStat1 (str(fcoeInvalidDelimiter | fcoeInvalidFrames | fcoeInvalidSize | fcoeNormalSizeBadFcCRC | fcoeNormalSizeGoodFcCRC | fcoeUndersizeBadFcCRC | fcoeUndersizeGoodFcCRC | fcoeValidFrames)): Signifies additional FCOE stat 1
+        - AdditionalFcoeStat2 (str(fcoeInvalidDelimiter | fcoeInvalidFrames | fcoeInvalidSize | fcoeNormalSizeBadFcCRC | fcoeNormalSizeGoodFcCRC | fcoeUndersizeBadFcCRC | fcoeUndersizeGoodFcCRC | fcoeValidFrames)): Sets the additional FCoE shared stats.
+        - CsvFilePath (str): Sets the CSV file path.
+        - CsvLogPollIntervalMultiplier (number): Used to specify the time interval between log polling events.
+        - DataStorePollingIntervalMultiplier (number): The data store polling interval value is the result of the data store polling interval multiplier value multiplied by the polling interval value set for the test.
+        - EnableAutoDataStore (bool): If this option is enabled, StatViewer writes the statistical values in binary format for all test results in a view. The test results is converted into a binary array and written to a file.
+        - EnableCsvLogging (bool): If this option is enabled, StatViewer writes the statistical values in comma separated value format for all test results in a view.
+        - EnableDataCenterSharedStats (bool): If true, enables statistics for Data Center.
+        - GuardrailEnabled (bool): NOT DEFINED
+        - MaxNumberOfStatsPerCustomGraph (number): The data store polling interval value is the result of the data store polling interval multiplier value multiplied by the polling interval value set for the test.
+        - PollInterval (number): The multiplier used with the frequency (2 seconds), to set the time interval between polling events. The default is 1 (1 times 2 seconds = 2 seconds).
+        - TimeSynchronization (str(syncTimeToSystemClock | syncTimeToTestStart)): The statistics polling time can be configured to get synchronized with the system clock or reset it to 0 when the test starts. The time synchronization behavior can be changed only before the test starts and does not apply during test run.
+        - TimestampPrecision (number): The timestamp precision allows you to change the timestamp precision from microseconds to nanoseconds for specific StatViewer statistics and features. The timestamp precision can be set to have the fstatistics display values with decimals ranging from 0 to 9.
+        - UgsTcpPort (number): Used to specify the UGS TCP port.
+
+        Returns
+        -------
+        - self: This instance with matching statistics resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of statistics data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the statistics resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def CheckViewTreeGroupExists(self, *args, **kwargs):
         # type: (*Any, **Any) -> None
         """Executes the checkViewTreeGroupExists operation on the server.
