@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Data(Base):
@@ -37,9 +39,11 @@ class Data(Base):
         'ColumnCount': 'columnCount',
         'CurrentPage': 'currentPage',
         'EgressMode': 'egressMode',
+        'EgressOption': 'egressOption',
         'EgressPageSize': 'egressPageSize',
         'IsBlocked': 'isBlocked',
         'IsReady': 'isReady',
+        'LastPageSize': 'lastPageSize',
         'PageSize': 'pageSize',
         'PageValues': 'pageValues',
         'RowCount': 'rowCount',
@@ -50,6 +54,7 @@ class Data(Base):
     }
     _SDM_ENUM_MAP = {
         'egressMode': ['conditional', 'paged'],
+        'egressOption': ['rowsWithNoPackets', 'rowsWithPackets', 'showAll'],
     }
 
     def __init__(self, parent, list_op=False):
@@ -67,10 +72,10 @@ class Data(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.statistics.view.data.egress.egress import Egress
-        if self._properties.get('Egress', None) is not None:
-            return self._properties.get('Egress')
-        else:
-            return Egress(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Egress', None) is not None:
+                return self._properties.get('Egress')
+        return Egress(self)
 
     @property
     def EgressRxCondition(self):
@@ -84,10 +89,10 @@ class Data(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.statistics.view.data.egressrxcondition.egressrxcondition import EgressRxCondition
-        if self._properties.get('EgressRxCondition', None) is not None:
-            return self._properties.get('EgressRxCondition')
-        else:
-            return EgressRxCondition(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('EgressRxCondition', None) is not None:
+                return self._properties.get('EgressRxCondition')
+        return EgressRxCondition(self)._select()
 
     @property
     def AllowPaging(self):
@@ -147,6 +152,20 @@ class Data(Base):
         # type: (str) -> None
         self._set_attribute(self._SDM_ATT_MAP['EgressMode'], value)
 
+    @property
+    def EgressOption(self):
+        # type: () -> str
+        """
+        Returns
+        -------
+        - str(rowsWithNoPackets | rowsWithPackets | showAll): 
+        """
+        return self._get_attribute(self._SDM_ATT_MAP['EgressOption'])
+    @EgressOption.setter
+    def EgressOption(self, value):
+        # type: (str) -> None
+        self._set_attribute(self._SDM_ATT_MAP['EgressOption'], value)
+
     @property
     def EgressPageSize(self):
         # type: () -> int
@@ -181,6 +200,16 @@ class Data(Base):
         """
         return self._get_attribute(self._SDM_ATT_MAP['IsReady'])
 
+    @property
+    def LastPageSize(self):
+        # type: () -> int
+        """
+        Returns
+        -------
+        - number: 
+        """
+        return self._get_attribute(self._SDM_ATT_MAP['LastPageSize'])
+
     @property
     def PageSize(self):
         # type: () -> int
@@ -253,14 +282,15 @@ class Data(Base):
         """
         return self._get_attribute(self._SDM_ATT_MAP['TotalRows'])
 
-    def update(self, CurrentPage=None, EgressMode=None, EgressPageSize=None, PageSize=None):
-        # type: (int, str, int, int) -> Data
+    def update(self, CurrentPage=None, EgressMode=None, EgressOption=None, EgressPageSize=None, PageSize=None):
+        # type: (int, str, str, int, int) -> Data
         """Updates data resource on the server.
 
         Args
         ----
         - CurrentPage (number): 
         - EgressMode (str(conditional | paged)): 
+        - EgressOption (str(rowsWithNoPackets | rowsWithPackets | showAll)): 
         - EgressPageSize (number): 
         - PageSize (number): 
 
@@ -269,3 +299,58 @@ class Data(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def find(self, AllowPaging=None, ColumnCaptions=None, ColumnCount=None, CurrentPage=None, EgressMode=None, EgressOption=None, EgressPageSize=None, IsBlocked=None, IsReady=None, LastPageSize=None, PageSize=None, PageValues=None, RowCount=None, RowValues=None, Timestamp=None, TotalPages=None, TotalRows=None):
+        """Finds and retrieves data resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve data resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all data resources from the server.
+
+        Args
+        ----
+        - AllowPaging (bool): 
+        - ColumnCaptions (list(str)): 
+        - ColumnCount (number): 
+        - CurrentPage (number): 
+        - EgressMode (str(conditional | paged)): 
+        - EgressOption (str(rowsWithNoPackets | rowsWithPackets | showAll)): 
+        - EgressPageSize (number): 
+        - IsBlocked (bool): 
+        - IsReady (bool): 
+        - LastPageSize (number): 
+        - PageSize (number): 
+        - PageValues (list(list[list[str]])): Returns the values in the current page. The ingress row is grouped with its corresponding egress rows
+        - RowCount (number): 
+        - RowValues (dict(arg1:list[list[list[str]]])): 
+        - Timestamp (number): 
+        - TotalPages (number): 
+        - TotalRows (number): 
+
+        Returns
+        -------
+        - self: This instance with matching data resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of data data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the data resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
