@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class DrillDown(Base):
@@ -58,10 +60,10 @@ class DrillDown(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.statistics.view.drilldown.availabletargetrowfilters.availabletargetrowfilters import AvailableTargetRowFilters
-        if self._properties.get('AvailableTargetRowFilters', None) is not None:
-            return self._properties.get('AvailableTargetRowFilters')
-        else:
-            return AvailableTargetRowFilters(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('AvailableTargetRowFilters', None) is not None:
+                return self._properties.get('AvailableTargetRowFilters')
+        return AvailableTargetRowFilters(self)
 
     @property
     def AvailableDrillDownOptions(self):
