@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Layer23NextGenProtocolFilter(Base):
@@ -61,10 +63,10 @@ class Layer23NextGenProtocolFilter(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.statistics.view.layer23nextgenprotocolfilter.advancedfilter.advancedfilter import AdvancedFilter
-        if self._properties.get('AdvancedFilter', None) is not None:
-            return self._properties.get('AdvancedFilter')
-        else:
-            return AdvancedFilter(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('AdvancedFilter', None) is not None:
+                return self._properties.get('AdvancedFilter')
+        return AdvancedFilter(self)
 
     @property
     def AvailableAdvancedFilterOptions(self):
@@ -78,10 +80,10 @@ class Layer23NextGenProtocolFilter(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.statistics.view.layer23nextgenprotocolfilter.availableadvancedfilteroptions.availableadvancedfilteroptions import AvailableAdvancedFilterOptions
-        if self._properties.get('AvailableAdvancedFilterOptions', None) is not None:
-            return self._properties.get('AvailableAdvancedFilterOptions')
-        else:
-            return AvailableAdvancedFilterOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('AvailableAdvancedFilterOptions', None) is not None:
+                return self._properties.get('AvailableAdvancedFilterOptions')
+        return AvailableAdvancedFilterOptions(self)
 
     @property
     def AdvancedCVFilter(self):
