@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Bfdv4Interface(Base):
@@ -82,10 +84,10 @@ class Bfdv4Interface(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.bfdv4session_dfe5a64bfc5795e7fe612df749b6836a import Bfdv4Session
-        if self._properties.get('Bfdv4Session', None) is not None:
-            return self._properties.get('Bfdv4Session')
-        else:
-            return Bfdv4Session(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Bfdv4Session', None) is not None:
+                return self._properties.get('Bfdv4Session')
+        return Bfdv4Session(self)._select()
 
     @property
     def LearnedInfo(self):
@@ -99,10 +101,10 @@ class Bfdv4Interface(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.learnedinfo.learnedinfo_ff4d5e5643a63bccb40b6cf64fc58100 import LearnedInfo
-        if self._properties.get('LearnedInfo', None) is not None:
-            return self._properties.get('LearnedInfo')
-        else:
-            return LearnedInfo(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('LearnedInfo', None) is not None:
+                return self._properties.get('LearnedInfo')
+        return LearnedInfo(self)
 
     @property
     def Active(self):
