@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class BroadcastDomainV6(Base):
@@ -81,10 +83,10 @@ class BroadcastDomainV6(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.pntlvlist_f29efa99695d122f75b5efd68698cd57 import PnTLVList
-        if self._properties.get('PnTLVList', None) is not None:
-            return self._properties.get('PnTLVList')
-        else:
-            return PnTLVList(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('PnTLVList', None) is not None:
+                return self._properties.get('PnTLVList')
+        return PnTLVList(self)
 
     @property
     def Active(self):
@@ -442,6 +444,50 @@ class BroadcastDomainV6(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, Count=None, DescriptiveName=None, Name=None, NoOfMacPools=None, UsebVlan=None):
+        # type: (int, str, str, int, bool) -> BroadcastDomainV6
+        """Finds and retrieves broadcastDomainV6 resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve broadcastDomainV6 resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all broadcastDomainV6 resources from the server.
+
+        Args
+        ----
+        - Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group.
+        - DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but may offer more context.
+        - Name (str): Name of NGPF element, guaranteed to be unique in Scenario
+        - NoOfMacPools (number): Number of Mac Pools
+        - UsebVlan (bool): Use B-VLAN
+
+        Returns
+        -------
+        - self: This instance with matching broadcastDomainV6 resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of broadcastDomainV6 data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the broadcastDomainV6 resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def AdvertiseAliasing(self, *args, **kwargs):
         # type: (*Any, **Any) -> Union[List[str], None]
         """Executes the advertiseAliasing operation on the server.
