@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Buckets(Base):
@@ -62,10 +64,10 @@ class Buckets(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.actionsprofile_c65384e18e20517e184ef23474b0b960 import ActionsProfile
-        if self._properties.get('ActionsProfile', None) is not None:
-            return self._properties.get('ActionsProfile')
-        else:
-            return ActionsProfile(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('ActionsProfile', None) is not None:
+                return self._properties.get('ActionsProfile')
+        return ActionsProfile(self)._select()
 
     @property
     def BucketDescription(self):
