@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class CfmSlm(Base):
@@ -74,10 +76,10 @@ class CfmSlm(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.stopslmparams_2117fd9e6d0ad885042f04f4604813e9 import StopSlmParams
-        if self._properties.get('StopSlmParams', None) is not None:
-            return self._properties.get('StopSlmParams')
-        else:
-            return StopSlmParams(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('StopSlmParams', None) is not None:
+                return self._properties.get('StopSlmParams')
+        return StopSlmParams(self)._select()
 
     @property
     def Count(self):
@@ -152,7 +154,7 @@ class CfmSlm(Base):
         """
         Returns
         -------
-        - obj(ixnetwork_restpy.multivalue.Multivalue): If enabled, will send continous bursts.
+        - obj(ixnetwork_restpy.multivalue.Multivalue): If enabled, will send continuous bursts.
         """
         from ixnetwork_restpy.multivalue import Multivalue
         return Multivalue(self, self._get_attribute(self._SDM_ATT_MAP['SlmContinuousBurst']))
@@ -229,7 +231,7 @@ class CfmSlm(Base):
         """
         Returns
         -------
-        - obj(ixnetwork_restpy.multivalue.Multivalue): Mode
+        - obj(ixnetwork_restpy.multivalue.Multivalue): Synthetic Loss Measurement Method - One way or Two way
         """
         from ixnetwork_restpy.multivalue import Multivalue
         return Multivalue(self, self._get_attribute(self._SDM_ATT_MAP['SlmMode']))
@@ -347,6 +349,51 @@ class CfmSlm(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, Count=None, DescriptiveName=None, Name=None, SlmStateInfo=None, SlmTestIdInfo=None, SlmTxFCfInfo=None):
+        # type: (int, str, str, List[str], List[int], List[int]) -> CfmSlm
+        """Finds and retrieves cfmSlm resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve cfmSlm resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all cfmSlm resources from the server.
+
+        Args
+        ----
+        - Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group.
+        - DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but may offer more context.
+        - Name (str): Name of NGPF element, guaranteed to be unique in Scenario
+        - SlmStateInfo (list(str[expired | none | notStarted | running | stopped])): Displays the current SLM State. Valid states are Running, Stopped, Expired and Not Started.
+        - SlmTestIdInfo (list(number)): Displays SLM Test ID Information.
+        - SlmTxFCfInfo (list(number)): Displays SLM Last TxFCf.
+
+        Returns
+        -------
+        - self: This instance with matching cfmSlm resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of cfmSlm data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the cfmSlm resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def StartSlm(self, *args, **kwargs):
         # type: (*Any, **Any) -> Union[List[str], None]
         """Executes the startSlm operation on the server.
