@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class CuspCP(Base):
@@ -60,17 +62,17 @@ class CuspCP(Base):
         """
         Returns
         -------
-        - obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.upgroupinfo_f5beff0f5213c06f1da33f6d518d236a.UpGroupInfo): An instance of the UpGroupInfo class
+        - obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.upgroupinfo_20235edbe32eb48e3acc3bd1091e84c4.UpGroupInfo): An instance of the UpGroupInfo class
 
         Raises
         ------
         - ServerError: The server has encountered an uncategorized error condition
         """
-        from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.upgroupinfo_f5beff0f5213c06f1da33f6d518d236a import UpGroupInfo
-        if self._properties.get('UpGroupInfo', None) is not None:
-            return self._properties.get('UpGroupInfo')
-        else:
-            return UpGroupInfo(self)
+        from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.upgroupinfo_20235edbe32eb48e3acc3bd1091e84c4 import UpGroupInfo
+        if len(self._object_properties) > 0:
+            if self._properties.get('UpGroupInfo', None) is not None:
+                return self._properties.get('UpGroupInfo')
+        return UpGroupInfo(self)
 
     @property
     def Active(self):
