@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Dhcp6LearnedInfo(Base):
@@ -133,3 +135,49 @@ class Dhcp6LearnedInfo(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def find(self, Count=None, DescriptiveName=None, Name=None, TabbedDiscoveredAddresses=None, TabbedDiscoveredGateways=None, TabbedDiscoveredPrefix=None, TabbedDiscoveredPrefixLength=None):
+        # type: (int, str, str, List[str], List[str], List[str], List[int]) -> Dhcp6LearnedInfo
+        """Finds and retrieves dhcp6LearnedInfo resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve dhcp6LearnedInfo resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all dhcp6LearnedInfo resources from the server.
+
+        Args
+        ----
+        - Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group.
+        - DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but may offer more context.
+        - Name (str): Name of NGPF element, guaranteed to be unique in Scenario
+        - TabbedDiscoveredAddresses (list(str)): The discovered IPv6 addresses.
+        - TabbedDiscoveredGateways (list(str)): The discovered gateway IPv6 addresses.
+        - TabbedDiscoveredPrefix (list(str)): The discovered IPv6 prefix.
+        - TabbedDiscoveredPrefixLength (list(number)): The length of the discovered IPv6 prefix.
+
+        Returns
+        -------
+        - self: This instance with matching dhcp6LearnedInfo resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of dhcp6LearnedInfo data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the dhcp6LearnedInfo resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
