@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Dhcpv4client(Base):
@@ -77,10 +79,10 @@ class Dhcpv4client(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.bfdv4interface_91b557a3f744baf442dbe21ac75e8f2e import Bfdv4Interface
-        if self._properties.get('Bfdv4Interface', None) is not None:
-            return self._properties.get('Bfdv4Interface')
-        else:
-            return Bfdv4Interface(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Bfdv4Interface', None) is not None:
+                return self._properties.get('Bfdv4Interface')
+        return Bfdv4Interface(self)
 
     @property
     def BgpIpv4Peer(self):
@@ -94,10 +96,10 @@ class Dhcpv4client(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.bgpipv4peer_904e2c38f7c97d7b9bfa48f79492ac8a import BgpIpv4Peer
-        if self._properties.get('BgpIpv4Peer', None) is not None:
-            return self._properties.get('BgpIpv4Peer')
-        else:
-            return BgpIpv4Peer(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('BgpIpv4Peer', None) is not None:
+                return self._properties.get('BgpIpv4Peer')
+        return BgpIpv4Peer(self)
 
     @property
     def ECpriRe(self):
@@ -111,10 +113,10 @@ class Dhcpv4client(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ecprire_51f1030cbafd2e567d3b517032a1b011 import ECpriRe
-        if self._properties.get('ECpriRe', None) is not None:
-            return self._properties.get('ECpriRe')
-        else:
-            return ECpriRe(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('ECpriRe', None) is not None:
+                return self._properties.get('ECpriRe')
+        return ECpriRe(self)
 
     @property
     def ECpriRec(self):
@@ -128,10 +130,10 @@ class Dhcpv4client(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ecprirec_129f1d43f285a4f806ade4e0df814255 import ECpriRec
-        if self._properties.get('ECpriRec', None) is not None:
-            return self._properties.get('ECpriRec')
-        else:
-            return ECpriRec(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('ECpriRec', None) is not None:
+                return self._properties.get('ECpriRec')
+        return ECpriRec(self)
 
     @property
     def Geneve(self):
@@ -145,10 +147,10 @@ class Dhcpv4client(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.geneve_14ab6f140956b4fc77d1d0f03c5e7514 import Geneve
-        if self._properties.get('Geneve', None) is not None:
-            return self._properties.get('Geneve')
-        else:
-            return Geneve(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Geneve', None) is not None:
+                return self._properties.get('Geneve')
+        return Geneve(self)
 
     @property
     def IgmpHost(self):
@@ -162,10 +164,10 @@ class Dhcpv4client(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.igmphost_8940887674c0387469423e8df3a33854 import IgmpHost
-        if self._properties.get('IgmpHost', None) is not None:
-            return self._properties.get('IgmpHost')
-        else:
-            return IgmpHost(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('IgmpHost', None) is not None:
+                return self._properties.get('IgmpHost')
+        return IgmpHost(self)
 
     @property
     def IgmpQuerier(self):
@@ -179,10 +181,10 @@ class Dhcpv4client(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.igmpquerier_38c883b0cec7ffb5405af90bf1b8cda5 import IgmpQuerier
-        if self._properties.get('IgmpQuerier', None) is not None:
-            return self._properties.get('IgmpQuerier')
-        else:
-            return IgmpQuerier(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('IgmpQuerier', None) is not None:
+                return self._properties.get('IgmpQuerier')
+        return IgmpQuerier(self)
 
     @property
     def MplsOam(self):
@@ -196,10 +198,10 @@ class Dhcpv4client(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.mplsoam_e01bb6affe899a4731aa60619f4aeadc import MplsOam
-        if self._properties.get('MplsOam', None) is not None:
-            return self._properties.get('MplsOam')
-        else:
-            return MplsOam(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('MplsOam', None) is not None:
+                return self._properties.get('MplsOam')
+        return MplsOam(self)
 
     @property
     def NetconfClient(self):
@@ -213,27 +215,27 @@ class Dhcpv4client(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.netconfclient_1eaa2ab0efacd988796bdc1f5fe4291c import NetconfClient
-        if self._properties.get('NetconfClient', None) is not None:
-            return self._properties.get('NetconfClient')
-        else:
-            return NetconfClient(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('NetconfClient', None) is not None:
+                return self._properties.get('NetconfClient')
+        return NetconfClient(self)
 
     @property
     def NetconfServer(self):
         """
         Returns
         -------
-        - obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.netconfserver_ef6d7597b8407441914451a9b6bf1bf5.NetconfServer): An instance of the NetconfServer class
+        - obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.netconfserver_bf453114f7f2bb7b009c8c9874517624.NetconfServer): An instance of the NetconfServer class
 
         Raises
         ------
         - ServerError: The server has encountered an uncategorized error condition
         """
-        from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.netconfserver_ef6d7597b8407441914451a9b6bf1bf5 import NetconfServer
-        if self._properties.get('NetconfServer', None) is not None:
-            return self._properties.get('NetconfServer')
-        else:
-            return NetconfServer(self)
+        from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.netconfserver_bf453114f7f2bb7b009c8c9874517624 import NetconfServer
+        if len(self._object_properties) > 0:
+            if self._properties.get('NetconfServer', None) is not None:
+                return self._properties.get('NetconfServer')
+        return NetconfServer(self)
 
     @property
     def Ospfv2(self):
@@ -247,10 +249,10 @@ class Dhcpv4client(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ospfv2_eb5737de1e17134d62e78286b93d24ac import Ospfv2
-        if self._properties.get('Ospfv2', None) is not None:
-            return self._properties.get('Ospfv2')
-        else:
-            return Ospfv2(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Ospfv2', None) is not None:
+                return self._properties.get('Ospfv2')
+        return Ospfv2(self)
 
     @property
     def Pcc(self):
@@ -264,10 +266,10 @@ class Dhcpv4client(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.pcc_4548de1a5046938dd4962870dfbd425f import Pcc
-        if self._properties.get('Pcc', None) is not None:
-            return self._properties.get('Pcc')
-        else:
-            return Pcc(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Pcc', None) is not None:
+                return self._properties.get('Pcc')
+        return Pcc(self)
 
     @property
     def Pce(self):
@@ -281,10 +283,10 @@ class Dhcpv4client(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.pce_bd5f6a11078a4f0deb5d56bef8e9674f import Pce
-        if self._properties.get('Pce', None) is not None:
-            return self._properties.get('Pce')
-        else:
-            return Pce(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Pce', None) is not None:
+                return self._properties.get('Pce')
+        return Pce(self)
 
     @property
     def PimV4Interface(self):
@@ -298,10 +300,10 @@ class Dhcpv4client(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.pimv4interface_92603cbceaf153039f7575ed9bc4aa67 import PimV4Interface
-        if self._properties.get('PimV4Interface', None) is not None:
-            return self._properties.get('PimV4Interface')
-        else:
-            return PimV4Interface(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('PimV4Interface', None) is not None:
+                return self._properties.get('PimV4Interface')
+        return PimV4Interface(self)
 
     @property
     def Tag(self):
@@ -315,10 +317,10 @@ class Dhcpv4client(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tag_e30f24de79247381d4dfd423b2f6986d import Tag
-        if self._properties.get('Tag', None) is not None:
-            return self._properties.get('Tag')
-        else:
-            return Tag(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Tag', None) is not None:
+                return self._properties.get('Tag')
+        return Tag(self)
 
     @property
     def TlvProfile(self):
@@ -332,10 +334,10 @@ class Dhcpv4client(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tlvprofile.tlvprofile_69db000d3ef3b060f5edc387b878736c import TlvProfile
-        if self._properties.get('TlvProfile', None) is not None:
-            return self._properties.get('TlvProfile')
-        else:
-            return TlvProfile(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('TlvProfile', None) is not None:
+                return self._properties.get('TlvProfile')
+        return TlvProfile(self)
 
     @property
     def Vxlan(self):
@@ -349,10 +351,10 @@ class Dhcpv4client(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.vxlan_ed3df6fe7146492fc5fe0f77f53f9473 import Vxlan
-        if self._properties.get('Vxlan', None) is not None:
-            return self._properties.get('Vxlan')
-        else:
-            return Vxlan(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Vxlan', None) is not None:
+                return self._properties.get('Vxlan')
+        return Vxlan(self)
 
     @property
     def Vxlangpe(self):
@@ -366,10 +368,10 @@ class Dhcpv4client(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.vxlangpe_e779e9783907b2c61304fff3bae70291 import Vxlangpe
-        if self._properties.get('Vxlangpe', None) is not None:
-            return self._properties.get('Vxlangpe')
-        else:
-            return Vxlangpe(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Vxlangpe', None) is not None:
+                return self._properties.get('Vxlangpe')
+        return Vxlangpe(self)
 
     @property
     def ConnectedVia(self):
