@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Dhcpv4relayAgent(Base):
@@ -68,10 +70,10 @@ class Dhcpv4relayAgent(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.dhcp4relayagenttlvprofile_1f5a4a0853366dc50313b9b3e8f6e68d import Dhcp4RelayAgentTlvProfile
-        if self._properties.get('Dhcp4RelayAgentTlvProfile', None) is not None:
-            return self._properties.get('Dhcp4RelayAgentTlvProfile')
-        else:
-            return Dhcp4RelayAgentTlvProfile(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Dhcp4RelayAgentTlvProfile', None) is not None:
+                return self._properties.get('Dhcp4RelayAgentTlvProfile')
+        return Dhcp4RelayAgentTlvProfile(self)._select()
 
     @property
     def ConnectedVia(self):
