@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Dhcpv6server(Base):
@@ -72,10 +74,10 @@ class Dhcpv6server(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.dhcp6serversessions_0c878921a71494f8bce977ffffb48289 import Dhcp6ServerSessions
-        if self._properties.get('Dhcp6ServerSessions', None) is not None:
-            return self._properties.get('Dhcp6ServerSessions')
-        else:
-            return Dhcp6ServerSessions(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Dhcp6ServerSessions', None) is not None:
+                return self._properties.get('Dhcp6ServerSessions')
+        return Dhcp6ServerSessions(self)._select()
 
     @property
     def TlvProfile(self):
@@ -89,10 +91,10 @@ class Dhcpv6server(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tlvprofile.tlvprofile_69db000d3ef3b060f5edc387b878736c import TlvProfile
-        if self._properties.get('TlvProfile', None) is not None:
-            return self._properties.get('TlvProfile')
-        else:
-            return TlvProfile(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('TlvProfile', None) is not None:
+                return self._properties.get('TlvProfile')
+        return TlvProfile(self)
 
     @property
     def ConnectedVia(self):
