@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class FlowSet(Base):
@@ -66,10 +68,10 @@ class FlowSet(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.flowprofile_a1f78cfc247b918e0d8219ac19d05f87 import FlowProfile
-        if self._properties.get('FlowProfile', None) is not None:
-            return self._properties.get('FlowProfile')
-        else:
-            return FlowProfile(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('FlowProfile', None) is not None:
+                return self._properties.get('FlowProfile')
+        return FlowProfile(self)._select()
 
     @property
     def Active(self):
