@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Groups(Base):
@@ -64,10 +66,10 @@ class Groups(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.buckets_bd4257b6720604ee2ee57801dd96774d import Buckets
-        if self._properties.get('Buckets', None) is not None:
-            return self._properties.get('Buckets')
-        else:
-            return Buckets(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Buckets', None) is not None:
+                return self._properties.get('Buckets')
+        return Buckets(self)
 
     @property
     def Active(self):
