@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class IPv6PseudoNodeRoutes(Base):
@@ -87,10 +89,10 @@ class IPv6PseudoNodeRoutes(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisl3pseudoroutemtidipv6_2a10c4ed3c307b62d44ec1ae4467199f import IsisL3PseudoRouteMtIdIPv6
-        if self._properties.get('IsisL3PseudoRouteMtIdIPv6', None) is not None:
-            return self._properties.get('IsisL3PseudoRouteMtIdIPv6')
-        else:
-            return IsisL3PseudoRouteMtIdIPv6(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('IsisL3PseudoRouteMtIdIPv6', None) is not None:
+                return self._properties.get('IsisL3PseudoRouteMtIdIPv6')
+        return IsisL3PseudoRouteMtIdIPv6(self)._select()
 
     @property
     def PseudoRoutesSid(self):
@@ -104,10 +106,10 @@ class IPv6PseudoNodeRoutes(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.pseudoroutessid_623bc67162f81219eae7debb23b5fa39 import PseudoRoutesSid
-        if self._properties.get('PseudoRoutesSid', None) is not None:
-            return self._properties.get('PseudoRoutesSid')
-        else:
-            return PseudoRoutesSid(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('PseudoRoutesSid', None) is not None:
+                return self._properties.get('PseudoRoutesSid')
+        return PseudoRoutesSid(self)._select()
 
     @property
     def Tag(self):
@@ -121,10 +123,10 @@ class IPv6PseudoNodeRoutes(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tag_e30f24de79247381d4dfd423b2f6986d import Tag
-        if self._properties.get('Tag', None) is not None:
-            return self._properties.get('Tag')
-        else:
-            return Tag(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Tag', None) is not None:
+                return self._properties.get('Tag')
+        return Tag(self)
 
     @property
     def Active(self):
