@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class IsisBierSubDomainList(Base):
@@ -60,10 +62,10 @@ class IsisBierSubDomainList(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisbierbsobjectlist_72488dadc9d26969d482f402d7de2734 import IsisBierBSObjectList
-        if self._properties.get('IsisBierBSObjectList', None) is not None:
-            return self._properties.get('IsisBierBSObjectList')
-        else:
-            return IsisBierBSObjectList(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('IsisBierBSObjectList', None) is not None:
+                return self._properties.get('IsisBierBSObjectList')
+        return IsisBierBSObjectList(self)
 
     @property
     def BAR(self):
@@ -186,6 +188,49 @@ class IsisBierSubDomainList(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, Count=None, DescriptiveName=None, Name=None, NumberOfBSLen=None):
+        # type: (int, str, str, int) -> IsisBierSubDomainList
+        """Finds and retrieves isisBierSubDomainList resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve isisBierSubDomainList resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all isisBierSubDomainList resources from the server.
+
+        Args
+        ----
+        - Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group.
+        - DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but may offer more context.
+        - Name (str): Name of NGPF element, guaranteed to be unique in Scenario
+        - NumberOfBSLen (number): Number of Supported BSL
+
+        Returns
+        -------
+        - self: This instance with matching isisBierSubDomainList resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of isisBierSubDomainList data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the isisBierSubDomainList resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def get_device_ids(self, PortNames=None, BAR=None, BFRId=None, IPA=None, Active=None, SubDomainId=None):
         """Base class infrastructure that gets a list of isisBierSubDomainList device ids encapsulated by this object.
 
