@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class IsisPseudoInterface(Base):
@@ -56,10 +58,10 @@ class IsisPseudoInterface(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisdcepseudoifaceattpoint1config_dce0066317952a09c055b9f568621953 import IsisDcePseudoIfaceAttPoint1Config
-        if self._properties.get('IsisDcePseudoIfaceAttPoint1Config', None) is not None:
-            return self._properties.get('IsisDcePseudoIfaceAttPoint1Config')
-        else:
-            return IsisDcePseudoIfaceAttPoint1Config(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('IsisDcePseudoIfaceAttPoint1Config', None) is not None:
+                return self._properties.get('IsisDcePseudoIfaceAttPoint1Config')
+        return IsisDcePseudoIfaceAttPoint1Config(self)
 
     @property
     def IsisDcePseudoIfaceAttPoint2Config(self):
@@ -73,10 +75,10 @@ class IsisPseudoInterface(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisdcepseudoifaceattpoint2config_08c96458d8806c0878ba2591f7235870 import IsisDcePseudoIfaceAttPoint2Config
-        if self._properties.get('IsisDcePseudoIfaceAttPoint2Config', None) is not None:
-            return self._properties.get('IsisDcePseudoIfaceAttPoint2Config')
-        else:
-            return IsisDcePseudoIfaceAttPoint2Config(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('IsisDcePseudoIfaceAttPoint2Config', None) is not None:
+                return self._properties.get('IsisDcePseudoIfaceAttPoint2Config')
+        return IsisDcePseudoIfaceAttPoint2Config(self)
 
     @property
     def IsisL3PseudoIfaceAttPoint1Config(self):
@@ -90,10 +92,10 @@ class IsisPseudoInterface(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisl3pseudoifaceattpoint1config_e6b2374da4892fed3474f1ab974dbf1c import IsisL3PseudoIfaceAttPoint1Config
-        if self._properties.get('IsisL3PseudoIfaceAttPoint1Config', None) is not None:
-            return self._properties.get('IsisL3PseudoIfaceAttPoint1Config')
-        else:
-            return IsisL3PseudoIfaceAttPoint1Config(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('IsisL3PseudoIfaceAttPoint1Config', None) is not None:
+                return self._properties.get('IsisL3PseudoIfaceAttPoint1Config')
+        return IsisL3PseudoIfaceAttPoint1Config(self)
 
     @property
     def IsisL3PseudoIfaceAttPoint2Config(self):
@@ -107,10 +109,10 @@ class IsisPseudoInterface(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisl3pseudoifaceattpoint2config_37681cb7f2d7b1eb6c812c1b9f243542 import IsisL3PseudoIfaceAttPoint2Config
-        if self._properties.get('IsisL3PseudoIfaceAttPoint2Config', None) is not None:
-            return self._properties.get('IsisL3PseudoIfaceAttPoint2Config')
-        else:
-            return IsisL3PseudoIfaceAttPoint2Config(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('IsisL3PseudoIfaceAttPoint2Config', None) is not None:
+                return self._properties.get('IsisL3PseudoIfaceAttPoint2Config')
+        return IsisL3PseudoIfaceAttPoint2Config(self)
 
     @property
     def IsisSpbPseudoIfaceAttPoint1Config(self):
@@ -124,10 +126,10 @@ class IsisPseudoInterface(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisspbpseudoifaceattpoint1config_04ab03c0f19e657e435c655358111db5 import IsisSpbPseudoIfaceAttPoint1Config
-        if self._properties.get('IsisSpbPseudoIfaceAttPoint1Config', None) is not None:
-            return self._properties.get('IsisSpbPseudoIfaceAttPoint1Config')
-        else:
-            return IsisSpbPseudoIfaceAttPoint1Config(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('IsisSpbPseudoIfaceAttPoint1Config', None) is not None:
+                return self._properties.get('IsisSpbPseudoIfaceAttPoint1Config')
+        return IsisSpbPseudoIfaceAttPoint1Config(self)
 
     @property
     def IsisSpbPseudoIfaceAttPoint2Config(self):
@@ -141,10 +143,10 @@ class IsisPseudoInterface(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisspbpseudoifaceattpoint2config_0781ccf029e86f2c708647212802930e import IsisSpbPseudoIfaceAttPoint2Config
-        if self._properties.get('IsisSpbPseudoIfaceAttPoint2Config', None) is not None:
-            return self._properties.get('IsisSpbPseudoIfaceAttPoint2Config')
-        else:
-            return IsisSpbPseudoIfaceAttPoint2Config(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('IsisSpbPseudoIfaceAttPoint2Config', None) is not None:
+                return self._properties.get('IsisSpbPseudoIfaceAttPoint2Config')
+        return IsisSpbPseudoIfaceAttPoint2Config(self)
 
     @property
     def IsisTrillPseudoIfaceAttPoint1Config(self):
@@ -158,10 +160,10 @@ class IsisPseudoInterface(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isistrillpseudoifaceattpoint1config_4c83cc199df8becee43d785e9ef03dc7 import IsisTrillPseudoIfaceAttPoint1Config
-        if self._properties.get('IsisTrillPseudoIfaceAttPoint1Config', None) is not None:
-            return self._properties.get('IsisTrillPseudoIfaceAttPoint1Config')
-        else:
-            return IsisTrillPseudoIfaceAttPoint1Config(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('IsisTrillPseudoIfaceAttPoint1Config', None) is not None:
+                return self._properties.get('IsisTrillPseudoIfaceAttPoint1Config')
+        return IsisTrillPseudoIfaceAttPoint1Config(self)
 
     @property
     def IsisTrillPseudoIfaceAttPoint2Config(self):
@@ -175,10 +177,10 @@ class IsisPseudoInterface(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isistrillpseudoifaceattpoint2config_1910327d5bcdde39c812851ec539a846 import IsisTrillPseudoIfaceAttPoint2Config
-        if self._properties.get('IsisTrillPseudoIfaceAttPoint2Config', None) is not None:
-            return self._properties.get('IsisTrillPseudoIfaceAttPoint2Config')
-        else:
-            return IsisTrillPseudoIfaceAttPoint2Config(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('IsisTrillPseudoIfaceAttPoint2Config', None) is not None:
+                return self._properties.get('IsisTrillPseudoIfaceAttPoint2Config')
+        return IsisTrillPseudoIfaceAttPoint2Config(self)
 
     @property
     def Count(self):
