@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class IsisPseudoSRv6LocatorEntryList(Base):
@@ -70,10 +72,10 @@ class IsisPseudoSRv6LocatorEntryList(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isispseudosrv6endsidlist_7f1f5407e7e0f543c58ead0450ef8be9 import IsisPseudoSRv6EndSIDList
-        if self._properties.get('IsisPseudoSRv6EndSIDList', None) is not None:
-            return self._properties.get('IsisPseudoSRv6EndSIDList')
-        else:
-            return IsisPseudoSRv6EndSIDList(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('IsisPseudoSRv6EndSIDList', None) is not None:
+                return self._properties.get('IsisPseudoSRv6EndSIDList')
+        return IsisPseudoSRv6EndSIDList(self)._select()
 
     @property
     def Active(self):
@@ -306,6 +308,49 @@ class IsisPseudoSRv6LocatorEntryList(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, Count=None, DescriptiveName=None, Name=None, SidCount=None):
+        # type: (int, str, str, int) -> IsisPseudoSRv6LocatorEntryList
+        """Finds and retrieves isisPseudoSRv6LocatorEntryList resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve isisPseudoSRv6LocatorEntryList resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all isisPseudoSRv6LocatorEntryList resources from the server.
+
+        Args
+        ----
+        - Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group.
+        - DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but may offer more context.
+        - Name (str): Name of NGPF element, guaranteed to be unique in Scenario
+        - SidCount (number): SID Count
+
+        Returns
+        -------
+        - self: This instance with matching isisPseudoSRv6LocatorEntryList resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of isisPseudoSRv6LocatorEntryList data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the isisPseudoSRv6LocatorEntryList resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def Abort(self, *args, **kwargs):
         # type: (*Any, **Any) -> None
         """Executes the abort operation on the server.
