@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class IsisSpbRouter(Base):
@@ -91,10 +93,10 @@ class IsisSpbRouter(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.spbtopologylist_079e088e28e1c709b12ccf5543f3c230 import SpbTopologyList
-        if self._properties.get('SpbTopologyList', None) is not None:
-            return self._properties.get('SpbTopologyList')
-        else:
-            return SpbTopologyList(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('SpbTopologyList', None) is not None:
+                return self._properties.get('SpbTopologyList')
+        return SpbTopologyList(self)._select()
 
     @property
     def Active(self):
