@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class IsisSRv6LocatorEntryList(Base):
@@ -70,10 +72,10 @@ class IsisSRv6LocatorEntryList(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isissrv6endsidlist_02de140eb2719a0e953620cb8889e8d6 import IsisSRv6EndSIDList
-        if self._properties.get('IsisSRv6EndSIDList', None) is not None:
-            return self._properties.get('IsisSRv6EndSIDList')
-        else:
-            return IsisSRv6EndSIDList(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('IsisSRv6EndSIDList', None) is not None:
+                return self._properties.get('IsisSRv6EndSIDList')
+        return IsisSRv6EndSIDList(self)._select()
 
     @property
     def Active(self):
@@ -306,6 +308,49 @@ class IsisSRv6LocatorEntryList(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, Count=None, DescriptiveName=None, Name=None, SidCount=None):
+        # type: (int, str, str, int) -> IsisSRv6LocatorEntryList
+        """Finds and retrieves isisSRv6LocatorEntryList resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve isisSRv6LocatorEntryList resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all isisSRv6LocatorEntryList resources from the server.
+
+        Args
+        ----
+        - Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group.
+        - DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but may offer more context.
+        - Name (str): Name of NGPF element, guaranteed to be unique in Scenario
+        - SidCount (number): SID Count
+
+        Returns
+        -------
+        - self: This instance with matching isisSRv6LocatorEntryList resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of isisSRv6LocatorEntryList data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the isisSRv6LocatorEntryList resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def get_device_ids(self, PortNames=None, Active=None, AdvertiseLocatorAsPrefix=None, Algorithm=None, DBit=None, Locator=None, LocatorName=None, LocatorSize=None, Metric=None, MtApplicabilityForIPv6Locator=None, MtId=None, PrefixLength=None, Redistribution=None, ReservedFlags=None, RouteMetric=None, RouteOrigin=None):
         """Base class infrastructure that gets a list of isisSRv6LocatorEntryList device ids encapsulated by this object.
 
