@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class LdpLeafRangeV6(Base):
@@ -68,10 +70,10 @@ class LdpLeafRangeV6(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ldptlvlist_30bf84fe9b838fe1c5800e633f13cff2 import LdpTLVList
-        if self._properties.get('LdpTLVList', None) is not None:
-            return self._properties.get('LdpTLVList')
-        else:
-            return LdpTLVList(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('LdpTLVList', None) is not None:
+                return self._properties.get('LdpTLVList')
+        return LdpTLVList(self)
 
     @property
     def Active(self):
@@ -275,6 +277,50 @@ class LdpLeafRangeV6(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, Count=None, DescriptiveName=None, LSPType=None, Name=None, NumberOfTLVs=None):
+        # type: (int, str, str, str, int) -> LdpLeafRangeV6
+        """Finds and retrieves ldpLeafRangeV6 resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve ldpLeafRangeV6 resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all ldpLeafRangeV6 resources from the server.
+
+        Args
+        ----
+        - Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group.
+        - DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but may offer more context.
+        - LSPType (str(p2MP)): LSP Type
+        - Name (str): Name of NGPF element, guaranteed to be unique in Scenario
+        - NumberOfTLVs (number): Number Of TLVs
+
+        Returns
+        -------
+        - self: This instance with matching ldpLeafRangeV6 resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of ldpLeafRangeV6 data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the ldpLeafRangeV6 resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def ActivateLeafRange(self, *args, **kwargs):
         # type: (*Any, **Any) -> Union[List[str], None]
         """Executes the activateLeafRange operation on the server.
