@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class LearnedInfoUpdate(Base):
@@ -52,10 +54,10 @@ class LearnedInfoUpdate(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.learnedinfo.pcebasicrsvpsynclspupdateparams_8eebf36e958239643e818ec82c070a9d import PceBasicRsvpSyncLspUpdateParams
-        if self._properties.get('PceBasicRsvpSyncLspUpdateParams', None) is not None:
-            return self._properties.get('PceBasicRsvpSyncLspUpdateParams')
-        else:
-            return PceBasicRsvpSyncLspUpdateParams(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('PceBasicRsvpSyncLspUpdateParams', None) is not None:
+                return self._properties.get('PceBasicRsvpSyncLspUpdateParams')
+        return PceBasicRsvpSyncLspUpdateParams(self)
 
     @property
     def PceBasicSrSyncLspUpdateParams(self):
@@ -69,10 +71,10 @@ class LearnedInfoUpdate(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.learnedinfo.pcebasicsrsynclspupdateparams_e224da984d79f6f4694b7fe51cfdca2e import PceBasicSrSyncLspUpdateParams
-        if self._properties.get('PceBasicSrSyncLspUpdateParams', None) is not None:
-            return self._properties.get('PceBasicSrSyncLspUpdateParams')
-        else:
-            return PceBasicSrSyncLspUpdateParams(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('PceBasicSrSyncLspUpdateParams', None) is not None:
+                return self._properties.get('PceBasicSrSyncLspUpdateParams')
+        return PceBasicSrSyncLspUpdateParams(self)
 
     @property
     def PceBasicSrv6SyncLspUpdateParams(self):
@@ -86,10 +88,10 @@ class LearnedInfoUpdate(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.learnedinfo.pcebasicsrv6synclspupdateparams_f8b23c23c5f697c906745f450fa4928e import PceBasicSrv6SyncLspUpdateParams
-        if self._properties.get('PceBasicSrv6SyncLspUpdateParams', None) is not None:
-            return self._properties.get('PceBasicSrv6SyncLspUpdateParams')
-        else:
-            return PceBasicSrv6SyncLspUpdateParams(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('PceBasicSrv6SyncLspUpdateParams', None) is not None:
+                return self._properties.get('PceBasicSrv6SyncLspUpdateParams')
+        return PceBasicSrv6SyncLspUpdateParams(self)
 
     @property
     def PceDetailedRsvpSyncLspUpdateParams(self):
@@ -103,10 +105,10 @@ class LearnedInfoUpdate(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.learnedinfo.pcedetailedrsvpsynclspupdateparams_e9ce5c06b7306f8f1557d3a9a0d44c61 import PceDetailedRsvpSyncLspUpdateParams
-        if self._properties.get('PceDetailedRsvpSyncLspUpdateParams', None) is not None:
-            return self._properties.get('PceDetailedRsvpSyncLspUpdateParams')
-        else:
-            return PceDetailedRsvpSyncLspUpdateParams(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('PceDetailedRsvpSyncLspUpdateParams', None) is not None:
+                return self._properties.get('PceDetailedRsvpSyncLspUpdateParams')
+        return PceDetailedRsvpSyncLspUpdateParams(self)
 
     @property
     def PceDetailedSrSyncLspUpdateParams(self):
@@ -120,10 +122,10 @@ class LearnedInfoUpdate(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.learnedinfo.pcedetailedsrsynclspupdateparams_48855195a8f4f4b7a77d8bd5ab97cf25 import PceDetailedSrSyncLspUpdateParams
-        if self._properties.get('PceDetailedSrSyncLspUpdateParams', None) is not None:
-            return self._properties.get('PceDetailedSrSyncLspUpdateParams')
-        else:
-            return PceDetailedSrSyncLspUpdateParams(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('PceDetailedSrSyncLspUpdateParams', None) is not None:
+                return self._properties.get('PceDetailedSrSyncLspUpdateParams')
+        return PceDetailedSrSyncLspUpdateParams(self)
 
     @property
     def PceDetailedSrv6SyncLspUpdateParams(self):
@@ -137,10 +139,10 @@ class LearnedInfoUpdate(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.learnedinfo.pcedetailedsrv6synclspupdateparams_e418ef8ea23a19f0617af42b48dee0f9 import PceDetailedSrv6SyncLspUpdateParams
-        if self._properties.get('PceDetailedSrv6SyncLspUpdateParams', None) is not None:
-            return self._properties.get('PceDetailedSrv6SyncLspUpdateParams')
-        else:
-            return PceDetailedSrv6SyncLspUpdateParams(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('PceDetailedSrv6SyncLspUpdateParams', None) is not None:
+                return self._properties.get('PceDetailedSrv6SyncLspUpdateParams')
+        return PceDetailedSrv6SyncLspUpdateParams(self)
 
     def add(self):
         """Adds a new learnedInfoUpdate resource on the json, only valid with config assistant
