@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class MldMcastIPv6GroupList(Base):
@@ -61,10 +63,10 @@ class MldMcastIPv6GroupList(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.mlducastipv6sourcelist_d83ad2fbae6376e2b6cb9b364249dbb9 import MldUcastIPv6SourceList
-        if self._properties.get('MldUcastIPv6SourceList', None) is not None:
-            return self._properties.get('MldUcastIPv6SourceList')
-        else:
-            return MldUcastIPv6SourceList(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('MldUcastIPv6SourceList', None) is not None:
+                return self._properties.get('MldUcastIPv6SourceList')
+        return MldUcastIPv6SourceList(self)._select()
 
     @property
     def Tag(self):
@@ -78,10 +80,10 @@ class MldMcastIPv6GroupList(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tag_e30f24de79247381d4dfd423b2f6986d import Tag
-        if self._properties.get('Tag', None) is not None:
-            return self._properties.get('Tag')
-        else:
-            return Tag(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Tag', None) is not None:
+                return self._properties.get('Tag')
+        return Tag(self)
 
     @property
     def Active(self):
@@ -214,6 +216,50 @@ class MldMcastIPv6GroupList(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, Count=None, DescriptiveName=None, Name=None, NoOfSrcRanges=None, State=None):
+        # type: (int, str, str, int, List[str]) -> MldMcastIPv6GroupList
+        """Finds and retrieves mldMcastIPv6GroupList resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve mldMcastIPv6GroupList resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all mldMcastIPv6GroupList resources from the server.
+
+        Args
+        ----
+        - Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group.
+        - DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but may offer more context.
+        - Name (str): Name of NGPF element, guaranteed to be unique in Scenario
+        - NoOfSrcRanges (number): Sources per Multicast Group (multiplier)
+        - State (list(str[iptv | joined | notJoined | notStarted])): Indicates the state of the groups in the range
+
+        Returns
+        -------
+        - self: This instance with matching mldMcastIPv6GroupList resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of mldMcastIPv6GroupList data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the mldMcastIPv6GroupList resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def Join(self, *args, **kwargs):
         # type: (*Any, **Any) -> Union[List[str], None]
         """Executes the join operation on the server.
