@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class MsrpListener(Base):
@@ -76,10 +78,10 @@ class MsrpListener(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.learnedinfo.learnedinfo_ff4d5e5643a63bccb40b6cf64fc58100 import LearnedInfo
-        if self._properties.get('LearnedInfo', None) is not None:
-            return self._properties.get('LearnedInfo')
-        else:
-            return LearnedInfo(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('LearnedInfo', None) is not None:
+                return self._properties.get('LearnedInfo')
+        return LearnedInfo(self)
 
     @property
     def MsrpListenerDomains(self):
@@ -93,10 +95,10 @@ class MsrpListener(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.msrplistenerdomains_f2fe387dee9561ca08fc00cc9bf60ef4 import MsrpListenerDomains
-        if self._properties.get('MsrpListenerDomains', None) is not None:
-            return self._properties.get('MsrpListenerDomains')
-        else:
-            return MsrpListenerDomains(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('MsrpListenerDomains', None) is not None:
+                return self._properties.get('MsrpListenerDomains')
+        return MsrpListenerDomains(self)._select()
 
     @property
     def SubscribedStreams(self):
@@ -110,10 +112,10 @@ class MsrpListener(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.subscribedstreams_b01da202c4f5221aa9094d86a288d1bd import SubscribedStreams
-        if self._properties.get('SubscribedStreams', None) is not None:
-            return self._properties.get('SubscribedStreams')
-        else:
-            return SubscribedStreams(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('SubscribedStreams', None) is not None:
+                return self._properties.get('SubscribedStreams')
+        return SubscribedStreams(self)._select()
 
     @property
     def Active(self):
