@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class NetworkGroup(Base):
@@ -60,10 +62,10 @@ class NetworkGroup(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.bgpiprouteproperty_ffd9071ae88c6283e9f54ec948882405 import BgpIPRouteProperty
-        if self._properties.get('BgpIPRouteProperty', None) is not None:
-            return self._properties.get('BgpIPRouteProperty')
-        else:
-            return BgpIPRouteProperty(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('BgpIPRouteProperty', None) is not None:
+                return self._properties.get('BgpIPRouteProperty')
+        return BgpIPRouteProperty(self)
 
     @property
     def BgpL3VpnRouteProperty(self):
@@ -77,10 +79,10 @@ class NetworkGroup(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.bgpl3vpnrouteproperty_3b5e18e475abdb9b6f2bf410d51d886a import BgpL3VpnRouteProperty
-        if self._properties.get('BgpL3VpnRouteProperty', None) is not None:
-            return self._properties.get('BgpL3VpnRouteProperty')
-        else:
-            return BgpL3VpnRouteProperty(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('BgpL3VpnRouteProperty', None) is not None:
+                return self._properties.get('BgpL3VpnRouteProperty')
+        return BgpL3VpnRouteProperty(self)
 
     @property
     def BgpMVpnReceiverSitesIpv4(self):
@@ -94,10 +96,10 @@ class NetworkGroup(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.bgpmvpnreceiversitesipv4_279b1194a64614140f00d08a876cb61b import BgpMVpnReceiverSitesIpv4
-        if self._properties.get('BgpMVpnReceiverSitesIpv4', None) is not None:
-            return self._properties.get('BgpMVpnReceiverSitesIpv4')
-        else:
-            return BgpMVpnReceiverSitesIpv4(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('BgpMVpnReceiverSitesIpv4', None) is not None:
+                return self._properties.get('BgpMVpnReceiverSitesIpv4')
+        return BgpMVpnReceiverSitesIpv4(self)
 
     @property
     def BgpMVpnReceiverSitesIpv6(self):
@@ -111,10 +113,10 @@ class NetworkGroup(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.bgpmvpnreceiversitesipv6_49c886be42acc1f3fc70df1023ccb0bd import BgpMVpnReceiverSitesIpv6
-        if self._properties.get('BgpMVpnReceiverSitesIpv6', None) is not None:
-            return self._properties.get('BgpMVpnReceiverSitesIpv6')
-        else:
-            return BgpMVpnReceiverSitesIpv6(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('BgpMVpnReceiverSitesIpv6', None) is not None:
+                return self._properties.get('BgpMVpnReceiverSitesIpv6')
+        return BgpMVpnReceiverSitesIpv6(self)
 
     @property
     def BgpMVpnSenderSitesIpv4(self):
@@ -128,10 +130,10 @@ class NetworkGroup(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.bgpmvpnsendersitesipv4_4fb28863ad3595e11a7fecc4fbb6ec9d import BgpMVpnSenderSitesIpv4
-        if self._properties.get('BgpMVpnSenderSitesIpv4', None) is not None:
-            return self._properties.get('BgpMVpnSenderSitesIpv4')
-        else:
-            return BgpMVpnSenderSitesIpv4(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('BgpMVpnSenderSitesIpv4', None) is not None:
+                return self._properties.get('BgpMVpnSenderSitesIpv4')
+        return BgpMVpnSenderSitesIpv4(self)
 
     @property
     def BgpMVpnSenderSitesIpv6(self):
@@ -145,10 +147,10 @@ class NetworkGroup(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.bgpmvpnsendersitesipv6_3217a8473cfbb135fc2545010c09ffb6 import BgpMVpnSenderSitesIpv6
-        if self._properties.get('BgpMVpnSenderSitesIpv6', None) is not None:
-            return self._properties.get('BgpMVpnSenderSitesIpv6')
-        else:
-            return BgpMVpnSenderSitesIpv6(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('BgpMVpnSenderSitesIpv6', None) is not None:
+                return self._properties.get('BgpMVpnSenderSitesIpv6')
+        return BgpMVpnSenderSitesIpv6(self)
 
     @property
     def BgpV6IPRouteProperty(self):
@@ -162,10 +164,10 @@ class NetworkGroup(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.bgpv6iprouteproperty_3bc5aff598784532c6b5ff0b601d2985 import BgpV6IPRouteProperty
-        if self._properties.get('BgpV6IPRouteProperty', None) is not None:
-            return self._properties.get('BgpV6IPRouteProperty')
-        else:
-            return BgpV6IPRouteProperty(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('BgpV6IPRouteProperty', None) is not None:
+                return self._properties.get('BgpV6IPRouteProperty')
+        return BgpV6IPRouteProperty(self)
 
     @property
     def BgpV6L3VpnRouteProperty(self):
@@ -179,10 +181,10 @@ class NetworkGroup(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.bgpv6l3vpnrouteproperty_15999adbfe8d61825751768ad5e0ddda import BgpV6L3VpnRouteProperty
-        if self._properties.get('BgpV6L3VpnRouteProperty', None) is not None:
-            return self._properties.get('BgpV6L3VpnRouteProperty')
-        else:
-            return BgpV6L3VpnRouteProperty(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('BgpV6L3VpnRouteProperty', None) is not None:
+                return self._properties.get('BgpV6L3VpnRouteProperty')
+        return BgpV6L3VpnRouteProperty(self)
 
     @property
     def CMacProperties(self):
@@ -196,10 +198,10 @@ class NetworkGroup(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.cmacproperties_4ac468c2f246fc5ef1a77fc3e4ebe180 import CMacProperties
-        if self._properties.get('CMacProperties', None) is not None:
-            return self._properties.get('CMacProperties')
-        else:
-            return CMacProperties(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('CMacProperties', None) is not None:
+                return self._properties.get('CMacProperties')
+        return CMacProperties(self)
 
     @property
     def DeviceGroup(self):
@@ -213,10 +215,10 @@ class NetworkGroup(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.devicegroup_fe4647b311377ec16edf5dcfe93dca09 import DeviceGroup
-        if self._properties.get('DeviceGroup', None) is not None:
-            return self._properties.get('DeviceGroup')
-        else:
-            return DeviceGroup(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('DeviceGroup', None) is not None:
+                return self._properties.get('DeviceGroup')
+        return DeviceGroup(self)
 
     @property
     def DslPools(self):
@@ -230,10 +232,10 @@ class NetworkGroup(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.dslpools_d9b929e10c822a015fb7026b5bad393a import DslPools
-        if self._properties.get('DslPools', None) is not None:
-            return self._properties.get('DslPools')
-        else:
-            return DslPools(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('DslPools', None) is not None:
+                return self._properties.get('DslPools')
+        return DslPools(self)
 
     @property
     def ECpriReRadioChannelsOrUsers(self):
@@ -247,10 +249,10 @@ class NetworkGroup(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ecprireradiochannelsorusers_d1f6861b47ba784e3298939a333f12b9 import ECpriReRadioChannelsOrUsers
-        if self._properties.get('ECpriReRadioChannelsOrUsers', None) is not None:
-            return self._properties.get('ECpriReRadioChannelsOrUsers')
-        else:
-            return ECpriReRadioChannelsOrUsers(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('ECpriReRadioChannelsOrUsers', None) is not None:
+                return self._properties.get('ECpriReRadioChannelsOrUsers')
+        return ECpriReRadioChannelsOrUsers(self)
 
     @property
     def ECpriRecRadioChannelsOrUsers(self):
@@ -264,10 +266,10 @@ class NetworkGroup(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ecprirecradiochannelsorusers_5814e34000b9bdc960142e49f7af3c67 import ECpriRecRadioChannelsOrUsers
-        if self._properties.get('ECpriRecRadioChannelsOrUsers', None) is not None:
-            return self._properties.get('ECpriRecRadioChannelsOrUsers')
-        else:
-            return ECpriRecRadioChannelsOrUsers(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('ECpriRecRadioChannelsOrUsers', None) is not None:
+                return self._properties.get('ECpriRecRadioChannelsOrUsers')
+        return ECpriRecRadioChannelsOrUsers(self)
 
     @property
     def EvpnIPv4PrefixRange(self):
@@ -281,10 +283,10 @@ class NetworkGroup(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.evpnipv4prefixrange_79e14e1ab070701ebf4eb586cecc565f import EvpnIPv4PrefixRange
-        if self._properties.get('EvpnIPv4PrefixRange', None) is not None:
-            return self._properties.get('EvpnIPv4PrefixRange')
-        else:
-            return EvpnIPv4PrefixRange(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('EvpnIPv4PrefixRange', None) is not None:
+                return self._properties.get('EvpnIPv4PrefixRange')
+        return EvpnIPv4PrefixRange(self)
 
     @property
     def EvpnIPv6PrefixRange(self):
@@ -298,10 +300,27 @@ class NetworkGroup(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.evpnipv6prefixrange_f8dd80c93700c982de65324fe6552b86 import EvpnIPv6PrefixRange
-        if self._properties.get('EvpnIPv6PrefixRange', None) is not None:
-            return self._properties.get('EvpnIPv6PrefixRange')
-        else:
-            return EvpnIPv6PrefixRange(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('EvpnIPv6PrefixRange', None) is not None:
+                return self._properties.get('EvpnIPv6PrefixRange')
+        return EvpnIPv6PrefixRange(self)
+
+    @property
+    def GRIBIIpv4Entry(self):
+        """
+        Returns
+        -------
+        - obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.gribiipv4entry_ed5330eae91aea3aecb945c3eda32ad4.GRIBIIpv4Entry): An instance of the GRIBIIpv4Entry class
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.gribiipv4entry_ed5330eae91aea3aecb945c3eda32ad4 import GRIBIIpv4Entry
+        if len(self._object_properties) > 0:
+            if self._properties.get('GRIBIIpv4Entry', None) is not None:
+                return self._properties.get('GRIBIIpv4Entry')
+        return GRIBIIpv4Entry(self)
 
     @property
     def Ipv4PrefixPools(self):
@@ -315,10 +334,10 @@ class NetworkGroup(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ipv4prefixpools_2d6f2aedde61c058965d4e1b21741352 import Ipv4PrefixPools
-        if self._properties.get('Ipv4PrefixPools', None) is not None:
-            return self._properties.get('Ipv4PrefixPools')
-        else:
-            return Ipv4PrefixPools(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Ipv4PrefixPools', None) is not None:
+                return self._properties.get('Ipv4PrefixPools')
+        return Ipv4PrefixPools(self)
 
     @property
     def Ipv6PrefixPools(self):
@@ -332,10 +351,10 @@ class NetworkGroup(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ipv6prefixpools_f83aba85ff769655b348dc60ddcb30f2 import Ipv6PrefixPools
-        if self._properties.get('Ipv6PrefixPools', None) is not None:
-            return self._properties.get('Ipv6PrefixPools')
-        else:
-            return Ipv6PrefixPools(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Ipv6PrefixPools', None) is not None:
+                return self._properties.get('Ipv6PrefixPools')
+        return Ipv6PrefixPools(self)
 
     @property
     def IsisL3RouteProperty(self):
@@ -349,10 +368,10 @@ class NetworkGroup(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisl3routeproperty_b92337ebc659bd40bd9c30fab98749e7 import IsisL3RouteProperty
-        if self._properties.get('IsisL3RouteProperty', None) is not None:
-            return self._properties.get('IsisL3RouteProperty')
-        else:
-            return IsisL3RouteProperty(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('IsisL3RouteProperty', None) is not None:
+                return self._properties.get('IsisL3RouteProperty')
+        return IsisL3RouteProperty(self)
 
     @property
     def IsisSpbMacCloudConfig(self):
@@ -366,10 +385,10 @@ class NetworkGroup(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisspbmaccloudconfig_791b0bf61c8f6877cabfa2621478ab8a import IsisSpbMacCloudConfig
-        if self._properties.get('IsisSpbMacCloudConfig', None) is not None:
-            return self._properties.get('IsisSpbMacCloudConfig')
-        else:
-            return IsisSpbMacCloudConfig(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('IsisSpbMacCloudConfig', None) is not None:
+                return self._properties.get('IsisSpbMacCloudConfig')
+        return IsisSpbMacCloudConfig(self)
 
     @property
     def IsisTrillUCastMacConfig(self):
@@ -383,10 +402,10 @@ class NetworkGroup(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isistrillucastmacconfig_a91c5b3e28b2bee04ff08d2e22fad1e2 import IsisTrillUCastMacConfig
-        if self._properties.get('IsisTrillUCastMacConfig', None) is not None:
-            return self._properties.get('IsisTrillUCastMacConfig')
-        else:
-            return IsisTrillUCastMacConfig(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('IsisTrillUCastMacConfig', None) is not None:
+                return self._properties.get('IsisTrillUCastMacConfig')
+        return IsisTrillUCastMacConfig(self)
 
     @property
     def LdpFECProperty(self):
@@ -400,10 +419,10 @@ class NetworkGroup(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ldpfecproperty_9d07999903dc2acadf9a2f44f8a94399 import LdpFECProperty
-        if self._properties.get('LdpFECProperty', None) is not None:
-            return self._properties.get('LdpFECProperty')
-        else:
-            return LdpFECProperty(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('LdpFECProperty', None) is not None:
+                return self._properties.get('LdpFECProperty')
+        return LdpFECProperty(self)
 
     @property
     def LdpIpv6FECProperty(self):
@@ -417,10 +436,10 @@ class NetworkGroup(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ldpipv6fecproperty_408cfe80a37623da202d7739fba9b830 import LdpIpv6FECProperty
-        if self._properties.get('LdpIpv6FECProperty', None) is not None:
-            return self._properties.get('LdpIpv6FECProperty')
-        else:
-            return LdpIpv6FECProperty(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('LdpIpv6FECProperty', None) is not None:
+                return self._properties.get('LdpIpv6FECProperty')
+        return LdpIpv6FECProperty(self)
 
     @property
     def MacPools(self):
@@ -434,10 +453,10 @@ class NetworkGroup(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.macpools_414597218f17eaa9c882bf703e2d0bdd import MacPools
-        if self._properties.get('MacPools', None) is not None:
-            return self._properties.get('MacPools')
-        else:
-            return MacPools(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('MacPools', None) is not None:
+                return self._properties.get('MacPools')
+        return MacPools(self)
 
     @property
     def NetworkGroup(self):
@@ -451,10 +470,10 @@ class NetworkGroup(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.networkgroup_4a63874e791827c3a0361c2d201dbc0c import NetworkGroup
-        if self._properties.get('NetworkGroup', None) is not None:
-            return self._properties.get('NetworkGroup')
-        else:
-            return NetworkGroup(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('NetworkGroup', None) is not None:
+                return self._properties.get('NetworkGroup')
+        return NetworkGroup(self)
 
     @property
     def NetworkRangeInfo(self):
@@ -468,10 +487,10 @@ class NetworkGroup(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.networkrangeinfo_cbb1e7fa358c353ee8fd62246a36a824 import NetworkRangeInfo
-        if self._properties.get('NetworkRangeInfo', None) is not None:
-            return self._properties.get('NetworkRangeInfo')
-        else:
-            return NetworkRangeInfo(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('NetworkRangeInfo', None) is not None:
+                return self._properties.get('NetworkRangeInfo')
+        return NetworkRangeInfo(self)
 
     @property
     def NetworkTopology(self):
@@ -485,10 +504,10 @@ class NetworkGroup(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.networktopology_657b9792feb17675a34c183046aa9924 import NetworkTopology
-        if self._properties.get('NetworkTopology', None) is not None:
-            return self._properties.get('NetworkTopology')
-        else:
-            return NetworkTopology(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('NetworkTopology', None) is not None:
+                return self._properties.get('NetworkTopology')
+        return NetworkTopology(self)
 
     @property
     def OspfRouteProperty(self):
@@ -502,10 +521,10 @@ class NetworkGroup(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ospfrouteproperty_d69371739e1874a63feb0c8493c3f052 import OspfRouteProperty
-        if self._properties.get('OspfRouteProperty', None) is not None:
-            return self._properties.get('OspfRouteProperty')
-        else:
-            return OspfRouteProperty(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('OspfRouteProperty', None) is not None:
+                return self._properties.get('OspfRouteProperty')
+        return OspfRouteProperty(self)
 
     @property
     def Ospfv3RouteProperty(self):
@@ -519,10 +538,10 @@ class NetworkGroup(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ospfv3routeproperty_daf6d024b6ece255d2d043618b13bae5 import Ospfv3RouteProperty
-        if self._properties.get('Ospfv3RouteProperty', None) is not None:
-            return self._properties.get('Ospfv3RouteProperty')
-        else:
-            return Ospfv3RouteProperty(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Ospfv3RouteProperty', None) is not None:
+                return self._properties.get('Ospfv3RouteProperty')
+        return Ospfv3RouteProperty(self)
 
     @property
     def Count(self):
