@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class OFSwitchChannel(Base):
@@ -71,10 +73,10 @@ class OFSwitchChannel(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.auxiliaryconnectionlist_00191c1165a6248dea286f67cd56938f import AuxiliaryConnectionList
-        if self._properties.get('AuxiliaryConnectionList', None) is not None:
-            return self._properties.get('AuxiliaryConnectionList')
-        else:
-            return AuxiliaryConnectionList(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('AuxiliaryConnectionList', None) is not None:
+                return self._properties.get('AuxiliaryConnectionList')
+        return AuxiliaryConnectionList(self)
 
     @property
     def Active(self):
