@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class OfSwitchPorts(Base):
@@ -78,10 +80,10 @@ class OfSwitchPorts(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ofswitchqueues_9037a6161291f813628ddfbefe3df8ed import OfSwitchQueues
-        if self._properties.get('OfSwitchQueues', None) is not None:
-            return self._properties.get('OfSwitchQueues')
-        else:
-            return OfSwitchQueues(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('OfSwitchQueues', None) is not None:
+                return self._properties.get('OfSwitchQueues')
+        return OfSwitchQueues(self)._select()
 
     @property
     def Active(self):
@@ -400,6 +402,51 @@ class OfSwitchPorts(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, Count=None, CurrentConnectionType=None, DescriptiveName=None, Name=None, NumQueueRange=None, ParentSwitch=None):
+        # type: (int, List[str], str, str, int, str) -> OfSwitchPorts
+        """Finds and retrieves ofSwitchPorts resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve ofSwitchPorts resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all ofSwitchPorts resources from the server.
+
+        Args
+        ----
+        - Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group.
+        - CurrentConnectionType (list(str[auto | externalSwitch | host | internalSwitch | noConnection])): Port Type calculated based on host topology assigned and forced type.
+        - DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but may offer more context.
+        - Name (str): Name of NGPF element, guaranteed to be unique in Scenario
+        - NumQueueRange (number): Specify the number of Queue ranges to be configured for this switch port
+        - ParentSwitch (str): Parent Switch Name
+
+        Returns
+        -------
+        - self: This instance with matching ofSwitchPorts resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of ofSwitchPorts data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the ofSwitchPorts resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def SimulatePortUpDown(self, *args, **kwargs):
         # type: (*Any, **Any) -> Union[List[str], None]
         """Executes the simulatePortUpDown operation on the server.
