@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Ospfv3(Base):
@@ -110,10 +112,10 @@ class Ospfv3(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.connector_d0d942810e4010add7642d3914a1f29b import Connector
-        if self._properties.get('Connector', None) is not None:
-            return self._properties.get('Connector')
-        else:
-            return Connector(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Connector', None) is not None:
+                return self._properties.get('Connector')
+        return Connector(self)
 
     @property
     def LearnedInfo(self):
@@ -127,10 +129,10 @@ class Ospfv3(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.learnedinfo.learnedinfo_ff4d5e5643a63bccb40b6cf64fc58100 import LearnedInfo
-        if self._properties.get('LearnedInfo', None) is not None:
-            return self._properties.get('LearnedInfo')
-        else:
-            return LearnedInfo(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('LearnedInfo', None) is not None:
+                return self._properties.get('LearnedInfo')
+        return LearnedInfo(self)
 
     @property
     def Ospfv3SRv6AdjSIDList(self):
@@ -144,10 +146,10 @@ class Ospfv3(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ospfv3srv6adjsidlist_bbaf05c92b116fc5c4157a7367085df2 import Ospfv3SRv6AdjSIDList
-        if self._properties.get('Ospfv3SRv6AdjSIDList', None) is not None:
-            return self._properties.get('Ospfv3SRv6AdjSIDList')
-        else:
-            return Ospfv3SRv6AdjSIDList(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Ospfv3SRv6AdjSIDList', None) is not None:
+                return self._properties.get('Ospfv3SRv6AdjSIDList')
+        return Ospfv3SRv6AdjSIDList(self)._select()
 
     @property
     def Active(self):
