@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Ovsdbserver(Base):
@@ -75,10 +77,10 @@ class Ovsdbserver(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.manager_c6443684a3a8badebe021783a46d1b90 import Manager
-        if self._properties.get('Manager', None) is not None:
-            return self._properties.get('Manager')
-        else:
-            return Manager(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Manager', None) is not None:
+                return self._properties.get('Manager')
+        return Manager(self)._select()
 
     @property
     def ConnectedVia(self):
