@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class PseudoRoutesSid(Base):
@@ -259,6 +261,50 @@ class PseudoRoutesSid(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, Count=None, DescriptiveName=None, LocalSystemID=None, Name=None, NetworkAddress=None):
+        # type: (int, str, List[str], str, List[str]) -> PseudoRoutesSid
+        """Finds and retrieves pseudoRoutesSid resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve pseudoRoutesSid resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all pseudoRoutesSid resources from the server.
+
+        Args
+        ----
+        - Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group.
+        - DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but may offer more context.
+        - LocalSystemID (list(str)): System ID
+        - Name (str): Name of NGPF element, guaranteed to be unique in Scenario
+        - NetworkAddress (list(str)): Address
+
+        Returns
+        -------
+        - self: This instance with matching pseudoRoutesSid resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of pseudoRoutesSid data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the pseudoRoutesSid resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def get_device_ids(self, PortNames=None, Active=None, Algorithm=None, ConfigureSIDIndexLabel=None, EnableFapm=None, FapmMetric=None, Ipv4EFlag=None, Ipv4LFlag=None, Ipv4NFlag=None, Ipv4PFlag=None, Ipv4RFlag=None, Ipv4VFlag=None, SIDIndexLabel=None):
         """Base class infrastructure that gets a list of pseudoRoutesSid device ids encapsulated by this object.
 
