@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class SpbSimEdgeBaseVidList(Base):
@@ -61,10 +63,10 @@ class SpbSimEdgeBaseVidList(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.spbsimedgeisidlist_cfeb124762b8e4653da4ea2e084e78c8 import SpbSimEdgeIsidList
-        if self._properties.get('SpbSimEdgeIsidList', None) is not None:
-            return self._properties.get('SpbSimEdgeIsidList')
-        else:
-            return SpbSimEdgeIsidList(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('SpbSimEdgeIsidList', None) is not None:
+                return self._properties.get('SpbSimEdgeIsidList')
+        return SpbSimEdgeIsidList(self)._select()
 
     @property
     def Active(self):
@@ -198,6 +200,49 @@ class SpbSimEdgeBaseVidList(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, Count=None, DescriptiveName=None, IsidCount=None, Name=None):
+        # type: (int, str, int, str) -> SpbSimEdgeBaseVidList
+        """Finds and retrieves spbSimEdgeBaseVidList resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve spbSimEdgeBaseVidList resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all spbSimEdgeBaseVidList resources from the server.
+
+        Args
+        ----
+        - Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group.
+        - DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but may offer more context.
+        - IsidCount (number): ISID Count(multiplier)
+        - Name (str): Name of NGPF element, guaranteed to be unique in Scenario
+
+        Returns
+        -------
+        - self: This instance with matching spbSimEdgeBaseVidList resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of spbSimEdgeBaseVidList data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the spbSimEdgeBaseVidList resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def get_device_ids(self, PortNames=None, Active=None, BaseVid=None, BaseVlanPriority=None, BvlanTpid=None, EctAlgorithm=None, UseFlagBit=None):
         """Base class infrastructure that gets a list of spbSimEdgeBaseVidList device ids encapsulated by this object.
 
