@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class SpbSimEdgeTopologyList(Base):
@@ -62,10 +64,10 @@ class SpbSimEdgeTopologyList(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.spbsimedgebasevidlist_166a7ab8274498ee804810aa449de276 import SpbSimEdgeBaseVidList
-        if self._properties.get('SpbSimEdgeBaseVidList', None) is not None:
-            return self._properties.get('SpbSimEdgeBaseVidList')
-        else:
-            return SpbSimEdgeBaseVidList(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('SpbSimEdgeBaseVidList', None) is not None:
+                return self._properties.get('SpbSimEdgeBaseVidList')
+        return SpbSimEdgeBaseVidList(self)._select()
 
     @property
     def Active(self):
@@ -205,6 +207,49 @@ class SpbSimEdgeTopologyList(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, BaseVIDCount=None, Count=None, DescriptiveName=None, Name=None):
+        # type: (int, int, str, str) -> SpbSimEdgeTopologyList
+        """Finds and retrieves spbSimEdgeTopologyList resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve spbSimEdgeTopologyList resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all spbSimEdgeTopologyList resources from the server.
+
+        Args
+        ----
+        - BaseVIDCount (number): Base VID Count(multiplier)
+        - Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group.
+        - DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but may offer more context.
+        - Name (str): Name of NGPF element, guaranteed to be unique in Scenario
+
+        Returns
+        -------
+        - self: This instance with matching spbSimEdgeTopologyList resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of spbSimEdgeTopologyList data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the spbSimEdgeTopologyList resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def get_device_ids(self, PortNames=None, Active=None, CistExternalRootCost=None, CistRootId=None, NumberOfPorts=None, PortIdentifier=None, TopologyId=None, Vbit=None):
         """Base class infrastructure that gets a list of spbSimEdgeTopologyList device ids encapsulated by this object.
 
