@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class StopCcmSimulatedMpParams(Base):
@@ -39,6 +41,41 @@ class StopCcmSimulatedMpParams(Base):
     def __init__(self, parent, list_op=False):
         super(StopCcmSimulatedMpParams, self).__init__(parent, list_op)
 
+    def find(self):
+        """Finds and retrieves stopCcmSimulatedMpParams resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve stopCcmSimulatedMpParams resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all stopCcmSimulatedMpParams resources from the server.
+
+        Returns
+        -------
+        - self: This instance with matching stopCcmSimulatedMpParams resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of stopCcmSimulatedMpParams data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the stopCcmSimulatedMpParams resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def StopCcmSimulatedMp(self, *args, **kwargs):
         # type: (*Any, **Any) -> None
         """Executes the stopCcmSimulatedMp operation on the server.
