@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Tables(Base):
@@ -61,10 +63,10 @@ class Tables(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.flowset_4668cc7c02c6c6c6cb9975c2ed2dbda5 import FlowSet
-        if self._properties.get('FlowSet', None) is not None:
-            return self._properties.get('FlowSet')
-        else:
-            return FlowSet(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('FlowSet', None) is not None:
+                return self._properties.get('FlowSet')
+        return FlowSet(self)
 
     @property
     def Active(self):
