@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Topology(Base):
@@ -64,10 +66,10 @@ class Topology(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.devicegroup_fe4647b311377ec16edf5dcfe93dca09 import DeviceGroup
-        if self._properties.get('DeviceGroup', None) is not None:
-            return self._properties.get('DeviceGroup')
-        else:
-            return DeviceGroup(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('DeviceGroup', None) is not None:
+                return self._properties.get('DeviceGroup')
+        return DeviceGroup(self)
 
     @property
     def DescriptiveName(self):
