@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class AppLibFlow(Base):
@@ -60,10 +62,10 @@ class AppLibFlow(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.trafficitem.applibprofile.applibflow.connection.connection import Connection
-        if self._properties.get('Connection', None) is not None:
-            return self._properties.get('Connection')
-        else:
-            return Connection(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Connection', None) is not None:
+                return self._properties.get('Connection')
+        return Connection(self)
 
     @property
     def Parameter(self):
@@ -77,10 +79,10 @@ class AppLibFlow(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.trafficitem.applibprofile.applibflow.parameter.parameter import Parameter
-        if self._properties.get('Parameter', None) is not None:
-            return self._properties.get('Parameter')
-        else:
-            return Parameter(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Parameter', None) is not None:
+                return self._properties.get('Parameter')
+        return Parameter(self)
 
     @property
     def ConfigId(self):
@@ -138,7 +140,7 @@ class AppLibFlow(Base):
         """
         Returns
         -------
-        - str: the name of the Flow.
+        - str: The name of the Flow.
         """
         return self._get_attribute(self._SDM_ATT_MAP['Name'])
 
@@ -213,7 +215,7 @@ class AppLibFlow(Base):
         - Description (str): Brief description of what the flow does.
         - FlowId (str): The identifier of the flow.
         - FlowSize (number): The size of the flow in bytes.
-        - Name (str): the name of the Flow.
+        - Name (str): The name of the Flow.
         - Parameters (list(str)): Array containing configurable parameters per flow.
         - Percentage (number): The amount of traffic generated for this flows.
 
