@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class FramePayload(Base):
@@ -63,7 +65,7 @@ class FramePayload(Base):
         """
         Returns
         -------
-        - bool: If true, Custom Pattern is repeated.
+        - bool: f true, Custom Pattern is repeated.
         """
         return self._get_attribute(self._SDM_ATT_MAP['CustomRepeat'])
     @CustomRepeat.setter
@@ -92,7 +94,7 @@ class FramePayload(Base):
         Args
         ----
         - CustomPattern (str): If Frame Payload type is Custom, then this attribute specifies a string in hex format.
-        - CustomRepeat (bool): If true, Custom Pattern is repeated.
+        - CustomRepeat (bool): f true, Custom Pattern is repeated.
         - Type (str(CJPAT | CRPAT | custom | decrementByte | decrementWord | incrementByte | incrementWord | random)): The types of Frame Payload.
 
         Raises
@@ -100,3 +102,45 @@ class FramePayload(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def find(self, CustomPattern=None, CustomRepeat=None, Type=None):
+        # type: (str, bool, str) -> FramePayload
+        """Finds and retrieves framePayload resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve framePayload resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all framePayload resources from the server.
+
+        Args
+        ----
+        - CustomPattern (str): If Frame Payload type is Custom, then this attribute specifies a string in hex format.
+        - CustomRepeat (bool): f true, Custom Pattern is repeated.
+        - Type (str(CJPAT | CRPAT | custom | decrementByte | decrementWord | incrementByte | incrementWord | random)): The types of Frame Payload.
+
+        Returns
+        -------
+        - self: This instance with matching framePayload resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of framePayload data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the framePayload resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
