@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class DhcpV6DiscoveredInfo(Base):
@@ -103,3 +105,47 @@ class DhcpV6DiscoveredInfo(Base):
         - list(dict(arg1:number,arg2:str)): (Read Only) The identifier or 'tag' for this DHCPv6 option. The DHCPv6 option value field may contain data for configuration parameter information.
         """
         return self._get_attribute(self._SDM_ATT_MAP['Tlvs'])
+
+    def find(self, IaRebindTime=None, IaRenewTime=None, Ipv6Address=None, IsDhcpV6LearnedInfoRefreshed=None, ProtocolInterface=None, Tlvs=None):
+        """Finds and retrieves dhcpV6DiscoveredInfo resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve dhcpV6DiscoveredInfo resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all dhcpV6DiscoveredInfo resources from the server.
+
+        Args
+        ----
+        - IaRebindTime (number): (Read Only) The rebind timer value (in seconds) specified by the DHCPv6 Server.
+        - IaRenewTime (number): (Read Only) The renew timer value (in seconds) specified by the DHCPv6 Server.
+        - Ipv6Address (list(str)): (Read Only) A learned/allocated IPv6 address for this interface.
+        - IsDhcpV6LearnedInfoRefreshed (bool): (Read Only) When true, the DHCPv6 discovered information is refreshed automatically.
+        - ProtocolInterface (str(None | /api/v1/sessions/1/ixnetwork/vport/.../interface)): (Read Only) An Ixia protocol interface that is negotiating with the DHCPv6 Server.
+        - Tlvs (list(dict(arg1:number,arg2:str))): (Read Only) The identifier or 'tag' for this DHCPv6 option. The DHCPv6 option value field may contain data for configuration parameter information.
+
+        Returns
+        -------
+        - self: This instance with matching dhcpV6DiscoveredInfo resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of dhcpV6DiscoveredInfo data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the dhcpV6DiscoveredInfo resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
