@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class AtlasFourHundredGigLan(Base):
@@ -67,7 +69,7 @@ class AtlasFourHundredGigLan(Base):
     }
     _SDM_ENUM_MAP = {
         'autoInstrumentation': ['endOfFrame', 'floating'],
-        'loopbackMode': ['internalLoopback', 'lineLoopback', 'none'],
+        'loopbackMode': ['none', 'lineLoopback', 'internalLoopback'],
         'sendSetsMode': ['alternate', 'typeAOnly', 'typeBOnly'],
         'speed': ['speed100g', 'speed200g', 'speed400g', 'speed50g'],
         'typeAOrderedSets': ['localFault', 'remoteFault'],
@@ -89,10 +91,10 @@ class AtlasFourHundredGigLan(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.atlasfourhundredgiglan.fcoe.fcoe import Fcoe
-        if self._properties.get('Fcoe', None) is not None:
-            return self._properties.get('Fcoe')
-        else:
-            return Fcoe(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Fcoe', None) is not None:
+                return self._properties.get('Fcoe')
+        return Fcoe(self)._select()
 
     @property
     def AutoInstrumentation(self):
@@ -100,7 +102,7 @@ class AtlasFourHundredGigLan(Base):
         """
         Returns
         -------
-        - str(endOfFrame | floating): 
+        - str(endOfFrame | floating): The auto instrumentation mode.
         """
         return self._get_attribute(self._SDM_ATT_MAP['AutoInstrumentation'])
     @AutoInstrumentation.setter
@@ -142,7 +144,7 @@ class AtlasFourHundredGigLan(Base):
         """
         Returns
         -------
-        - bool: 
+        - bool: If true, enables the portsppm.
         """
         return self._get_attribute(self._SDM_ATT_MAP['EnablePPM'])
     @EnablePPM.setter
@@ -184,7 +186,7 @@ class AtlasFourHundredGigLan(Base):
         """
         Returns
         -------
-        - bool: 
+        - bool: If true, enables the port's MAC flow control mechanisms to listen for a directed address pause message.
         """
         return self._get_attribute(self._SDM_ATT_MAP['EnabledFlowControl'])
     @EnabledFlowControl.setter
@@ -254,7 +256,7 @@ class AtlasFourHundredGigLan(Base):
         """
         Returns
         -------
-        - str: 
+        - str: The 48-bit MAC address that the port listens on for a directed pause.
         """
         return self._get_attribute(self._SDM_ATT_MAP['FlowControlDirectedAddress'])
     @FlowControlDirectedAddress.setter
@@ -376,7 +378,7 @@ class AtlasFourHundredGigLan(Base):
         """
         Returns
         -------
-        - str(internalLoopback | lineLoopback | none): 
+        - str(none | lineLoopback | internalLoopback): 
         """
         return self._get_attribute(self._SDM_ATT_MAP['LoopbackMode'])
     @LoopbackMode.setter
@@ -390,7 +392,7 @@ class AtlasFourHundredGigLan(Base):
         """
         Returns
         -------
-        - number: 
+        - number: Indicates the value that needs to be adjusted for the line transmit frequency.
         """
         return self._get_attribute(self._SDM_ATT_MAP['Ppm'])
     @Ppm.setter
@@ -488,7 +490,7 @@ class AtlasFourHundredGigLan(Base):
         """
         Returns
         -------
-        - bool: 
+        - bool: If enabled, will allow transmission of packets even if the receive link is down.
         """
         return self._get_attribute(self._SDM_ATT_MAP['TxIgnoreRxLinkFaults'])
     @TxIgnoreRxLinkFaults.setter
@@ -544,18 +546,18 @@ class AtlasFourHundredGigLan(Base):
 
         Args
         ----
-        - AutoInstrumentation (str(endOfFrame | floating)): 
+        - AutoInstrumentation (str(endOfFrame | floating)): The auto instrumentation mode.
         - BadBlocksNumber (number): 
         - EnableAutoNegotiation (bool): 
-        - EnablePPM (bool): 
+        - EnablePPM (bool): If true, enables the portsppm.
         - EnableRsFec (bool): 
         - EnableRsFecStats (bool): 
-        - EnabledFlowControl (bool): 
+        - EnabledFlowControl (bool): If true, enables the port's MAC flow control mechanisms to listen for a directed address pause message.
         - FirecodeAdvertise (bool): 
         - FirecodeForceOff (bool): 
         - FirecodeForceOn (bool): 
         - FirecodeRequest (bool): 
-        - FlowControlDirectedAddress (str): 
+        - FlowControlDirectedAddress (str): The 48-bit MAC address that the port listens on for a directed pause.
         - ForceDisableFEC (bool): 
         - GoodBlocksNumber (number): 
         - LaserOn (bool): 
@@ -563,15 +565,15 @@ class AtlasFourHundredGigLan(Base):
         - LoopContinuously (bool): 
         - LoopCountNumber (number): 
         - Loopback (bool): 
-        - LoopbackMode (str(internalLoopback | lineLoopback | none)): 
-        - Ppm (number): 
+        - LoopbackMode (str(none | lineLoopback | internalLoopback)): 
+        - Ppm (number): Indicates the value that needs to be adjusted for the line transmit frequency.
         - RsFecAdvertise (bool): 
         - RsFecForceOn (bool): 
         - RsFecRequest (bool): 
         - SendSetsMode (str(alternate | typeAOnly | typeBOnly)): 
         - Speed (str(speed100g | speed200g | speed400g | speed50g)): 
         - StartErrorInsertion (bool): 
-        - TxIgnoreRxLinkFaults (bool): 
+        - TxIgnoreRxLinkFaults (bool): If enabled, will allow transmission of packets even if the receive link is down.
         - TypeAOrderedSets (str(localFault | remoteFault)): 
         - TypeBOrderedSets (str(localFault | remoteFault)): 
         - UseANResults (bool): 
@@ -581,3 +583,74 @@ class AtlasFourHundredGigLan(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def find(self, AutoInstrumentation=None, BadBlocksNumber=None, EnableAutoNegotiation=None, EnablePPM=None, EnableRsFec=None, EnableRsFecStats=None, EnabledFlowControl=None, FirecodeAdvertise=None, FirecodeForceOff=None, FirecodeForceOn=None, FirecodeRequest=None, FlowControlDirectedAddress=None, ForceDisableFEC=None, GoodBlocksNumber=None, IeeeL1Defaults=None, LaserOn=None, LinkTraining=None, LoopContinuously=None, LoopCountNumber=None, Loopback=None, LoopbackMode=None, Ppm=None, RsFecAdvertise=None, RsFecForceOn=None, RsFecRequest=None, SendSetsMode=None, Speed=None, StartErrorInsertion=None, TxIgnoreRxLinkFaults=None, TypeAOrderedSets=None, TypeBOrderedSets=None, UseANResults=None):
+        # type: (str, int, bool, bool, bool, bool, bool, bool, bool, bool, bool, str, bool, int, bool, bool, bool, bool, int, bool, str, int, bool, bool, bool, str, str, bool, bool, str, str, bool) -> AtlasFourHundredGigLan
+        """Finds and retrieves atlasFourHundredGigLan resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve atlasFourHundredGigLan resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all atlasFourHundredGigLan resources from the server.
+
+        Args
+        ----
+        - AutoInstrumentation (str(endOfFrame | floating)): The auto instrumentation mode.
+        - BadBlocksNumber (number): 
+        - EnableAutoNegotiation (bool): 
+        - EnablePPM (bool): If true, enables the portsppm.
+        - EnableRsFec (bool): 
+        - EnableRsFecStats (bool): 
+        - EnabledFlowControl (bool): If true, enables the port's MAC flow control mechanisms to listen for a directed address pause message.
+        - FirecodeAdvertise (bool): 
+        - FirecodeForceOff (bool): 
+        - FirecodeForceOn (bool): 
+        - FirecodeRequest (bool): 
+        - FlowControlDirectedAddress (str): The 48-bit MAC address that the port listens on for a directed pause.
+        - ForceDisableFEC (bool): 
+        - GoodBlocksNumber (number): 
+        - IeeeL1Defaults (bool): 
+        - LaserOn (bool): 
+        - LinkTraining (bool): 
+        - LoopContinuously (bool): 
+        - LoopCountNumber (number): 
+        - Loopback (bool): 
+        - LoopbackMode (str(none | lineLoopback | internalLoopback)): 
+        - Ppm (number): Indicates the value that needs to be adjusted for the line transmit frequency.
+        - RsFecAdvertise (bool): 
+        - RsFecForceOn (bool): 
+        - RsFecRequest (bool): 
+        - SendSetsMode (str(alternate | typeAOnly | typeBOnly)): 
+        - Speed (str(speed100g | speed200g | speed400g | speed50g)): 
+        - StartErrorInsertion (bool): 
+        - TxIgnoreRxLinkFaults (bool): If enabled, will allow transmission of packets even if the receive link is down.
+        - TypeAOrderedSets (str(localFault | remoteFault)): 
+        - TypeBOrderedSets (str(localFault | remoteFault)): 
+        - UseANResults (bool): 
+
+        Returns
+        -------
+        - self: This instance with matching atlasFourHundredGigLan resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of atlasFourHundredGigLan data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the atlasFourHundredGigLan resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
