@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Ethernet(Base):
@@ -44,7 +46,9 @@ class Ethernet(Base):
         'MasterSlaveMode': 'masterSlaveMode',
         'Media': 'media',
         'NegotiateMasterSlave': 'negotiateMasterSlave',
+        'NegotiatePrimarySecondary': 'negotiatePrimarySecondary',
         'Ppm': 'ppm',
+        'PrimarySecondaryMode': 'primarySecondaryMode',
         'SelectedSpeeds': 'selectedSpeeds',
         'Speed': 'speed',
         'SpeedAuto': 'speedAuto',
@@ -53,6 +57,7 @@ class Ethernet(Base):
         'autoInstrumentation': ['endOfFrame', 'floating'],
         'masterSlaveMode': ['master', 'slave'],
         'media': ['copper', 'fiber', 'sgmii'],
+        'primarySecondaryMode': ['primary', 'secondary'],
         'speed': ['auto', 'speed1000', 'speed100fd', 'speed100hd', 'speed10fd', 'speed10hd'],
     }
 
@@ -71,10 +76,10 @@ class Ethernet(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.ethernet.fcoe.fcoe import Fcoe
-        if self._properties.get('Fcoe', None) is not None:
-            return self._properties.get('Fcoe')
-        else:
-            return Fcoe(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Fcoe', None) is not None:
+                return self._properties.get('Fcoe')
+        return Fcoe(self)._select()
 
     @property
     def Oam(self):
@@ -88,10 +93,10 @@ class Ethernet(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.ethernet.oam.oam import Oam
-        if self._properties.get('Oam', None) is not None:
-            return self._properties.get('Oam')
-        else:
-            return Oam(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Oam', None) is not None:
+                return self._properties.get('Oam')
+        return Oam(self)._select()
 
     @property
     def TxLane(self):
@@ -105,10 +110,10 @@ class Ethernet(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.ethernet.txlane.txlane import TxLane
-        if self._properties.get('TxLane', None) is not None:
-            return self._properties.get('TxLane')
-        else:
-            return TxLane(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('TxLane', None) is not None:
+                return self._properties.get('TxLane')
+        return TxLane(self)._select()
 
     @property
     def AutoInstrumentation(self):
@@ -188,7 +193,7 @@ class Ethernet(Base):
         """
         Returns
         -------
-        - bool: If true, enables the port's MAC flow control and mechanisms to listen for a directed address pause message.
+        - bool: If true, enables the port's MAC flow control mechanisms to listen for a directed address pause message.
         """
         return self._get_attribute(self._SDM_ATT_MAP['EnabledFlowControl'])
     @EnabledFlowControl.setter
@@ -227,7 +232,7 @@ class Ethernet(Base):
     @property
     def MasterSlaveMode(self):
         # type: () -> str
-        """
+        """DEPRECATED 
         Returns
         -------
         - str(master | slave): NOT DEFINED
@@ -255,7 +260,7 @@ class Ethernet(Base):
     @property
     def NegotiateMasterSlave(self):
         # type: () -> bool
-        """
+        """DEPRECATED 
         Returns
         -------
         - bool: NOT DEFINED
@@ -266,13 +271,27 @@ class Ethernet(Base):
         # type: (bool) -> None
         self._set_attribute(self._SDM_ATT_MAP['NegotiateMasterSlave'], value)
 
+    @property
+    def NegotiatePrimarySecondary(self):
+        # type: () -> bool
+        """
+        Returns
+        -------
+        - bool: 
+        """
+        return self._get_attribute(self._SDM_ATT_MAP['NegotiatePrimarySecondary'])
+    @NegotiatePrimarySecondary.setter
+    def NegotiatePrimarySecondary(self, value):
+        # type: (bool) -> None
+        self._set_attribute(self._SDM_ATT_MAP['NegotiatePrimarySecondary'], value)
+
     @property
     def Ppm(self):
         # type: () -> int
         """
         Returns
         -------
-        - number: Indicates the value that needs to be adjusted for the line transmit frequency
+        - number: Indicates the value that needs to be adjusted for the line transmit frequency.
         """
         return self._get_attribute(self._SDM_ATT_MAP['Ppm'])
     @Ppm.setter
@@ -280,6 +299,20 @@ class Ethernet(Base):
         # type: (int) -> None
         self._set_attribute(self._SDM_ATT_MAP['Ppm'], value)
 
+    @property
+    def PrimarySecondaryMode(self):
+        # type: () -> str
+        """
+        Returns
+        -------
+        - str(primary | secondary): 
+        """
+        return self._get_attribute(self._SDM_ATT_MAP['PrimarySecondaryMode'])
+    @PrimarySecondaryMode.setter
+    def PrimarySecondaryMode(self, value):
+        # type: (str) -> None
+        self._set_attribute(self._SDM_ATT_MAP['PrimarySecondaryMode'], value)
+
     @property
     def SelectedSpeeds(self):
         # type: () -> List[str]
@@ -322,8 +355,8 @@ class Ethernet(Base):
         # type: (List[str]) -> None
         self._set_attribute(self._SDM_ATT_MAP['SpeedAuto'], value)
 
-    def update(self, AutoInstrumentation=None, AutoNegotiate=None, EnablePPM=None, EnabledFlowControl=None, FlowControlDirectedAddress=None, Loopback=None, MasterSlaveMode=None, Media=None, NegotiateMasterSlave=None, Ppm=None, SelectedSpeeds=None, Speed=None, SpeedAuto=None):
-        # type: (str, bool, bool, bool, str, bool, str, str, bool, int, List[str], str, List[str]) -> Ethernet
+    def update(self, AutoInstrumentation=None, AutoNegotiate=None, EnablePPM=None, EnabledFlowControl=None, FlowControlDirectedAddress=None, Loopback=None, MasterSlaveMode=None, Media=None, NegotiateMasterSlave=None, NegotiatePrimarySecondary=None, Ppm=None, PrimarySecondaryMode=None, SelectedSpeeds=None, Speed=None, SpeedAuto=None):
+        # type: (str, bool, bool, bool, str, bool, str, str, bool, bool, int, str, List[str], str, List[str]) -> Ethernet
         """Updates ethernet resource on the server.
 
         Args
@@ -331,13 +364,15 @@ class Ethernet(Base):
         - AutoInstrumentation (str(endOfFrame | floating)): The auto instrumentation mode.
         - AutoNegotiate (bool): If enabled, allows autonegotiation between ports for speed and duplex operation based on the various choices. The selected capabilities are advertised during AutoNegotiation
         - EnablePPM (bool): If true, enables the portsppm.
-        - EnabledFlowControl (bool): If true, enables the port's MAC flow control and mechanisms to listen for a directed address pause message.
+        - EnabledFlowControl (bool): If true, enables the port's MAC flow control mechanisms to listen for a directed address pause message.
         - FlowControlDirectedAddress (str): The 48-bit MAC address that the port listens on for a directed pause.
         - Loopback (bool): If enabled, the port is set to internally loopback from transmit to receive.
         - MasterSlaveMode (str(master | slave)): NOT DEFINED
         - Media (str(copper | fiber | sgmii)): Available only for Ethernet cards that support this dual-PHY capability.
         - NegotiateMasterSlave (bool): NOT DEFINED
-        - Ppm (number): Indicates the value that needs to be adjusted for the line transmit frequency
+        - NegotiatePrimarySecondary (bool): 
+        - Ppm (number): Indicates the value that needs to be adjusted for the line transmit frequency.
+        - PrimarySecondaryMode (str(primary | secondary)): 
         - SelectedSpeeds (list(str[speed10fd | speed10hd | speed100fd | speed100hd | speed1000])): Which speeds are selected for the current media and AN settings.
         - Speed (str(auto | speed1000 | speed100fd | speed100hd | speed10fd | speed10hd)): The speed and duplex operation options.
         - SpeedAuto (list(str[all | speed1000 | speed100fd | speed100hd | speed10fd | speed10hd])): If selected, allows auto negotiation between ports for speed and duplex operation based on the various choices. The selected capabilities are advertised during AutoNegotiation.
@@ -347,3 +382,60 @@ class Ethernet(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def find(self, AutoInstrumentation=None, AutoNegotiate=None, AvailableSpeeds=None, CanModifySpeed=None, CanSetMultipleSpeeds=None, EnablePPM=None, EnabledFlowControl=None, FlowControlDirectedAddress=None, Loopback=None, MasterSlaveMode=None, Media=None, NegotiateMasterSlave=None, NegotiatePrimarySecondary=None, Ppm=None, PrimarySecondaryMode=None, SelectedSpeeds=None, Speed=None, SpeedAuto=None):
+        # type: (str, bool, List[str], bool, bool, bool, bool, str, bool, str, str, bool, bool, int, str, List[str], str, List[str]) -> Ethernet
+        """Finds and retrieves ethernet resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve ethernet resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all ethernet resources from the server.
+
+        Args
+        ----
+        - AutoInstrumentation (str(endOfFrame | floating)): The auto instrumentation mode.
+        - AutoNegotiate (bool): If enabled, allows autonegotiation between ports for speed and duplex operation based on the various choices. The selected capabilities are advertised during AutoNegotiation
+        - AvailableSpeeds (list(str[speed10fd | speed10hd | speed100fd | speed100hd | speed1000])): Which speeds are available for the current media and AN settings.
+        - CanModifySpeed (bool): Returns true/false depending upon if the port can change speed for the current media and AN settings.
+        - CanSetMultipleSpeeds (bool): Can this port selectmultiple speeds for the current media and AN settings.
+        - EnablePPM (bool): If true, enables the portsppm.
+        - EnabledFlowControl (bool): If true, enables the port's MAC flow control mechanisms to listen for a directed address pause message.
+        - FlowControlDirectedAddress (str): The 48-bit MAC address that the port listens on for a directed pause.
+        - Loopback (bool): If enabled, the port is set to internally loopback from transmit to receive.
+        - MasterSlaveMode (str(master | slave)): NOT DEFINED
+        - Media (str(copper | fiber | sgmii)): Available only for Ethernet cards that support this dual-PHY capability.
+        - NegotiateMasterSlave (bool): NOT DEFINED
+        - NegotiatePrimarySecondary (bool): 
+        - Ppm (number): Indicates the value that needs to be adjusted for the line transmit frequency.
+        - PrimarySecondaryMode (str(primary | secondary)): 
+        - SelectedSpeeds (list(str[speed10fd | speed10hd | speed100fd | speed100hd | speed1000])): Which speeds are selected for the current media and AN settings.
+        - Speed (str(auto | speed1000 | speed100fd | speed100hd | speed10fd | speed10hd)): The speed and duplex operation options.
+        - SpeedAuto (list(str[all | speed1000 | speed100fd | speed100hd | speed10fd | speed10hd])): If selected, allows auto negotiation between ports for speed and duplex operation based on the various choices. The selected capabilities are advertised during AutoNegotiation.
+
+        Returns
+        -------
+        - self: This instance with matching ethernet resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of ethernet data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the ethernet resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
