@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class KrakenFourHundredGigLan(Base):
@@ -71,7 +73,7 @@ class KrakenFourHundredGigLan(Base):
     }
     _SDM_ENUM_MAP = {
         'autoInstrumentation': ['endOfFrame', 'floating'],
-        'loopbackMode': ['internalLoopback', 'lineLoopback', 'none'],
+        'loopbackMode': ['none', 'lineLoopback', 'internalLoopback'],
         'sendSetsMode': ['alternate', 'typeAOnly', 'typeBOnly'],
         'speed': ['speed100g', 'speed200g', 'speed400g', 'speed50g'],
         'typeAOrderedSets': ['localFault', 'remoteFault'],
@@ -93,10 +95,10 @@ class KrakenFourHundredGigLan(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.krakenfourhundredgiglan.fcoe.fcoe import Fcoe
-        if self._properties.get('Fcoe', None) is not None:
-            return self._properties.get('Fcoe')
-        else:
-            return Fcoe(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Fcoe', None) is not None:
+                return self._properties.get('Fcoe')
+        return Fcoe(self)._select()
 
     @property
     def AutoInstrumentation(self):
@@ -214,7 +216,7 @@ class KrakenFourHundredGigLan(Base):
         """
         Returns
         -------
-        - bool: NOT DEFINED
+        - bool: If true, enables the port's MAC flow control mechanisms to listen for a directed address pause message.
         """
         return self._get_attribute(self._SDM_ATT_MAP['EnabledFlowControl'])
     @EnabledFlowControl.setter
@@ -402,7 +404,7 @@ class KrakenFourHundredGigLan(Base):
         """
         Returns
         -------
-        - str(internalLoopback | lineLoopback | none): NOT DEFINED
+        - str(none | lineLoopback | internalLoopback): NOT DEFINED
         """
         return self._get_attribute(self._SDM_ATT_MAP['LoopbackMode'])
     @LoopbackMode.setter
@@ -528,7 +530,7 @@ class KrakenFourHundredGigLan(Base):
         """
         Returns
         -------
-        - bool: NOT DEFINED
+        - bool: If enabled, will allow transmission of packets even if the receive link is down.
         """
         return self._get_attribute(self._SDM_ATT_MAP['TxIgnoreRxLinkFaults'])
     @TxIgnoreRxLinkFaults.setter
@@ -589,7 +591,7 @@ class KrakenFourHundredGigLan(Base):
         - EnablePPM (bool): If true, enables the portsppm.
         - EnableRsFec (bool): NOT DEFINED
         - EnableRsFecStats (bool): NOT DEFINED
-        - EnabledFlowControl (bool): NOT DEFINED
+        - EnabledFlowControl (bool): If true, enables the port's MAC flow control mechanisms to listen for a directed address pause message.
         - FirecodeAdvertise (bool): NOT DEFINED
         - FirecodeForceOff (bool): NOT DEFINED
         - FirecodeForceOn (bool): NOT DEFINED
@@ -601,7 +603,7 @@ class KrakenFourHundredGigLan(Base):
         - LoopContinuously (bool): NOT DEFINED
         - LoopCountNumber (number): NOT DEFINED
         - Loopback (bool): If enabled, the port is set to internally loopback from transmit to receive.
-        - LoopbackMode (str(internalLoopback | lineLoopback | none)): NOT DEFINED
+        - LoopbackMode (str(none | lineLoopback | internalLoopback)): NOT DEFINED
         - Ppm (number): Indicates the value that needs to be adjusted for the line transmit frequency.
         - RsFecAdvertise (bool): NOT DEFINED
         - RsFecForceOn (bool): NOT DEFINED
@@ -610,7 +612,7 @@ class KrakenFourHundredGigLan(Base):
         - SendSetsMode (str(alternate | typeAOnly | typeBOnly)): NOT DEFINED
         - Speed (str(speed100g | speed200g | speed400g | speed50g)): NOT DEFINED
         - StartErrorInsertion (bool): NOT DEFINED
-        - TxIgnoreRxLinkFaults (bool): NOT DEFINED
+        - TxIgnoreRxLinkFaults (bool): If enabled, will allow transmission of packets even if the receive link is down.
         - TypeAOrderedSets (str(localFault | remoteFault)): NOT DEFINED
         - TypeBOrderedSets (str(localFault | remoteFault)): NOT DEFINED
         - UseANResults (bool): NOT DEFINED
@@ -620,3 +622,78 @@ class KrakenFourHundredGigLan(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def find(self, AutoInstrumentation=None, AvailableSpeeds=None, BadBlocksNumber=None, CanModifySpeed=None, CanSetMultipleSpeeds=None, EnableAutoNegotiation=None, EnablePPM=None, EnableRsFec=None, EnableRsFecStats=None, EnabledFlowControl=None, FirecodeAdvertise=None, FirecodeForceOff=None, FirecodeForceOn=None, FirecodeRequest=None, FlowControlDirectedAddress=None, ForceDisableFEC=None, GoodBlocksNumber=None, IeeeL1Defaults=None, LaserOn=None, LinkTraining=None, LoopContinuously=None, LoopCountNumber=None, Loopback=None, LoopbackMode=None, Ppm=None, RsFecAdvertise=None, RsFecForceOn=None, RsFecRequest=None, SelectedSpeeds=None, SendSetsMode=None, Speed=None, StartErrorInsertion=None, TxIgnoreRxLinkFaults=None, TypeAOrderedSets=None, TypeBOrderedSets=None, UseANResults=None):
+        # type: (str, List[str], int, bool, bool, bool, bool, bool, bool, bool, bool, bool, bool, bool, str, bool, int, bool, bool, bool, bool, int, bool, str, int, bool, bool, bool, List[str], str, str, bool, bool, str, str, bool) -> KrakenFourHundredGigLan
+        """Finds and retrieves krakenFourHundredGigLan resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve krakenFourHundredGigLan resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all krakenFourHundredGigLan resources from the server.
+
+        Args
+        ----
+        - AutoInstrumentation (str(endOfFrame | floating)): The auto instrumentation mode.
+        - AvailableSpeeds (list(str[speed100g | speed50g | speed200g | speed400g])): Which speeds are available for the current media and AN settings.
+        - BadBlocksNumber (number): NOT DEFINED
+        - CanModifySpeed (bool): Returns true/false depending upon if the port can change speed for the current media and AN settings.
+        - CanSetMultipleSpeeds (bool): Can this port selectmultiple speeds for the current media and AN settings.
+        - EnableAutoNegotiation (bool): NOT DEFINED
+        - EnablePPM (bool): If true, enables the portsppm.
+        - EnableRsFec (bool): NOT DEFINED
+        - EnableRsFecStats (bool): NOT DEFINED
+        - EnabledFlowControl (bool): If true, enables the port's MAC flow control mechanisms to listen for a directed address pause message.
+        - FirecodeAdvertise (bool): NOT DEFINED
+        - FirecodeForceOff (bool): NOT DEFINED
+        - FirecodeForceOn (bool): NOT DEFINED
+        - FirecodeRequest (bool): NOT DEFINED
+        - FlowControlDirectedAddress (str): The 48-bit MAC address that the port listens on for a directed pause.
+        - ForceDisableFEC (bool): NOT DEFINED
+        - GoodBlocksNumber (number): NOT DEFINED
+        - IeeeL1Defaults (bool): NOT DEFINED
+        - LaserOn (bool): NOT DEFINED
+        - LinkTraining (bool): NOT DEFINED
+        - LoopContinuously (bool): NOT DEFINED
+        - LoopCountNumber (number): NOT DEFINED
+        - Loopback (bool): If enabled, the port is set to internally loopback from transmit to receive.
+        - LoopbackMode (str(none | lineLoopback | internalLoopback)): NOT DEFINED
+        - Ppm (number): Indicates the value that needs to be adjusted for the line transmit frequency.
+        - RsFecAdvertise (bool): NOT DEFINED
+        - RsFecForceOn (bool): NOT DEFINED
+        - RsFecRequest (bool): NOT DEFINED
+        - SelectedSpeeds (list(str[speed100g | speed50g | speed200g | speed400g])): Which speeds are selected for the current media and AN settings.
+        - SendSetsMode (str(alternate | typeAOnly | typeBOnly)): NOT DEFINED
+        - Speed (str(speed100g | speed200g | speed400g | speed50g)): NOT DEFINED
+        - StartErrorInsertion (bool): NOT DEFINED
+        - TxIgnoreRxLinkFaults (bool): If enabled, will allow transmission of packets even if the receive link is down.
+        - TypeAOrderedSets (str(localFault | remoteFault)): NOT DEFINED
+        - TypeBOrderedSets (str(localFault | remoteFault)): NOT DEFINED
+        - UseANResults (bool): NOT DEFINED
+
+        Returns
+        -------
+        - self: This instance with matching krakenFourHundredGigLan resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of krakenFourHundredGigLan data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the krakenFourHundredGigLan resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
