@@ -19,8 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Novus5GTenTwentyFiveGigLan(Base):
@@ -68,47 +71,62 @@ class Novus5GTenTwentyFiveGigLan(Base):
         'TypeBOrderedSets': 'typeBOrderedSets',
         'UseANResults': 'useANResults',
     }
+    _SDM_ENUM_MAP = {
+        'autoInstrumentation': ['endOfFrame', 'floating'],
+        'loopbackMode': ['none', 'lineLoopback', 'internalLoopback'],
+        'sendSetsMode': ['alternate', 'typeAOnly', 'typeBOnly'],
+        'speed': ['speed100g', 'speed10g', 'speed25g', 'speed50g'],
+        'typeAOrderedSets': ['localFault', 'remoteFault'],
+        'typeBOrderedSets': ['localFault', 'remoteFault'],
+    }
 
-    def __init__(self, parent):
-        super(Novus5GTenTwentyFiveGigLan, self).__init__(parent)
+    def __init__(self, parent, list_op=False):
+        super(Novus5GTenTwentyFiveGigLan, self).__init__(parent, list_op)
 
     @property
     def Fcoe(self):
         """
         Returns
         -------
-        - obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.ethernet.fcoe.fcoe.Fcoe): An instance of the Fcoe class
+        - obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.novus5gtentwentyfivegiglan.fcoe.fcoe.Fcoe): An instance of the Fcoe class
 
         Raises
         ------
         - ServerError: The server has encountered an uncategorized error condition
         """
-        from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.ethernet.fcoe.fcoe import Fcoe
+        from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.novus5gtentwentyfivegiglan.fcoe.fcoe import Fcoe
+        if len(self._object_properties) > 0:
+            if self._properties.get('Fcoe', None) is not None:
+                return self._properties.get('Fcoe')
         return Fcoe(self)._select()
 
     @property
     def AutoInstrumentation(self):
+        # type: () -> str
         """
         Returns
         -------
-        - str(endOfFrame | floating): 
+        - str(endOfFrame | floating): The auto instrumentation mode.
         """
         return self._get_attribute(self._SDM_ATT_MAP['AutoInstrumentation'])
     @AutoInstrumentation.setter
     def AutoInstrumentation(self, value):
+        # type: (str) -> None
         self._set_attribute(self._SDM_ATT_MAP['AutoInstrumentation'], value)
 
     @property
     def AvailableSpeeds(self):
+        # type: () -> List[str]
         """
         Returns
         -------
-        - list(str[speed100g | speed25g | speed50g | speed10g | speed40g]): Which speeds are available for the current media and AN settings.
+        - list(str[speed100g | speed25g | speed50g | speed10g]): Which speeds are available for the current media and AN settings.
         """
         return self._get_attribute(self._SDM_ATT_MAP['AvailableSpeeds'])
 
     @property
     def BadBlocksNumber(self):
+        # type: () -> int
         """
         Returns
         -------
@@ -117,10 +135,12 @@ class Novus5GTenTwentyFiveGigLan(Base):
         return self._get_attribute(self._SDM_ATT_MAP['BadBlocksNumber'])
     @BadBlocksNumber.setter
     def BadBlocksNumber(self, value):
+        # type: (int) -> None
         self._set_attribute(self._SDM_ATT_MAP['BadBlocksNumber'], value)
 
     @property
     def CanModifySpeed(self):
+        # type: () -> bool
         """
         Returns
         -------
@@ -130,6 +150,7 @@ class Novus5GTenTwentyFiveGigLan(Base):
 
     @property
     def CanSetMultipleSpeeds(self):
+        # type: () -> bool
         """
         Returns
         -------
@@ -139,6 +160,7 @@ class Novus5GTenTwentyFiveGigLan(Base):
 
     @property
     def EnableAutoNegotiation(self):
+        # type: () -> bool
         """
         Returns
         -------
@@ -147,22 +169,26 @@ class Novus5GTenTwentyFiveGigLan(Base):
         return self._get_attribute(self._SDM_ATT_MAP['EnableAutoNegotiation'])
     @EnableAutoNegotiation.setter
     def EnableAutoNegotiation(self, value):
+        # type: (bool) -> None
         self._set_attribute(self._SDM_ATT_MAP['EnableAutoNegotiation'], value)
 
     @property
     def EnablePPM(self):
+        # type: () -> bool
         """
         Returns
         -------
-        - bool: 
+        - bool: If true, enables the portsppm.
         """
         return self._get_attribute(self._SDM_ATT_MAP['EnablePPM'])
     @EnablePPM.setter
     def EnablePPM(self, value):
+        # type: (bool) -> None
         self._set_attribute(self._SDM_ATT_MAP['EnablePPM'], value)
 
     @property
     def EnableRsFec(self):
+        # type: () -> bool
         """
         Returns
         -------
@@ -171,10 +197,12 @@ class Novus5GTenTwentyFiveGigLan(Base):
         return self._get_attribute(self._SDM_ATT_MAP['EnableRsFec'])
     @EnableRsFec.setter
     def EnableRsFec(self, value):
+        # type: (bool) -> None
         self._set_attribute(self._SDM_ATT_MAP['EnableRsFec'], value)
 
     @property
     def EnableRsFecStats(self):
+        # type: () -> bool
         """
         Returns
         -------
@@ -183,22 +211,26 @@ class Novus5GTenTwentyFiveGigLan(Base):
         return self._get_attribute(self._SDM_ATT_MAP['EnableRsFecStats'])
     @EnableRsFecStats.setter
     def EnableRsFecStats(self, value):
+        # type: (bool) -> None
         self._set_attribute(self._SDM_ATT_MAP['EnableRsFecStats'], value)
 
     @property
     def EnabledFlowControl(self):
+        # type: () -> bool
         """
         Returns
         -------
-        - bool: 
+        - bool: If true, enables the port's MAC flow control mechanisms to listen for a directed address pause message.
         """
         return self._get_attribute(self._SDM_ATT_MAP['EnabledFlowControl'])
     @EnabledFlowControl.setter
     def EnabledFlowControl(self, value):
+        # type: (bool) -> None
         self._set_attribute(self._SDM_ATT_MAP['EnabledFlowControl'], value)
 
     @property
     def FirecodeAdvertise(self):
+        # type: () -> bool
         """
         Returns
         -------
@@ -207,10 +239,12 @@ class Novus5GTenTwentyFiveGigLan(Base):
         return self._get_attribute(self._SDM_ATT_MAP['FirecodeAdvertise'])
     @FirecodeAdvertise.setter
     def FirecodeAdvertise(self, value):
+        # type: (bool) -> None
         self._set_attribute(self._SDM_ATT_MAP['FirecodeAdvertise'], value)
 
     @property
     def FirecodeForceOff(self):
+        # type: () -> bool
         """DEPRECATED 
         Returns
         -------
@@ -219,10 +253,12 @@ class Novus5GTenTwentyFiveGigLan(Base):
         return self._get_attribute(self._SDM_ATT_MAP['FirecodeForceOff'])
     @FirecodeForceOff.setter
     def FirecodeForceOff(self, value):
+        # type: (bool) -> None
         self._set_attribute(self._SDM_ATT_MAP['FirecodeForceOff'], value)
 
     @property
     def FirecodeForceOn(self):
+        # type: () -> bool
         """
         Returns
         -------
@@ -231,10 +267,12 @@ class Novus5GTenTwentyFiveGigLan(Base):
         return self._get_attribute(self._SDM_ATT_MAP['FirecodeForceOn'])
     @FirecodeForceOn.setter
     def FirecodeForceOn(self, value):
+        # type: (bool) -> None
         self._set_attribute(self._SDM_ATT_MAP['FirecodeForceOn'], value)
 
     @property
     def FirecodeRequest(self):
+        # type: () -> bool
         """
         Returns
         -------
@@ -243,22 +281,26 @@ class Novus5GTenTwentyFiveGigLan(Base):
         return self._get_attribute(self._SDM_ATT_MAP['FirecodeRequest'])
     @FirecodeRequest.setter
     def FirecodeRequest(self, value):
+        # type: (bool) -> None
         self._set_attribute(self._SDM_ATT_MAP['FirecodeRequest'], value)
 
     @property
     def FlowControlDirectedAddress(self):
+        # type: () -> str
         """
         Returns
         -------
-        - str: 
+        - str: The 48-bit MAC address that the port listens on for a directed pause.
         """
         return self._get_attribute(self._SDM_ATT_MAP['FlowControlDirectedAddress'])
     @FlowControlDirectedAddress.setter
     def FlowControlDirectedAddress(self, value):
+        # type: (str) -> None
         self._set_attribute(self._SDM_ATT_MAP['FlowControlDirectedAddress'], value)
 
     @property
     def ForceDisableFEC(self):
+        # type: () -> bool
         """
         Returns
         -------
@@ -267,10 +309,12 @@ class Novus5GTenTwentyFiveGigLan(Base):
         return self._get_attribute(self._SDM_ATT_MAP['ForceDisableFEC'])
     @ForceDisableFEC.setter
     def ForceDisableFEC(self, value):
+        # type: (bool) -> None
         self._set_attribute(self._SDM_ATT_MAP['ForceDisableFEC'], value)
 
     @property
     def GoodBlocksNumber(self):
+        # type: () -> int
         """
         Returns
         -------
@@ -279,10 +323,12 @@ class Novus5GTenTwentyFiveGigLan(Base):
         return self._get_attribute(self._SDM_ATT_MAP['GoodBlocksNumber'])
     @GoodBlocksNumber.setter
     def GoodBlocksNumber(self, value):
+        # type: (int) -> None
         self._set_attribute(self._SDM_ATT_MAP['GoodBlocksNumber'], value)
 
     @property
     def IeeeL1Defaults(self):
+        # type: () -> bool
         """
         Returns
         -------
@@ -291,10 +337,12 @@ class Novus5GTenTwentyFiveGigLan(Base):
         return self._get_attribute(self._SDM_ATT_MAP['IeeeL1Defaults'])
     @IeeeL1Defaults.setter
     def IeeeL1Defaults(self, value):
+        # type: (bool) -> None
         self._set_attribute(self._SDM_ATT_MAP['IeeeL1Defaults'], value)
 
     @property
     def LaserOn(self):
+        # type: () -> bool
         """
         Returns
         -------
@@ -303,10 +351,12 @@ class Novus5GTenTwentyFiveGigLan(Base):
         return self._get_attribute(self._SDM_ATT_MAP['LaserOn'])
     @LaserOn.setter
     def LaserOn(self, value):
+        # type: (bool) -> None
         self._set_attribute(self._SDM_ATT_MAP['LaserOn'], value)
 
     @property
     def LinkTraining(self):
+        # type: () -> bool
         """
         Returns
         -------
@@ -316,6 +366,7 @@ class Novus5GTenTwentyFiveGigLan(Base):
 
     @property
     def LoopContinuously(self):
+        # type: () -> bool
         """
         Returns
         -------
@@ -324,10 +375,12 @@ class Novus5GTenTwentyFiveGigLan(Base):
         return self._get_attribute(self._SDM_ATT_MAP['LoopContinuously'])
     @LoopContinuously.setter
     def LoopContinuously(self, value):
+        # type: (bool) -> None
         self._set_attribute(self._SDM_ATT_MAP['LoopContinuously'], value)
 
     @property
     def LoopCountNumber(self):
+        # type: () -> int
         """
         Returns
         -------
@@ -336,46 +389,54 @@ class Novus5GTenTwentyFiveGigLan(Base):
         return self._get_attribute(self._SDM_ATT_MAP['LoopCountNumber'])
     @LoopCountNumber.setter
     def LoopCountNumber(self, value):
+        # type: (int) -> None
         self._set_attribute(self._SDM_ATT_MAP['LoopCountNumber'], value)
 
     @property
     def Loopback(self):
+        # type: () -> bool
         """
         Returns
         -------
-        - bool: 
+        - bool: If enabled, the port is set to internally loopback from transmit to receive.
         """
         return self._get_attribute(self._SDM_ATT_MAP['Loopback'])
     @Loopback.setter
     def Loopback(self, value):
+        # type: (bool) -> None
         self._set_attribute(self._SDM_ATT_MAP['Loopback'], value)
 
     @property
     def LoopbackMode(self):
+        # type: () -> str
         """
         Returns
         -------
-        - str(internalLoopback | lineLoopback | none): 
+        - str(none | lineLoopback | internalLoopback): 
         """
         return self._get_attribute(self._SDM_ATT_MAP['LoopbackMode'])
     @LoopbackMode.setter
     def LoopbackMode(self, value):
+        # type: (str) -> None
         self._set_attribute(self._SDM_ATT_MAP['LoopbackMode'], value)
 
     @property
     def Ppm(self):
+        # type: () -> int
         """
         Returns
         -------
-        - number: 
+        - number: Indicates the value that needs to be adjusted for the line transmit frequency.
         """
         return self._get_attribute(self._SDM_ATT_MAP['Ppm'])
     @Ppm.setter
     def Ppm(self, value):
+        # type: (int) -> None
         self._set_attribute(self._SDM_ATT_MAP['Ppm'], value)
 
     @property
     def RsFecAdvertise(self):
+        # type: () -> bool
         """
         Returns
         -------
@@ -384,10 +445,12 @@ class Novus5GTenTwentyFiveGigLan(Base):
         return self._get_attribute(self._SDM_ATT_MAP['RsFecAdvertise'])
     @RsFecAdvertise.setter
     def RsFecAdvertise(self, value):
+        # type: (bool) -> None
         self._set_attribute(self._SDM_ATT_MAP['RsFecAdvertise'], value)
 
     @property
     def RsFecForceOn(self):
+        # type: () -> bool
         """
         Returns
         -------
@@ -396,10 +459,12 @@ class Novus5GTenTwentyFiveGigLan(Base):
         return self._get_attribute(self._SDM_ATT_MAP['RsFecForceOn'])
     @RsFecForceOn.setter
     def RsFecForceOn(self, value):
+        # type: (bool) -> None
         self._set_attribute(self._SDM_ATT_MAP['RsFecForceOn'], value)
 
     @property
     def RsFecRequest(self):
+        # type: () -> bool
         """
         Returns
         -------
@@ -408,22 +473,26 @@ class Novus5GTenTwentyFiveGigLan(Base):
         return self._get_attribute(self._SDM_ATT_MAP['RsFecRequest'])
     @RsFecRequest.setter
     def RsFecRequest(self, value):
+        # type: (bool) -> None
         self._set_attribute(self._SDM_ATT_MAP['RsFecRequest'], value)
 
     @property
     def SelectedSpeeds(self):
+        # type: () -> List[str]
         """
         Returns
         -------
-        - list(str[speed100g | speed25g | speed50g | speed10g | speed40g]): Which speeds are selected for the current media and AN settings.
+        - list(str[speed100g | speed25g | speed50g | speed10g]): Which speeds are selected for the current media and AN settings.
         """
         return self._get_attribute(self._SDM_ATT_MAP['SelectedSpeeds'])
     @SelectedSpeeds.setter
     def SelectedSpeeds(self, value):
+        # type: (List[str]) -> None
         self._set_attribute(self._SDM_ATT_MAP['SelectedSpeeds'], value)
 
     @property
     def SendSetsMode(self):
+        # type: () -> str
         """
         Returns
         -------
@@ -432,22 +501,26 @@ class Novus5GTenTwentyFiveGigLan(Base):
         return self._get_attribute(self._SDM_ATT_MAP['SendSetsMode'])
     @SendSetsMode.setter
     def SendSetsMode(self, value):
+        # type: (str) -> None
         self._set_attribute(self._SDM_ATT_MAP['SendSetsMode'], value)
 
     @property
     def Speed(self):
+        # type: () -> str
         """
         Returns
         -------
-        - str(speed10g | speed25g): 
+        - str(speed100g | speed10g | speed25g | speed50g): 
         """
         return self._get_attribute(self._SDM_ATT_MAP['Speed'])
     @Speed.setter
     def Speed(self, value):
+        # type: (str) -> None
         self._set_attribute(self._SDM_ATT_MAP['Speed'], value)
 
     @property
     def StartErrorInsertion(self):
+        # type: () -> bool
         """
         Returns
         -------
@@ -456,10 +529,12 @@ class Novus5GTenTwentyFiveGigLan(Base):
         return self._get_attribute(self._SDM_ATT_MAP['StartErrorInsertion'])
     @StartErrorInsertion.setter
     def StartErrorInsertion(self, value):
+        # type: (bool) -> None
         self._set_attribute(self._SDM_ATT_MAP['StartErrorInsertion'], value)
 
     @property
     def TxIgnoreRxLinkFaults(self):
+        # type: () -> bool
         """
         Returns
         -------
@@ -468,10 +543,12 @@ class Novus5GTenTwentyFiveGigLan(Base):
         return self._get_attribute(self._SDM_ATT_MAP['TxIgnoreRxLinkFaults'])
     @TxIgnoreRxLinkFaults.setter
     def TxIgnoreRxLinkFaults(self, value):
+        # type: (bool) -> None
         self._set_attribute(self._SDM_ATT_MAP['TxIgnoreRxLinkFaults'], value)
 
     @property
     def TypeAOrderedSets(self):
+        # type: () -> str
         """
         Returns
         -------
@@ -480,10 +557,12 @@ class Novus5GTenTwentyFiveGigLan(Base):
         return self._get_attribute(self._SDM_ATT_MAP['TypeAOrderedSets'])
     @TypeAOrderedSets.setter
     def TypeAOrderedSets(self, value):
+        # type: (str) -> None
         self._set_attribute(self._SDM_ATT_MAP['TypeAOrderedSets'], value)
 
     @property
     def TypeBOrderedSets(self):
+        # type: () -> str
         """
         Returns
         -------
@@ -492,10 +571,12 @@ class Novus5GTenTwentyFiveGigLan(Base):
         return self._get_attribute(self._SDM_ATT_MAP['TypeBOrderedSets'])
     @TypeBOrderedSets.setter
     def TypeBOrderedSets(self, value):
+        # type: (str) -> None
         self._set_attribute(self._SDM_ATT_MAP['TypeBOrderedSets'], value)
 
     @property
     def UseANResults(self):
+        # type: () -> bool
         """
         Returns
         -------
@@ -504,40 +585,42 @@ class Novus5GTenTwentyFiveGigLan(Base):
         return self._get_attribute(self._SDM_ATT_MAP['UseANResults'])
     @UseANResults.setter
     def UseANResults(self, value):
+        # type: (bool) -> None
         self._set_attribute(self._SDM_ATT_MAP['UseANResults'], value)
 
     def update(self, AutoInstrumentation=None, BadBlocksNumber=None, EnableAutoNegotiation=None, EnablePPM=None, EnableRsFec=None, EnableRsFecStats=None, EnabledFlowControl=None, FirecodeAdvertise=None, FirecodeForceOff=None, FirecodeForceOn=None, FirecodeRequest=None, FlowControlDirectedAddress=None, ForceDisableFEC=None, GoodBlocksNumber=None, IeeeL1Defaults=None, LaserOn=None, LoopContinuously=None, LoopCountNumber=None, Loopback=None, LoopbackMode=None, Ppm=None, RsFecAdvertise=None, RsFecForceOn=None, RsFecRequest=None, SelectedSpeeds=None, SendSetsMode=None, Speed=None, StartErrorInsertion=None, TxIgnoreRxLinkFaults=None, TypeAOrderedSets=None, TypeBOrderedSets=None, UseANResults=None):
+        # type: (str, int, bool, bool, bool, bool, bool, bool, bool, bool, bool, str, bool, int, bool, bool, bool, int, bool, str, int, bool, bool, bool, List[str], str, str, bool, bool, str, str, bool) -> Novus5GTenTwentyFiveGigLan
         """Updates novus5GTenTwentyFiveGigLan resource on the server.
 
         Args
         ----
-        - AutoInstrumentation (str(endOfFrame | floating)): 
+        - AutoInstrumentation (str(endOfFrame | floating)): The auto instrumentation mode.
         - BadBlocksNumber (number): 
         - EnableAutoNegotiation (bool): 
-        - EnablePPM (bool): 
+        - EnablePPM (bool): If true, enables the portsppm.
         - EnableRsFec (bool): 
         - EnableRsFecStats (bool): 
-        - EnabledFlowControl (bool): 
+        - EnabledFlowControl (bool): If true, enables the port's MAC flow control mechanisms to listen for a directed address pause message.
         - FirecodeAdvertise (bool): 
         - FirecodeForceOff (bool): 
         - FirecodeForceOn (bool): 
         - FirecodeRequest (bool): 
-        - FlowControlDirectedAddress (str): 
+        - FlowControlDirectedAddress (str): The 48-bit MAC address that the port listens on for a directed pause.
         - ForceDisableFEC (bool): 
         - GoodBlocksNumber (number): 
         - IeeeL1Defaults (bool): 
         - LaserOn (bool): 
         - LoopContinuously (bool): 
         - LoopCountNumber (number): 
-        - Loopback (bool): 
-        - LoopbackMode (str(internalLoopback | lineLoopback | none)): 
-        - Ppm (number): 
+        - Loopback (bool): If enabled, the port is set to internally loopback from transmit to receive.
+        - LoopbackMode (str(none | lineLoopback | internalLoopback)): 
+        - Ppm (number): Indicates the value that needs to be adjusted for the line transmit frequency.
         - RsFecAdvertise (bool): 
         - RsFecForceOn (bool): 
         - RsFecRequest (bool): 
-        - SelectedSpeeds (list(str[speed100g | speed25g | speed50g | speed10g | speed40g])): Which speeds are selected for the current media and AN settings.
+        - SelectedSpeeds (list(str[speed100g | speed25g | speed50g | speed10g])): Which speeds are selected for the current media and AN settings.
         - SendSetsMode (str(alternate | typeAOnly | typeBOnly)): 
-        - Speed (str(speed10g | speed25g)): 
+        - Speed (str(speed100g | speed10g | speed25g | speed50g)): 
         - StartErrorInsertion (bool): 
         - TxIgnoreRxLinkFaults (bool): 
         - TypeAOrderedSets (str(localFault | remoteFault)): 
@@ -549,3 +632,78 @@ class Novus5GTenTwentyFiveGigLan(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def find(self, AutoInstrumentation=None, AvailableSpeeds=None, BadBlocksNumber=None, CanModifySpeed=None, CanSetMultipleSpeeds=None, EnableAutoNegotiation=None, EnablePPM=None, EnableRsFec=None, EnableRsFecStats=None, EnabledFlowControl=None, FirecodeAdvertise=None, FirecodeForceOff=None, FirecodeForceOn=None, FirecodeRequest=None, FlowControlDirectedAddress=None, ForceDisableFEC=None, GoodBlocksNumber=None, IeeeL1Defaults=None, LaserOn=None, LinkTraining=None, LoopContinuously=None, LoopCountNumber=None, Loopback=None, LoopbackMode=None, Ppm=None, RsFecAdvertise=None, RsFecForceOn=None, RsFecRequest=None, SelectedSpeeds=None, SendSetsMode=None, Speed=None, StartErrorInsertion=None, TxIgnoreRxLinkFaults=None, TypeAOrderedSets=None, TypeBOrderedSets=None, UseANResults=None):
+        # type: (str, List[str], int, bool, bool, bool, bool, bool, bool, bool, bool, bool, bool, bool, str, bool, int, bool, bool, bool, bool, int, bool, str, int, bool, bool, bool, List[str], str, str, bool, bool, str, str, bool) -> Novus5GTenTwentyFiveGigLan
+        """Finds and retrieves novus5GTenTwentyFiveGigLan resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve novus5GTenTwentyFiveGigLan resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all novus5GTenTwentyFiveGigLan resources from the server.
+
+        Args
+        ----
+        - AutoInstrumentation (str(endOfFrame | floating)): The auto instrumentation mode.
+        - AvailableSpeeds (list(str[speed100g | speed25g | speed50g | speed10g])): Which speeds are available for the current media and AN settings.
+        - BadBlocksNumber (number): 
+        - CanModifySpeed (bool): Returns true/false depending upon if the port can change speed for the current media and AN settings.
+        - CanSetMultipleSpeeds (bool): Can this port selectmultiple speeds for the current media and AN settings.
+        - EnableAutoNegotiation (bool): 
+        - EnablePPM (bool): If true, enables the portsppm.
+        - EnableRsFec (bool): 
+        - EnableRsFecStats (bool): 
+        - EnabledFlowControl (bool): If true, enables the port's MAC flow control mechanisms to listen for a directed address pause message.
+        - FirecodeAdvertise (bool): 
+        - FirecodeForceOff (bool): 
+        - FirecodeForceOn (bool): 
+        - FirecodeRequest (bool): 
+        - FlowControlDirectedAddress (str): The 48-bit MAC address that the port listens on for a directed pause.
+        - ForceDisableFEC (bool): 
+        - GoodBlocksNumber (number): 
+        - IeeeL1Defaults (bool): 
+        - LaserOn (bool): 
+        - LinkTraining (bool): 
+        - LoopContinuously (bool): 
+        - LoopCountNumber (number): 
+        - Loopback (bool): If enabled, the port is set to internally loopback from transmit to receive.
+        - LoopbackMode (str(none | lineLoopback | internalLoopback)): 
+        - Ppm (number): Indicates the value that needs to be adjusted for the line transmit frequency.
+        - RsFecAdvertise (bool): 
+        - RsFecForceOn (bool): 
+        - RsFecRequest (bool): 
+        - SelectedSpeeds (list(str[speed100g | speed25g | speed50g | speed10g])): Which speeds are selected for the current media and AN settings.
+        - SendSetsMode (str(alternate | typeAOnly | typeBOnly)): 
+        - Speed (str(speed100g | speed10g | speed25g | speed50g)): 
+        - StartErrorInsertion (bool): 
+        - TxIgnoreRxLinkFaults (bool): 
+        - TypeAOrderedSets (str(localFault | remoteFault)): 
+        - TypeBOrderedSets (str(localFault | remoteFault)): 
+        - UseANResults (bool): 
+
+        Returns
+        -------
+        - self: This instance with matching novus5GTenTwentyFiveGigLan resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of novus5GTenTwentyFiveGigLan data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the novus5GTenTwentyFiveGigLan resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
