@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class OAM(Base):
@@ -112,7 +114,7 @@ class OAM(Base):
         """
         Returns
         -------
-        - bool: If true, enables the loopback. when an ixia port goes to loopback mode, then all non oam packets coming to that port gets looped back. .
+        - bool: If true, enables the loopback. when an ixia port goes to loopback mode, then all non oam packets coming to that port gets looped back.
         """
         return self._get_attribute(self._SDM_ATT_MAP['Loopback'])
     @Loopback.setter
@@ -126,7 +128,7 @@ class OAM(Base):
         """
         Returns
         -------
-        - str: Indicates the Mac address.
+        - str: Mac address of the local DTE. By default, the mac address is automatically generated from card, port and other related information.
         """
         return self._get_attribute(self._SDM_ATT_MAP['MacAddress'])
     @MacAddress.setter
@@ -214,8 +216,8 @@ class OAM(Base):
         - Enabled (bool): If true, enables OAM for the Ten Gig Lan port.
         - IdleTimer (number): The timer used to ensure OAM sub layer adheres to maximum number of OAMPDUs per second and emits at least one OAMPDU per second. The default is 1, minimum value is 1 and maximum value is 10.
         - LinkEvents (bool): If true, enables link event interpreting support in Ixia port.
-        - Loopback (bool): If true, enables the loopback. when an ixia port goes to loopback mode, then all non oam packets coming to that port gets looped back. .
-        - MacAddress (str): Indicates the Mac address.
+        - Loopback (bool): If true, enables the loopback. when an ixia port goes to loopback mode, then all non oam packets coming to that port gets looped back.
+        - MacAddress (str): Mac address of the local DTE. By default, the mac address is automatically generated from card, port and other related information.
         - MaxOAMPDUSize (number): Indicates the maximum OAMPDU size supported by local DTE. The default is 1500, minimum is 64, and maximum is 1500 in octets.
         - OrganizationUniqueIdentifier (str): This three-octet field contains a 24-bit Organizationally Unique Identifier. The default value is 00-01-00. Any three octets hex value can be given.
         - TlvType (str): Indicates the tlv type.
@@ -227,3 +229,53 @@ class OAM(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def find(self, EnableTlvOption=None, Enabled=None, IdleTimer=None, LinkEvents=None, Loopback=None, MacAddress=None, MaxOAMPDUSize=None, OrganizationUniqueIdentifier=None, TlvType=None, TlvValue=None, VendorSpecificInformation=None):
+        # type: (bool, bool, int, bool, bool, str, int, str, str, str, str) -> OAM
+        """Finds and retrieves OAM resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve OAM resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all OAM resources from the server.
+
+        Args
+        ----
+        - EnableTlvOption (bool): If true, enables the tlv option.
+        - Enabled (bool): If true, enables OAM for the Ten Gig Lan port.
+        - IdleTimer (number): The timer used to ensure OAM sub layer adheres to maximum number of OAMPDUs per second and emits at least one OAMPDU per second. The default is 1, minimum value is 1 and maximum value is 10.
+        - LinkEvents (bool): If true, enables link event interpreting support in Ixia port.
+        - Loopback (bool): If true, enables the loopback. when an ixia port goes to loopback mode, then all non oam packets coming to that port gets looped back.
+        - MacAddress (str): Mac address of the local DTE. By default, the mac address is automatically generated from card, port and other related information.
+        - MaxOAMPDUSize (number): Indicates the maximum OAMPDU size supported by local DTE. The default is 1500, minimum is 64, and maximum is 1500 in octets.
+        - OrganizationUniqueIdentifier (str): This three-octet field contains a 24-bit Organizationally Unique Identifier. The default value is 00-01-00. Any three octets hex value can be given.
+        - TlvType (str): Indicates the tlv type.
+        - TlvValue (str): Enters the tlv value.
+        - VendorSpecificInformation (str): Contains the vendor specific information that is used to differentiate a vendor's product modes/version. Default is 00000000.
+
+        Returns
+        -------
+        - self: This instance with matching OAM resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of OAM data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the OAM resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
