@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Ppp(Base):
@@ -192,7 +194,7 @@ class Ppp(Base):
         """
         Returns
         -------
-        - bool: Enables the Open System Interconnection (OSI) Network Layer Control Protocol (OSINLCP).
+        - bool: Enables the Open System Interconnection (OSI) Network Layer Control Protocol (OSINLCP).localIpV6IdType
         """
         return self._get_attribute(self._SDM_ATT_MAP['EnableOsi'])
     @EnableOsi.setter
@@ -474,7 +476,7 @@ class Ppp(Base):
         - EnableIpV6 (bool): Enables the IPv6 Network Control Protocol (IPCP).
         - EnableLqm (bool): Enables Link Quality Monitoring (LQM) on the link.
         - EnableMpls (bool): Enables MPLS on the link.
-        - EnableOsi (bool): Enables the Open System Interconnection (OSI) Network Layer Control Protocol (OSINLCP).
+        - EnableOsi (bool): Enables the Open System Interconnection (OSI) Network Layer Control Protocol (OSINLCP).localIpV6IdType
         - Enabled (bool): If true, enables PPP for the POS port.
         - LocalIpAddress (str): The local port's requested IPv4 address. This address is sent by the local peer to the remote peer, as a Configuration Option in an IPCP Configuration Request packet. The default is 0.0.0.1.
         - LocalIpV6IdType (str(ipV6 | lastNegotiated | macBased | random)): The type of Interface Identifier (IID). It is a Configuration Options sent in the Configuration Request packet. A globally unique, non-zero Interface Identifier is preferred.
@@ -499,3 +501,71 @@ class Ppp(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def find(self, AvailableSpeeds=None, CanModifySpeed=None, CanSetMultipleSpeeds=None, ConfigurationRetries=None, EnableAccmNegotiation=None, EnableIpV4=None, EnableIpV6=None, EnableLqm=None, EnableMpls=None, EnableOsi=None, Enabled=None, LocalIpAddress=None, LocalIpV6IdType=None, LocalIpV6Iid=None, LocalIpV6MacBasedIid=None, LocalIpV6NegotiationMode=None, LqmReportInterval=None, PeerIpV6IdType=None, PeerIpV6Iid=None, PeerIpV6MacBasedIid=None, PeerIpV6NegotiationMode=None, PppLinkState=None, RetryTimeout=None, RxAlignment=None, RxMaxReceiveUnit=None, SelectedSpeeds=None, TxAlignment=None, TxMaxReceiveUnit=None, UseMagicNumber=None):
+        # type: (List[str], bool, bool, int, bool, bool, bool, bool, bool, bool, bool, str, str, str, str, str, int, str, str, str, str, str, int, int, int, List[str], int, int, bool) -> Ppp
+        """Finds and retrieves ppp resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve ppp resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all ppp resources from the server.
+
+        Args
+        ----
+        - AvailableSpeeds (list(str[])): Which speeds are available for the current media and AN settings.
+        - CanModifySpeed (bool): Returns true/false depending upon if the port can change speed for the current media and AN settings.
+        - CanSetMultipleSpeeds (bool): Can this port selectmultiple speeds for the current media and AN settings.
+        - ConfigurationRetries (number): The number of additional PPP configuration requests to send before beginning the termination process (if the peer is not properly acknowledging them). The default is 9 requests.
+        - EnableAccmNegotiation (bool): Enables negotiation of Asynchronous Control Character Mask (ACCM).
+        - EnableIpV4 (bool): Enables the IPv4 Network Control Protocol (IPCP).
+        - EnableIpV6 (bool): Enables the IPv6 Network Control Protocol (IPCP).
+        - EnableLqm (bool): Enables Link Quality Monitoring (LQM) on the link.
+        - EnableMpls (bool): Enables MPLS on the link.
+        - EnableOsi (bool): Enables the Open System Interconnection (OSI) Network Layer Control Protocol (OSINLCP).localIpV6IdType
+        - Enabled (bool): If true, enables PPP for the POS port.
+        - LocalIpAddress (str): The local port's requested IPv4 address. This address is sent by the local peer to the remote peer, as a Configuration Option in an IPCP Configuration Request packet. The default is 0.0.0.1.
+        - LocalIpV6IdType (str(ipV6 | lastNegotiated | macBased | random)): The type of Interface Identifier (IID). It is a Configuration Options sent in the Configuration Request packet. A globally unique, non-zero Interface Identifier is preferred.
+        - LocalIpV6Iid (str): (a 64-bit/8-octet value) The IPv6 Interface Identifier. It MUST be unique on the link.
+        - LocalIpV6MacBasedIid (str): (a 48-bit/6-octet value) The MAC Interface Identifier. It MUST be unique on the link.
+        - LocalIpV6NegotiationMode (str(localMay | localMust | peerMust)): Before the negotiation of the Interface Identifier (IID), the node chooses a tentative Interface Identifier.
+        - LqmReportInterval (number): The number of seconds between Link Quality Monitoring (LQM) reports.
+        - PeerIpV6IdType (str(ipV6 | lastNegotiated | macBased | random)): The type of Interface Identifier (IID). It is a Configuration Options sent in the Configuration Request packet. A globally unique, non-zero Interface Identifier is preferred.
+        - PeerIpV6Iid (str): (a 64-bit/8-octet value) The IPv6 Interface Identifier. It MUST be unique on the link.
+        - PeerIpV6MacBasedIid (str): (a 48-bit/6-octet value) The MAC Interface Identifier. It MUST be unique on the link.
+        - PeerIpV6NegotiationMode (str(localMust | peerMay | peerMust)): Before the negotiation of the Interface Identifier (IID), the node chooses a tentative Interface Identifier.
+        - PppLinkState (str): (Read-only) Indicates the current port link state. If PPP is enabled, the fully operational link state is indicated as PPP Up.
+        - RetryTimeout (number): The time, in seconds, between retransmissions of successive configuration or termination requests. The default is 8 seconds.
+        - RxAlignment (number): The byte alignment desired for Receive, in bytes. The default is 0 bytes.
+        - RxMaxReceiveUnit (number): The maximum transmit frame size desired, in bytes. The default is 65,535 bytes.
+        - SelectedSpeeds (list(str[])): Which speeds are selected for the current media and AN settings.
+        - TxAlignment (number): The byte alignment desired for Transmit, in bytes. The default is 0 bytes.
+        - TxMaxReceiveUnit (number): The maximum transmit frame size desired, in bytes. The default is 65,535 bytes.
+        - UseMagicNumber (bool): If enabled, magic number handling is enabled for negotiation and usage. The magic number is used primarily to detect looped connections.
+
+        Returns
+        -------
+        - self: This instance with matching ppp resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of ppp data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the ppp resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
