@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class TenGigLan(Base):
@@ -50,9 +52,9 @@ class TenGigLan(Base):
     }
     _SDM_ENUM_MAP = {
         'autoInstrumentation': ['endOfFrame', 'floating'],
-        'autoNegotiate': ['asymmetric', 'both', 'fullDuplex', 'none'],
-        'loopbackMode': ['internalLoopback', 'lineLoopback', 'none'],
-        'transmitClocking': ['external', 'internal', 'recovered'],
+        'autoNegotiate': ['none', 'both', 'asymmetric', 'fullDuplex'],
+        'loopbackMode': ['none', 'lineLoopback', 'internalLoopback'],
+        'transmitClocking': ['internal', 'external', 'recovered'],
     }
 
     def __init__(self, parent, list_op=False):
@@ -70,10 +72,10 @@ class TenGigLan(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.tengiglan.fcoe.fcoe import Fcoe
-        if self._properties.get('Fcoe', None) is not None:
-            return self._properties.get('Fcoe')
-        else:
-            return Fcoe(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Fcoe', None) is not None:
+                return self._properties.get('Fcoe')
+        return Fcoe(self)._select()
 
     @property
     def Oam(self):
@@ -87,10 +89,10 @@ class TenGigLan(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.tengiglan.oam.oam import Oam
-        if self._properties.get('Oam', None) is not None:
-            return self._properties.get('Oam')
-        else:
-            return Oam(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Oam', None) is not None:
+                return self._properties.get('Oam')
+        return Oam(self)._select()
 
     @property
     def TxLane(self):
@@ -104,10 +106,10 @@ class TenGigLan(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.l1config.tengiglan.txlane.txlane import TxLane
-        if self._properties.get('TxLane', None) is not None:
-            return self._properties.get('TxLane')
-        else:
-            return TxLane(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('TxLane', None) is not None:
+                return self._properties.get('TxLane')
+        return TxLane(self)._select()
 
     @property
     def AutoInstrumentation(self):
@@ -129,7 +131,7 @@ class TenGigLan(Base):
         """
         Returns
         -------
-        - str(asymmetric | both | fullDuplex | none): NOT DEFINED
+        - str(none | both | asymmetric | fullDuplex): NOT DEFINED
         """
         return self._get_attribute(self._SDM_ATT_MAP['AutoNegotiate'])
     @AutoNegotiate.setter
@@ -201,7 +203,7 @@ class TenGigLan(Base):
         """
         Returns
         -------
-        - bool: Enables the port's MAC Flow control mechanisms to listen for a directed address pause message.
+        - bool: If true, enables the port's MAC flow control mechanisms to listen for a directed address pause message.
         """
         return self._get_attribute(self._SDM_ATT_MAP['EnabledFlowControl'])
     @EnabledFlowControl.setter
@@ -215,7 +217,7 @@ class TenGigLan(Base):
         """
         Returns
         -------
-        - str: This is the 48-bit MAC address that the port will listen on for a directed pause message.
+        - str: The 48-bit MAC address that the port listens on for a directed pause.
         """
         return self._get_attribute(self._SDM_ATT_MAP['FlowControlDirectedAddress'])
     @FlowControlDirectedAddress.setter
@@ -243,7 +245,7 @@ class TenGigLan(Base):
         """
         Returns
         -------
-        - str(internalLoopback | lineLoopback | none): NOT DEFINED
+        - str(none | lineLoopback | internalLoopback): NOT DEFINED
         """
         return self._get_attribute(self._SDM_ATT_MAP['LoopbackMode'])
     @LoopbackMode.setter
@@ -285,7 +287,7 @@ class TenGigLan(Base):
         """
         Returns
         -------
-        - str(external | internal | recovered): The transmit clocking type for the 10G LAN port.
+        - str(internal | external | recovered): The transmit clocking type for the 10G LAN port.
         """
         return self._get_attribute(self._SDM_ATT_MAP['TransmitClocking'])
     @TransmitClocking.setter
@@ -314,16 +316,16 @@ class TenGigLan(Base):
         Args
         ----
         - AutoInstrumentation (str(endOfFrame | floating)): The auto instrumentation mode.
-        - AutoNegotiate (str(asymmetric | both | fullDuplex | none)): NOT DEFINED
+        - AutoNegotiate (str(none | both | asymmetric | fullDuplex)): NOT DEFINED
         - EnableLASIMonitoring (bool): If selected, enables LASI monitoring.
         - EnablePPM (bool): If true, enables the portsppm.
-        - EnabledFlowControl (bool): Enables the port's MAC Flow control mechanisms to listen for a directed address pause message.
-        - FlowControlDirectedAddress (str): This is the 48-bit MAC address that the port will listen on for a directed pause message.
+        - EnabledFlowControl (bool): If true, enables the port's MAC flow control mechanisms to listen for a directed address pause message.
+        - FlowControlDirectedAddress (str): The 48-bit MAC address that the port listens on for a directed pause.
         - Loopback (bool): If enabled, the port is set to internally loopback from transmit to receive.
-        - LoopbackMode (str(internalLoopback | lineLoopback | none)): NOT DEFINED
+        - LoopbackMode (str(none | lineLoopback | internalLoopback)): NOT DEFINED
         - Ppm (number): Indicates the value that needs to be adjusted for the line transmit frequency.
         - SelectedSpeeds (list(str[])): Which speeds are selected for the current media and AN settings.
-        - TransmitClocking (str(external | internal | recovered)): The transmit clocking type for the 10G LAN port.
+        - TransmitClocking (str(internal | external | recovered)): The transmit clocking type for the 10G LAN port.
         - TxIgnoreRxLinkFaults (bool): If enabled, will allow transmission of packets even if the receive link is down.
 
         Raises
@@ -331,3 +333,57 @@ class TenGigLan(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def find(self, AutoInstrumentation=None, AutoNegotiate=None, AvailableSpeeds=None, CanModifySpeed=None, CanSetMultipleSpeeds=None, EnableLASIMonitoring=None, EnablePPM=None, EnabledFlowControl=None, FlowControlDirectedAddress=None, Loopback=None, LoopbackMode=None, Ppm=None, SelectedSpeeds=None, TransmitClocking=None, TxIgnoreRxLinkFaults=None):
+        # type: (str, str, List[str], bool, bool, bool, bool, bool, str, bool, str, int, List[str], str, bool) -> TenGigLan
+        """Finds and retrieves tenGigLan resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve tenGigLan resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all tenGigLan resources from the server.
+
+        Args
+        ----
+        - AutoInstrumentation (str(endOfFrame | floating)): The auto instrumentation mode.
+        - AutoNegotiate (str(none | both | asymmetric | fullDuplex)): NOT DEFINED
+        - AvailableSpeeds (list(str[])): Which speeds are available for the current media and AN settings.
+        - CanModifySpeed (bool): Returns true/false depending upon if the port can change speed for the current media and AN settings.
+        - CanSetMultipleSpeeds (bool): Can this port selectmultiple speeds for the current media and AN settings.
+        - EnableLASIMonitoring (bool): If selected, enables LASI monitoring.
+        - EnablePPM (bool): If true, enables the portsppm.
+        - EnabledFlowControl (bool): If true, enables the port's MAC flow control mechanisms to listen for a directed address pause message.
+        - FlowControlDirectedAddress (str): The 48-bit MAC address that the port listens on for a directed pause.
+        - Loopback (bool): If enabled, the port is set to internally loopback from transmit to receive.
+        - LoopbackMode (str(none | lineLoopback | internalLoopback)): NOT DEFINED
+        - Ppm (number): Indicates the value that needs to be adjusted for the line transmit frequency.
+        - SelectedSpeeds (list(str[])): Which speeds are selected for the current media and AN settings.
+        - TransmitClocking (str(internal | external | recovered)): The transmit clocking type for the 10G LAN port.
+        - TxIgnoreRxLinkFaults (bool): If enabled, will allow transmission of packets even if the receive link is down.
+
+        Returns
+        -------
+        - self: This instance with matching tenGigLan resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of tenGigLan data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the tenGigLan resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
