@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class ApplyAction(Base):
@@ -57,10 +59,10 @@ class ApplyAction(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.applyactionmisstype_cb65e7e380c3e82fd0727515601c37f8 import ApplyActionMissType
-        if self._properties.get('ApplyActionMissType', None) is not None:
-            return self._properties.get('ApplyActionMissType')
-        else:
-            return ApplyActionMissType(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('ApplyActionMissType', None) is not None:
+                return self._properties.get('ApplyActionMissType')
+        return ApplyActionMissType(self)._select()
 
     @property
     def ApplyActionType(self):
@@ -74,10 +76,10 @@ class ApplyAction(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.applyactiontype_c99bd67b1f4afee24406c78527adb40f import ApplyActionType
-        if self._properties.get('ApplyActionType', None) is not None:
-            return self._properties.get('ApplyActionType')
-        else:
-            return ApplyActionType(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('ApplyActionType', None) is not None:
+                return self._properties.get('ApplyActionType')
+        return ApplyActionType(self)._select()
 
     @property
     def ExperimenterData(self):
@@ -181,3 +183,48 @@ class ApplyAction(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def find(self, ExperimenterData=None, ExperimenterDataLength=None, ExperimenterDataLengthMiss=None, ExperimenterDataMiss=None, ExperimenterId=None, ExperimenterIdMiss=None):
+        # type: (str, int, int, str, int, int) -> ApplyAction
+        """Finds and retrieves applyAction resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve applyAction resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all applyAction resources from the server.
+
+        Args
+        ----
+        - ExperimenterData (str): NOT DEFINED
+        - ExperimenterDataLength (number): NOT DEFINED
+        - ExperimenterDataLengthMiss (number): NOT DEFINED
+        - ExperimenterDataMiss (str): NOT DEFINED
+        - ExperimenterId (number): NOT DEFINED
+        - ExperimenterIdMiss (number): NOT DEFINED
+
+        Returns
+        -------
+        - self: This instance with matching applyAction resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of applyAction data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the applyAction resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
