@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Bgp(Base):
@@ -80,10 +82,10 @@ class Bgp(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.neighborrange_a1e9ecb177af994ec56d9e054fd677fb import NeighborRange
-        if self._properties.get('NeighborRange', None) is not None:
-            return self._properties.get('NeighborRange')
-        else:
-            return NeighborRange(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('NeighborRange', None) is not None:
+                return self._properties.get('NeighborRange')
+        return NeighborRange(self)
 
     @property
     def AutoFillUpDutIp(self):
@@ -498,6 +500,72 @@ class Bgp(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, AutoFillUpDutIp=None, DisableReceivedUpdateValidation=None, EVpnAfi=None, EVpnSafi=None, EnableAdVplsPrefixLengthInBits=None, EnableExternalActiveConnect=None, EnableInternalActiveConnect=None, EnableLabelExchangeOverLsp=None, EnableVpnLabelExchangeOverLsp=None, Enabled=None, EsImportRouteTargetSubType=None, EsImportRouteTargetType=None, EsiLabelExtendedCommunitySubType=None, EsiLabelExtendedCommunityType=None, EvpnIpAddressLengthUnit=None, ExternalRetries=None, ExternalRetryDelay=None, InternalRetries=None, InternalRetryDelay=None, MacMobilityExtendedCommunitySubType=None, MacMobilityExtendedCommunityType=None, MldpP2mpFecType=None, RunningState=None, Tester4ByteAsForIbgp=None, TesterAsForIbgp=None, TriggerVplsPwInitiation=None, VrfRouteImportExtendedCommunitySubType=None):
+        # type: (bool, bool, int, int, bool, bool, bool, bool, bool, bool, int, int, int, int, str, int, int, int, int, int, int, int, str, int, int, bool, int) -> Bgp
+        """Finds and retrieves bgp resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve bgp resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all bgp resources from the server.
+
+        Args
+        ----
+        - AutoFillUpDutIp (bool): If true, automatically fills up the IP of the DUT
+        - DisableReceivedUpdateValidation (bool): If true, disables any update validation request from the DUT.
+        - EVpnAfi (number): AFI to support EVPN. Default value is 25. Minimum valus is 0 and maximum value is 0xFFFF
+        - EVpnSafi (number): SAFI to support EVPN. Default value is 70. Minimum valus is 0 and maximum value is 0xFF.
+        - EnableAdVplsPrefixLengthInBits (bool): If true, enables the AdVpls length in bits.
+        - EnableExternalActiveConnect (bool): Causes a HELLO message to be actively sent when BGP testing starts.
+        - EnableInternalActiveConnect (bool): Causes a HELLO message to be actively sent when BGP testing starts.
+        - EnableLabelExchangeOverLsp (bool): Enables the ability to exchange labels over LSP for VPNs.
+        - EnableVpnLabelExchangeOverLsp (bool): If true, enables the exchange of VPN exchange over LSP
+        - Enabled (bool): Enables or disables the use of this emulated BGP router in the emulated BGP network. (default = disabled)
+        - EsImportRouteTargetSubType (number): This is a new transitive Route Target extended community carried with the Ethernet Segment route in EVPN. When used, it enables all the PEs connected to the same multi-homed site to import the Ethernet Segment routes. Default value is 2. Minimum value is 1 and maximum value is 0xFF.
+        - EsImportRouteTargetType (number): This is a new transitive Route Target extended community carried with the Ethernet Segment route in EVPN. When used, it enables all the PEs connected to the same multi-homed site to import the Ethernet Segment routes. Default value is 6. Minimum value is 1 and maximum value is 0xFF.
+        - EsiLabelExtendedCommunitySubType (number): This is a new transitive extended community in EVPN. It may be advertised along with Ethernet Auto-Discovery routes and it enables split-horizon procedures for multi-homed sites. Default value is 1. Minimum value is 1 and maximum value is 0xFF.
+        - EsiLabelExtendedCommunityType (number): This is a new transitive extended community in EVPN. It may be advertised along with Ethernet Auto-Discovery routes and it enables split-horizon procedures for multi-homed sites. Default value is 6. Minimum value is 1 and maximum value is 0xFF.
+        - EvpnIpAddressLengthUnit (str(bit | byte)): The unit of the IP address length field in MAC Advertisement route packet, can be bits or bytes
+        - ExternalRetries (number): The number of times to attempt an OPEN connection with the DUT router(s) before giving up.
+        - ExternalRetryDelay (number): When retries are necessary, the delay between retries.
+        - InternalRetries (number): The number of times to attempt an OPEN connection with the DUT router(s) before giving up.
+        - InternalRetryDelay (number): When retries are necessary, the delay between retries.
+        - MacMobilityExtendedCommunitySubType (number): This is a new transitive extended community used in EVPN. It may be advertised along with MAC Advertisement routes to support MAC mobility. Default value is 0. Minimum value is 0 and maximum value is 0xFF.
+        - MacMobilityExtendedCommunityType (number): This is a new transitive extended community used in EVPN. It may be advertised along with MAC Advertisement routes to support MAC mobility. Default value is 6. Minimum value is 1 and maximum value is 0xFF.
+        - MldpP2mpFecType (number): The MLDP P2MP FEC type value in hexadecimal.LOCAL EXECS
+        - RunningState (str(unknown | stopped | stopping | starting | started)): The current running state of the BGP server.
+        - Tester4ByteAsForIbgp (number): NOT DEFINED
+        - TesterAsForIbgp (number): NOT DEFINED
+        - TriggerVplsPwInitiation (bool): Enable to initiate a trigger a VPLS PW initation that is a BGP-LDP communication.
+        - VrfRouteImportExtendedCommunitySubType (number): Extended Community Sub Type to be used in VRF Route Import Extended Community.
+
+        Returns
+        -------
+        - self: This instance with matching bgp resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of bgp data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the bgp resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def Start(self, *args, **kwargs):
         # type: (*Any, **Any) -> None
         """Executes the start operation on the server.
