@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class BroadcastDomains(Base):
@@ -60,10 +62,10 @@ class BroadcastDomains(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.cmacrange_8ee0ca3976d10bdf7e1defed5469922a import CMacRange
-        if self._properties.get('CMacRange', None) is not None:
-            return self._properties.get('CMacRange')
-        else:
-            return CMacRange(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('CMacRange', None) is not None:
+                return self._properties.get('CMacRange')
+        return CMacRange(self)
 
     @property
     def AdRouteLabel(self):
