@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Bucket(Base):
@@ -57,10 +59,10 @@ class Bucket(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bucketaction_965ab5c99e9b19e16bf56a5314ddc36b import BucketAction
-        if self._properties.get('BucketAction', None) is not None:
-            return self._properties.get('BucketAction')
-        else:
-            return BucketAction(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('BucketAction', None) is not None:
+                return self._properties.get('BucketAction')
+        return BucketAction(self)
 
     @property
     def Description(self):
