@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Cfm(Base):
@@ -59,10 +61,10 @@ class Cfm(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bridge_303490481015947d17e8f3098590185b import Bridge
-        if self._properties.get('Bridge', None) is not None:
-            return self._properties.get('Bridge')
-        else:
-            return Bridge(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Bridge', None) is not None:
+                return self._properties.get('Bridge')
+        return Bridge(self)
 
     @property
     def EnableOptionalLmFunctionality(self):
@@ -177,6 +179,52 @@ class Cfm(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, EnableOptionalLmFunctionality=None, EnableOptionalTlvValidation=None, Enabled=None, ReceiveCcm=None, RunningState=None, SendCcm=None, SuppressErrorsOnAis=None):
+        # type: (bool, bool, bool, bool, str, bool, bool) -> Cfm
+        """Finds and retrieves cfm resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve cfm resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all cfm resources from the server.
+
+        Args
+        ----
+        - EnableOptionalLmFunctionality (bool): NOT DEFINED
+        - EnableOptionalTlvValidation (bool): If true, the CFM protocol will validate optional TLVs present in CFM packets.
+        - Enabled (bool): If true, the CFM protcol is enabled.
+        - ReceiveCcm (bool): If true, the CFM protocol can receive CFM CCMs on this port.
+        - RunningState (str(unknown | stopped | stopping | starting | started)): The current running state of the CFM protocol.
+        - SendCcm (bool): If true, the CFM protocol can send CFM CCMs from this port.
+        - SuppressErrorsOnAis (bool): If true, the errors on AIS are suopressed.
+
+        Returns
+        -------
+        - self: This instance with matching cfm resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of cfm data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the cfm resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def Start(self, *args, **kwargs):
         # type: (*Any, **Any) -> None
         """Executes the start operation on the server.
