@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class CustomTopologyNode(Base):
@@ -59,10 +61,10 @@ class CustomTopologyNode(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.customnetworktopologylinks_5e1eaf53830b67b52c94f8ec618f4c02 import CustomNetworkTopologyLinks
-        if self._properties.get('CustomNetworkTopologyLinks', None) is not None:
-            return self._properties.get('CustomNetworkTopologyLinks')
-        else:
-            return CustomNetworkTopologyLinks(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('CustomNetworkTopologyLinks', None) is not None:
+                return self._properties.get('CustomNetworkTopologyLinks')
+        return CustomNetworkTopologyLinks(self)
 
     @property
     def BridgePriority(self):
