@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class CustomTopologyNodeTopologyRange(Base):
@@ -57,10 +59,10 @@ class CustomTopologyNodeTopologyRange(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.customtopologyinterestedvlanrange_83977d105f4d179465b55fa6725a4487 import CustomTopologyInterestedVlanRange
-        if self._properties.get('CustomTopologyInterestedVlanRange', None) is not None:
-            return self._properties.get('CustomTopologyInterestedVlanRange')
-        else:
-            return CustomTopologyInterestedVlanRange(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('CustomTopologyInterestedVlanRange', None) is not None:
+                return self._properties.get('CustomTopologyInterestedVlanRange')
+        return CustomTopologyInterestedVlanRange(self)
 
     @property
     def NicknameCount(self):
