@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class CustomTopologySpbNodeBaseVidRange(Base):
@@ -60,10 +62,10 @@ class CustomTopologySpbNodeBaseVidRange(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.customtopologyspbnodeisidrange_38d1e356fa5f70b530ee017ce7bba58d import CustomTopologySpbNodeIsidRange
-        if self._properties.get('CustomTopologySpbNodeIsidRange', None) is not None:
-            return self._properties.get('CustomTopologySpbNodeIsidRange')
-        else:
-            return CustomTopologySpbNodeIsidRange(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('CustomTopologySpbNodeIsidRange', None) is not None:
+                return self._properties.get('CustomTopologySpbNodeIsidRange')
+        return CustomTopologySpbNodeIsidRange(self)
 
     @property
     def BVlanPriority(self):
