@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class CustomTopologySpbNodeTopologyRange(Base):
@@ -58,10 +60,10 @@ class CustomTopologySpbNodeTopologyRange(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.customtopologyspbnodebasevidrange_de0058a944364add436467ad4dd6ff34 import CustomTopologySpbNodeBaseVidRange
-        if self._properties.get('CustomTopologySpbNodeBaseVidRange', None) is not None:
-            return self._properties.get('CustomTopologySpbNodeBaseVidRange')
-        else:
-            return CustomTopologySpbNodeBaseVidRange(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('CustomTopologySpbNodeBaseVidRange', None) is not None:
+                return self._properties.get('CustomTopologySpbNodeBaseVidRange')
+        return CustomTopologySpbNodeBaseVidRange(self)
 
     @property
     def CistExternalRootCost(self):
