@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class DceNodeTopologyRange(Base):
@@ -61,10 +63,10 @@ class DceNodeTopologyRange(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.dcenodeinterestedvlanrange_b15c6822c508a957290b5d3ed2b3ea4e import DceNodeInterestedVlanRange
-        if self._properties.get('DceNodeInterestedVlanRange', None) is not None:
-            return self._properties.get('DceNodeInterestedVlanRange')
-        else:
-            return DceNodeInterestedVlanRange(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('DceNodeInterestedVlanRange', None) is not None:
+                return self._properties.get('DceNodeInterestedVlanRange')
+        return DceNodeInterestedVlanRange(self)
 
     @property
     def BroadcastPriority(self):
