@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class GroupDescriptionStatLearnedInformation(Base):
@@ -64,10 +66,10 @@ class GroupDescriptionStatLearnedInformation(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.groupbucketdescstatlearnedinformation_c5c1fdcf0cd8750ead47c9919177d367 import GroupBucketDescStatLearnedInformation
-        if self._properties.get('GroupBucketDescStatLearnedInformation', None) is not None:
-            return self._properties.get('GroupBucketDescStatLearnedInformation')
-        else:
-            return GroupBucketDescStatLearnedInformation(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('GroupBucketDescStatLearnedInformation', None) is not None:
+                return self._properties.get('GroupBucketDescStatLearnedInformation')
+        return GroupBucketDescStatLearnedInformation(self)
 
     @property
     def DataPathId(self):
