@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class GroupRange(Base):
@@ -63,10 +65,10 @@ class GroupRange(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.sourcerange_bfb4946333e992c2007f92349bd0076c import SourceRange
-        if self._properties.get('SourceRange', None) is not None:
-            return self._properties.get('SourceRange')
-        else:
-            return SourceRange(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('SourceRange', None) is not None:
+                return self._properties.get('SourceRange')
+        return SourceRange(self)
 
     @property
     def EnablePacking(self):
