@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class GroupStatLearnedInformation(Base):
@@ -68,10 +70,10 @@ class GroupStatLearnedInformation(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.groupstatbucketlearnedinformation_4457768602bbf2c9ed3e3e2bb1a30d7c import GroupStatBucketLearnedInformation
-        if self._properties.get('GroupStatBucketLearnedInformation', None) is not None:
-            return self._properties.get('GroupStatBucketLearnedInformation')
-        else:
-            return GroupStatBucketLearnedInformation(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('GroupStatBucketLearnedInformation', None) is not None:
+                return self._properties.get('GroupStatBucketLearnedInformation')
+        return GroupStatBucketLearnedInformation(self)
 
     @property
     def ByteCount(self):
