@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Host(Base):
@@ -69,10 +71,10 @@ class Host(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.group_b8eef8cdbd0da12e3fdb6e5fa5a6ef91 import Group
-        if self._properties.get('Group', None) is not None:
-            return self._properties.get('Group')
-        else:
-            return Group(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Group', None) is not None:
+                return self._properties.get('Group')
+        return Group(self)
 
     @property
     def Enabled(self):
