@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Host(Base):
@@ -69,10 +71,10 @@ class Host(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.grouprange_f61fdd85e4f0ee7466748db193fd2ec8 import GroupRange
-        if self._properties.get('GroupRange', None) is not None:
-            return self._properties.get('GroupRange')
-        else:
-            return GroupRange(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('GroupRange', None) is not None:
+                return self._properties.get('GroupRange')
+        return GroupRange(self)
 
     @property
     def EnableImmediateResp(self):
