@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class HostTopologyLearnedInformation(Base):
@@ -51,10 +53,10 @@ class HostTopologyLearnedInformation(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.switchhostrangelearnedinfo_c3ff6e8f58c97b1b0d4885ef2523cc50 import SwitchHostRangeLearnedInfo
-        if self._properties.get('SwitchHostRangeLearnedInfo', None) is not None:
-            return self._properties.get('SwitchHostRangeLearnedInfo')
-        else:
-            return SwitchHostRangeLearnedInfo(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('SwitchHostRangeLearnedInfo', None) is not None:
+                return self._properties.get('SwitchHostRangeLearnedInfo')
+        return SwitchHostRangeLearnedInfo(self)
 
     @property
     def SwitchHostRangeLearnedInfoTriggerAttributes(self):
@@ -68,10 +70,45 @@ class HostTopologyLearnedInformation(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.switchhostrangelearnedinfotriggerattributes_970cca4f196b63ea57bce8499441fe35 import SwitchHostRangeLearnedInfoTriggerAttributes
-        if self._properties.get('SwitchHostRangeLearnedInfoTriggerAttributes', None) is not None:
-            return self._properties.get('SwitchHostRangeLearnedInfoTriggerAttributes')
-        else:
-            return SwitchHostRangeLearnedInfoTriggerAttributes(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('SwitchHostRangeLearnedInfoTriggerAttributes', None) is not None:
+                return self._properties.get('SwitchHostRangeLearnedInfoTriggerAttributes')
+        return SwitchHostRangeLearnedInfoTriggerAttributes(self)._select()
+
+    def find(self):
+        """Finds and retrieves hostTopologyLearnedInformation resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve hostTopologyLearnedInformation resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all hostTopologyLearnedInformation resources from the server.
+
+        Returns
+        -------
+        - self: This instance with matching hostTopologyLearnedInformation resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of hostTopologyLearnedInformation data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the hostTopologyLearnedInformation resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
 
     def RefreshHostRangeLearnedInformation(self, *args, **kwargs):
         # type: (*Any, **Any) -> Union[bool, None]
