@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Igmp(Base):
@@ -62,10 +64,10 @@ class Igmp(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.host_0710de542a7934016dc82d18924d1082 import Host
-        if self._properties.get('Host', None) is not None:
-            return self._properties.get('Host')
-        else:
-            return Host(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Host', None) is not None:
+                return self._properties.get('Host')
+        return Host(self)
 
     @property
     def Querier(self):
@@ -79,10 +81,10 @@ class Igmp(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.querier_caaf4682cc5c2a511c8c68d13991790f import Querier
-        if self._properties.get('Querier', None) is not None:
-            return self._properties.get('Querier')
-        else:
-            return Querier(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Querier', None) is not None:
+                return self._properties.get('Querier')
+        return Querier(self)
 
     @property
     def EnableUnicastMode(self):
@@ -242,6 +244,55 @@ class Igmp(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, EnableUnicastMode=None, Enabled=None, NumberOfGroups=None, NumberOfQueries=None, QueryTimePeriod=None, RunningState=None, SendLeaveOnHostDisable=None, SendLeaveOnStop=None, StatsEnabled=None, TimePeriod=None):
+        # type: (bool, bool, int, int, int, str, bool, bool, bool, int) -> Igmp
+        """Finds and retrieves igmp resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve igmp resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all igmp resources from the server.
+
+        Args
+        ----
+        - EnableUnicastMode (bool): 
+        - Enabled (bool): Enables or disables the use of this emulated EIGRP router in the emulated EIGRP network. (default = disabled)
+        - NumberOfGroups (number): Provides a means of throttling the amount of IGMP traffic generated by the port.
+        - NumberOfQueries (number): Provides a means of throttling the amount of IGMP queries generated by the port.
+        - QueryTimePeriod (number): The time, in milliseconds, between queries.
+        - RunningState (str(unknown | stopped | stopping | starting | started)): The current running state of the IGMP server.
+        - SendLeaveOnHostDisable (bool): Send Leave On Host Disable
+        - SendLeaveOnStop (bool): Send leaves on stop (v2 and v3 only).
+        - StatsEnabled (bool): If true, this object enables the IGMP statistics.
+        - TimePeriod (number): Specifies the length of each time period during which the specified number of IGMP groups will be advertised.
+
+        Returns
+        -------
+        - self: This instance with matching igmp resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of igmp data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the igmp resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def Join(self, *args, **kwargs):
         # type: (*Any, **Any) -> None
         """Executes the join operation on the server.
