@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Instruction(Base):
@@ -57,10 +59,10 @@ class Instruction(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.instructiontype_48ecf22c686ab3b403480ead04a36305 import InstructionType
-        if self._properties.get('InstructionType', None) is not None:
-            return self._properties.get('InstructionType')
-        else:
-            return InstructionType(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('InstructionType', None) is not None:
+                return self._properties.get('InstructionType')
+        return InstructionType(self)._select()
 
     @property
     def InstructionTypeMiss(self):
@@ -74,10 +76,10 @@ class Instruction(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.instructiontypemiss_253739e9542d1a3617b510285726bcd8 import InstructionTypeMiss
-        if self._properties.get('InstructionTypeMiss', None) is not None:
-            return self._properties.get('InstructionTypeMiss')
-        else:
-            return InstructionTypeMiss(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('InstructionTypeMiss', None) is not None:
+                return self._properties.get('InstructionTypeMiss')
+        return InstructionTypeMiss(self)._select()
 
     @property
     def ExperimenterData(self):
@@ -181,3 +183,48 @@ class Instruction(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def find(self, ExperimenterData=None, ExperimenterDataLength=None, ExperimenterDataLengthMiss=None, ExperimenterDataMiss=None, ExperimenterId=None, ExperimenterIdMiss=None):
+        # type: (str, int, int, str, int, int) -> Instruction
+        """Finds and retrieves instruction resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve instruction resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all instruction resources from the server.
+
+        Args
+        ----
+        - ExperimenterData (str): NOT DEFINED
+        - ExperimenterDataLength (number): NOT DEFINED
+        - ExperimenterDataLengthMiss (number): NOT DEFINED
+        - ExperimenterDataMiss (str): NOT DEFINED
+        - ExperimenterId (number): NOT DEFINED
+        - ExperimenterIdMiss (number): NOT DEFINED
+
+        Returns
+        -------
+        - self: This instance with matching instruction resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of instruction data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the instruction resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
