@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Interface(Base):
@@ -72,10 +74,10 @@ class Interface(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.session_528e31d9c93d0ad2afb513a10d9d8be3 import Session
-        if self._properties.get('Session', None) is not None:
-            return self._properties.get('Session')
-        else:
-            return Session(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Session', None) is not None:
+                return self._properties.get('Session')
+        return Session(self)
 
     @property
     def EchoConfigureSrcIp(self):
