@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Ipv4MulticastVpn(Base):
@@ -80,10 +82,10 @@ family..
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.opaquevalueelement_d49e7d4c8b0df2f382492278f34bd590 import OpaqueValueElement
-        if self._properties.get('OpaqueValueElement', None) is not None:
-            return self._properties.get('OpaqueValueElement')
-        else:
-            return OpaqueValueElement(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('OpaqueValueElement', None) is not None:
+                return self._properties.get('OpaqueValueElement')
+        return OpaqueValueElement(self)
 
     @property
     def AddressFamily(self):
