@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class JoinPrune(Base):
@@ -75,10 +77,10 @@ class JoinPrune(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.learnedmgrstate_d7919072a223792ffde967c8d24af004 import LearnedMgrState
-        if self._properties.get('LearnedMgrState', None) is not None:
-            return self._properties.get('LearnedMgrState')
-        else:
-            return LearnedMgrState(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('LearnedMgrState', None) is not None:
+                return self._properties.get('LearnedMgrState')
+        return LearnedMgrState(self)
 
     @property
     def DiscardRegisterStates(self):
