@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class L2Interface(Base):
@@ -59,10 +61,10 @@ class L2Interface(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.l2vcrange_651ba042aec36c4cae0dc6de31d6d00a import L2VcRange
-        if self._properties.get('L2VcRange', None) is not None:
-            return self._properties.get('L2VcRange')
-        else:
-            return L2VcRange(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('L2VcRange', None) is not None:
+                return self._properties.get('L2VcRange')
+        return L2VcRange(self)
 
     @property
     def Count(self):
