@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class LinkOam(Base):
@@ -54,10 +56,10 @@ class LinkOam(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.link_38cd496cb7f730be08b2e1ec647ec0dd import Link
-        if self._properties.get('Link', None) is not None:
-            return self._properties.get('Link')
-        else:
-            return Link(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Link', None) is not None:
+                return self._properties.get('Link')
+        return Link(self)
 
     @property
     def Enabled(self):
@@ -97,6 +99,47 @@ class LinkOam(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, Enabled=None, RunningState=None):
+        # type: (bool, str) -> LinkOam
+        """Finds and retrieves linkOam resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve linkOam resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all linkOam resources from the server.
+
+        Args
+        ----
+        - Enabled (bool): If true, the Link OAM protocol is enabled.
+        - RunningState (str(unknown | stopped | stopping | starting | started)): The current runnings state of Link OAM.
+
+        Returns
+        -------
+        - self: This instance with matching linkOam resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of linkOam data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the linkOam resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def Start(self, *args, **kwargs):
         # type: (*Any, **Any) -> None
         """Executes the start operation on the server.
