@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class LocalEidRange(Base):
@@ -69,10 +71,10 @@ class LocalEidRange(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.locator_1ac254d24fe1c15bb04dc97b760a864a import Locator
-        if self._properties.get('Locator', None) is not None:
-            return self._properties.get('Locator')
-        else:
-            return Locator(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Locator', None) is not None:
+                return self._properties.get('Locator')
+        return Locator(self)
 
     @property
     def Count(self):
