@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class MacMulticast(Base):
@@ -58,10 +60,10 @@ class MacMulticast(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.unicastmacitem_27e98e853c72bbc2a69d3eb276897d78 import UnicastMacItem
-        if self._properties.get('UnicastMacItem', None) is not None:
-            return self._properties.get('UnicastMacItem')
-        else:
-            return UnicastMacItem(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('UnicastMacItem', None) is not None:
+                return self._properties.get('UnicastMacItem')
+        return UnicastMacItem(self)
 
     @property
     def Age(self):
