@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class MapServerCacheInfo(Base):
@@ -71,10 +73,10 @@ class MapServerCacheInfo(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.remotelocators_ace4921278a5aecb46922d99b858e10c import RemoteLocators
-        if self._properties.get('RemoteLocators', None) is not None:
-            return self._properties.get('RemoteLocators')
-        else:
-            return RemoteLocators(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('RemoteLocators', None) is not None:
+                return self._properties.get('RemoteLocators')
+        return RemoteLocators(self)
 
     @property
     def Action(self):
