@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class MeterConfigStatsLearnedInformation(Base):
@@ -66,10 +68,10 @@ class MeterConfigStatsLearnedInformation(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.meterconfigstatsbandlearnedinformation_286ea4e162fea52a8f873cffc4aff2fb import MeterConfigStatsBandLearnedInformation
-        if self._properties.get('MeterConfigStatsBandLearnedInformation', None) is not None:
-            return self._properties.get('MeterConfigStatsBandLearnedInformation')
-        else:
-            return MeterConfigStatsBandLearnedInformation(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('MeterConfigStatsBandLearnedInformation', None) is not None:
+                return self._properties.get('MeterConfigStatsBandLearnedInformation')
+        return MeterConfigStatsBandLearnedInformation(self)
 
     @property
     def DataPathId(self):
