@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class MeterStatsLearnedInformation(Base):
@@ -70,10 +72,10 @@ class MeterStatsLearnedInformation(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.meterstatsbandlearnedinformation_3262a471f223f3c4c65196c8f2de73a7 import MeterStatsBandLearnedInformation
-        if self._properties.get('MeterStatsBandLearnedInformation', None) is not None:
-            return self._properties.get('MeterStatsBandLearnedInformation')
-        else:
-            return MeterStatsBandLearnedInformation(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('MeterStatsBandLearnedInformation', None) is not None:
+                return self._properties.get('MeterStatsBandLearnedInformation')
+        return MeterStatsBandLearnedInformation(self)
 
     @property
     def ByteInCount(self):
