@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Mld(Base):
@@ -62,10 +64,10 @@ class Mld(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.host_fa1da007d58124057dd278c45c2d38ab import Host
-        if self._properties.get('Host', None) is not None:
-            return self._properties.get('Host')
-        else:
-            return Host(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Host', None) is not None:
+                return self._properties.get('Host')
+        return Host(self)
 
     @property
     def Querier(self):
@@ -79,10 +81,10 @@ class Mld(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.querier_dac8ed773affc99eb47c41c6e99f71c1 import Querier
-        if self._properties.get('Querier', None) is not None:
-            return self._properties.get('Querier')
-        else:
-            return Querier(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Querier', None) is not None:
+                return self._properties.get('Querier')
+        return Querier(self)
 
     @property
     def EnableDoneOnStop(self):
@@ -227,6 +229,54 @@ class Mld(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, EnableDoneOnStop=None, EnableUnicastMode=None, Enabled=None, Mldv2Report=None, NumberOfGroups=None, NumberOfQueries=None, QueryTimePeriod=None, RunningState=None, TimePeriod=None):
+        # type: (bool, bool, bool, str, int, int, int, str, int) -> Mld
+        """Finds and retrieves mld resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve mld resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all mld resources from the server.
+
+        Args
+        ----
+        - EnableDoneOnStop (bool): Controls the behavior of MLD messages.
+        - EnableUnicastMode (bool): 
+        - Enabled (bool): Enables or disables simulation of the router.
+        - Mldv2Report (str(type143 | type206)): The version of the MLD report to be generated.
+        - NumberOfGroups (number): Provides a means of throttling the amount of MLD traffic generated by the port.
+        - NumberOfQueries (number): Provides a means of throttling the amount of MLD queries generated by the port.
+        - QueryTimePeriod (number): The time, in milliseconds, between queries.
+        - RunningState (str(unknown | stopped | stopping | starting | started)): The current running state of the MLD server.
+        - TimePeriod (number): Specify the length of each time period during which the specified number of MLD Groups will be advertised.
+
+        Returns
+        -------
+        - self: This instance with matching mld resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of mld data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the mld resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def Start(self, *args, **kwargs):
         # type: (*Any, **Any) -> None
         """Executes the start operation on the server.
