@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class MplsOam(Base):
@@ -54,10 +56,10 @@ class MplsOam(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.learnedinformation_bf316e30bca65d9e9e580c5d39b34b03 import LearnedInformation
-        if self._properties.get('LearnedInformation', None) is not None:
-            return self._properties.get('LearnedInformation')
-        else:
-            return LearnedInformation(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('LearnedInformation', None) is not None:
+                return self._properties.get('LearnedInformation')
+        return LearnedInformation(self)
 
     @property
     def Router(self):
@@ -71,10 +73,10 @@ class MplsOam(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.router_d98f0aa300883baced55c78dabfc111a import Router
-        if self._properties.get('Router', None) is not None:
-            return self._properties.get('Router')
-        else:
-            return Router(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Router', None) is not None:
+                return self._properties.get('Router')
+        return Router(self)
 
     @property
     def Enabled(self):
@@ -114,6 +116,47 @@ class MplsOam(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, Enabled=None, RunningState=None):
+        # type: (bool, str) -> MplsOam
+        """Finds and retrieves mplsOam resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve mplsOam resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all mplsOam resources from the server.
+
+        Args
+        ----
+        - Enabled (bool): This signifies the enablement or disablement of the simulated router.
+        - RunningState (str(unknown | stopped | stopping | starting | started)): This signifies the current running state of the MPLS-OAM server. Possible values include Started, Starting, Stopped, Stopping and Unknown.
+
+        Returns
+        -------
+        - self: This instance with matching mplsOam resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of mplsOam data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the mplsOam resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def Start(self, *args, **kwargs):
         # type: (*Any, **Any) -> None
         """Executes the start operation on the server.
