@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class MplsRouteRange(Base):
@@ -94,10 +96,10 @@ class MplsRouteRange(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.assegment_768d9a7686c3f3831230ede95c06ead1 import AsSegment
-        if self._properties.get('AsSegment', None) is not None:
-            return self._properties.get('AsSegment')
-        else:
-            return AsSegment(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('AsSegment', None) is not None:
+                return self._properties.get('AsSegment')
+        return AsSegment(self)._select()
 
     @property
     def Cluster(self):
@@ -111,10 +113,10 @@ class MplsRouteRange(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.cluster_f5dfc012c0c1d2f27652ce60f19a838a import Cluster
-        if self._properties.get('Cluster', None) is not None:
-            return self._properties.get('Cluster')
-        else:
-            return Cluster(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Cluster', None) is not None:
+                return self._properties.get('Cluster')
+        return Cluster(self)._select()
 
     @property
     def Community(self):
@@ -128,10 +130,10 @@ class MplsRouteRange(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.community_9b24d345545116b92eb59a916175c6d2 import Community
-        if self._properties.get('Community', None) is not None:
-            return self._properties.get('Community')
-        else:
-            return Community(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Community', None) is not None:
+                return self._properties.get('Community')
+        return Community(self)._select()
 
     @property
     def ExtendedCommunity(self):
@@ -145,10 +147,10 @@ class MplsRouteRange(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.extendedcommunity_d16b92453ed6944893c8ecdac946dce2 import ExtendedCommunity
-        if self._properties.get('ExtendedCommunity', None) is not None:
-            return self._properties.get('ExtendedCommunity')
-        else:
-            return ExtendedCommunity(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('ExtendedCommunity', None) is not None:
+                return self._properties.get('ExtendedCommunity')
+        return ExtendedCommunity(self)._select()
 
     @property
     def Flapping(self):
@@ -162,10 +164,10 @@ class MplsRouteRange(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.flapping_0ce469197ce32c0b81e485d606cd5b40 import Flapping
-        if self._properties.get('Flapping', None) is not None:
-            return self._properties.get('Flapping')
-        else:
-            return Flapping(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Flapping', None) is not None:
+                return self._properties.get('Flapping')
+        return Flapping(self)._select()
 
     @property
     def LabelSpace(self):
@@ -179,10 +181,10 @@ class MplsRouteRange(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.labelspace_9c36d013d7e3f2df1ba135cca99d582a import LabelSpace
-        if self._properties.get('LabelSpace', None) is not None:
-            return self._properties.get('LabelSpace')
-        else:
-            return LabelSpace(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('LabelSpace', None) is not None:
+                return self._properties.get('LabelSpace')
+        return LabelSpace(self)._select()
 
     @property
     def AdvertiseNextHopAsV4(self):
