@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class MplsTp(Base):
@@ -63,10 +65,10 @@ class MplsTp(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.router_72a8c27ddd9762f7c4a0a41d1a263e83 import Router
-        if self._properties.get('Router', None) is not None:
-            return self._properties.get('Router')
-        else:
-            return Router(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Router', None) is not None:
+                return self._properties.get('Router')
+        return Router(self)
 
     @property
     def ApsChannelType(self):
@@ -241,6 +243,56 @@ class MplsTp(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, ApsChannelType=None, BfdCcChannelType=None, DelayManagementChannelType=None, EnableHighPerformanceMode=None, Enabled=None, FaultManagementChannelType=None, LossMeasurementChannelType=None, OnDemandCvChannelType=None, PwStatusChannelType=None, RunningState=None, Y1731ChannelType=None):
+        # type: (str, str, str, bool, bool, str, str, str, str, str, str) -> MplsTp
+        """Finds and retrieves mplsTp resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve mplsTp resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all mplsTp resources from the server.
+
+        Args
+        ----
+        - ApsChannelType (str): This signifies the Automatic Protection Switching Channel Type in hexadecimal format.
+        - BfdCcChannelType (str): This signifies the BFD Continuity Check Channel Type in hexadecimal format.
+        - DelayManagementChannelType (str): This signifies the Delay Measurement Channel Type in hexadecimal format.
+        - EnableHighPerformanceMode (bool): This signifies select the checkbox to enable high performance mode.
+        - Enabled (bool): This signifies that the mplsTp protocol is enabled.
+        - FaultManagementChannelType (str): This signifies the Fault Management Channel Type in hexadecimal format.
+        - LossMeasurementChannelType (str): This signifies the Loss Measurement Channel Type in hexadecimal format.
+        - OnDemandCvChannelType (str): This signifies the On Demand Connectivity Verification Channel Type in hexadecimal format.
+        - PwStatusChannelType (str): This signifies the Pseudowire Status Channel Type.
+        - RunningState (str(unknown | stopped | stopping | starting | started)): This signifies the running state of the protocol. Possible values include Started, Starting, Unknown, Stopping and Stopped.
+        - Y1731ChannelType (str): This signifies the Y.1731 Channel Type in hexadecimal format.
+
+        Returns
+        -------
+        - self: This instance with matching mplsTp resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of mplsTp data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the mplsTp resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def Start(self, *args, **kwargs):
         # type: (*Any, **Any) -> None
         """Executes the start operation on the server.
