@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Multicast(Base):
@@ -54,10 +56,10 @@ class Multicast(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.cluster_8dcd05006226c29e0542a45bb95b4f8f import Cluster
-        if self._properties.get('Cluster', None) is not None:
-            return self._properties.get('Cluster')
-        else:
-            return Cluster(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Cluster', None) is not None:
+                return self._properties.get('Cluster')
+        return Cluster(self)._select()
 
     @property
     def RouteDistinguisher(self):
@@ -71,10 +73,10 @@ class Multicast(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.routedistinguisher_2c6f642c4d203efc1987442fcc10ae18 import RouteDistinguisher
-        if self._properties.get('RouteDistinguisher', None) is not None:
-            return self._properties.get('RouteDistinguisher')
-        else:
-            return RouteDistinguisher(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('RouteDistinguisher', None) is not None:
+                return self._properties.get('RouteDistinguisher')
+        return RouteDistinguisher(self)._select()
 
     @property
     def EnableMulticast(self):
@@ -133,3 +135,45 @@ class Multicast(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def find(self, EnableMulticast=None, EnableMulticastCluster=None, GroupAddress=None):
+        # type: (bool, bool, str) -> Multicast
+        """Finds and retrieves multicast resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve multicast resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all multicast resources from the server.
+
+        Args
+        ----
+        - EnableMulticast (bool): Enables the use of Multicast VRFs (MVRFs). (default = false)
+        - EnableMulticastCluster (bool): If true, enables the use of BGP route reflection clusters for multicast VPN route distribution. (default = false)
+        - GroupAddress (str): The IP address for the Multicast Group. The default value is the default MDT group address, used as the Multicast Group address used as the destination for the MVPN tunnel. (default = 239.1.1.1
+
+        Returns
+        -------
+        - self: This instance with matching multicast resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of multicast data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the multicast resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
