@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class MulticastLeafRange(Base):
@@ -63,10 +65,10 @@ class MulticastLeafRange(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.grouptrafficrange_592edfb5d660c2ef731fff853a50b1a6 import GroupTrafficRange
-        if self._properties.get('GroupTrafficRange', None) is not None:
-            return self._properties.get('GroupTrafficRange')
-        else:
-            return GroupTrafficRange(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('GroupTrafficRange', None) is not None:
+                return self._properties.get('GroupTrafficRange')
+        return GroupTrafficRange(self)
 
     @property
     def OpaqueValueElement(self):
@@ -80,10 +82,10 @@ class MulticastLeafRange(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.opaquevalueelement_27bc1e55a7525caed38e30c9995224e2 import OpaqueValueElement
-        if self._properties.get('OpaqueValueElement', None) is not None:
-            return self._properties.get('OpaqueValueElement')
-        else:
-            return OpaqueValueElement(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('OpaqueValueElement', None) is not None:
+                return self._properties.get('OpaqueValueElement')
+        return OpaqueValueElement(self)
 
     @property
     def ContinuousIncrOpaqueValuesAcrossRoot(self):
