@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class MulticastRootRange(Base):
@@ -59,10 +61,10 @@ class MulticastRootRange(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.opaquevalueelement_dba87f250e9ae82d8aff17b985d5ef44 import OpaqueValueElement
-        if self._properties.get('OpaqueValueElement', None) is not None:
-            return self._properties.get('OpaqueValueElement')
-        else:
-            return OpaqueValueElement(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('OpaqueValueElement', None) is not None:
+                return self._properties.get('OpaqueValueElement')
+        return OpaqueValueElement(self)
 
     @property
     def SourceTrafficRange(self):
@@ -76,10 +78,10 @@ class MulticastRootRange(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.sourcetrafficrange_9e3a10265e96d4b6516626b5559092a9 import SourceTrafficRange
-        if self._properties.get('SourceTrafficRange', None) is not None:
-            return self._properties.get('SourceTrafficRange')
-        else:
-            return SourceTrafficRange(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('SourceTrafficRange', None) is not None:
+                return self._properties.get('SourceTrafficRange')
+        return SourceTrafficRange(self)
 
     @property
     def ContinuousIncrOpaqueValuesAcrossRoot(self):
