@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class MulticastSenderSite(Base):
@@ -79,10 +81,10 @@ class MulticastSenderSite(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.opaquevalueelement_4296dd5c4392f88e35ad043bc82d0c44 import OpaqueValueElement
-        if self._properties.get('OpaqueValueElement', None) is not None:
-            return self._properties.get('OpaqueValueElement')
-        else:
-            return OpaqueValueElement(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('OpaqueValueElement', None) is not None:
+                return self._properties.get('OpaqueValueElement')
+        return OpaqueValueElement(self)
 
     @property
     def AddressFamilyType(self):
