@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class NextHopInfo(Base):
@@ -53,10 +55,10 @@ class NextHopInfo(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.rdinfo_4880f052fc533ebf0339e97b80d3331e import RdInfo
-        if self._properties.get('RdInfo', None) is not None:
-            return self._properties.get('RdInfo')
-        else:
-            return RdInfo(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('RdInfo', None) is not None:
+                return self._properties.get('RdInfo')
+        return RdInfo(self)
 
     @property
     def NextHop(self):
