@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class OfChannelSessionPeersLearnedInformation(Base):
@@ -68,10 +70,10 @@ class OfChannelSessionPeersLearnedInformation(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.switchauxiliaryconnectionlearnedinfo_f79c51c709a70b2062dfab3a58ebde80 import SwitchAuxiliaryConnectionLearnedInfo
-        if self._properties.get('SwitchAuxiliaryConnectionLearnedInfo', None) is not None:
-            return self._properties.get('SwitchAuxiliaryConnectionLearnedInfo')
-        else:
-            return SwitchAuxiliaryConnectionLearnedInfo(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('SwitchAuxiliaryConnectionLearnedInfo', None) is not None:
+                return self._properties.get('SwitchAuxiliaryConnectionLearnedInfo')
+        return SwitchAuxiliaryConnectionLearnedInfo(self)
 
     @property
     def AveragePacketInReplyDelay(self):
