@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class OfChannelSwitchLearnedInfo(Base):
@@ -75,10 +77,10 @@ class OfChannelSwitchLearnedInfo(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ofchannelportsswitchlearnedinfo_aec9a10c2a9e74373f5bedf440b84b76 import OfChannelPortsSwitchLearnedInfo
-        if self._properties.get('OfChannelPortsSwitchLearnedInfo', None) is not None:
-            return self._properties.get('OfChannelPortsSwitchLearnedInfo')
-        else:
-            return OfChannelPortsSwitchLearnedInfo(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('OfChannelPortsSwitchLearnedInfo', None) is not None:
+                return self._properties.get('OfChannelPortsSwitchLearnedInfo')
+        return OfChannelPortsSwitchLearnedInfo(self)
 
     @property
     def OfChannelSessionPeersLearnedInformation(self):
@@ -92,10 +94,10 @@ class OfChannelSwitchLearnedInfo(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ofchannelsessionpeerslearnedinformation_3c21f6b29ee2df9053553af0d37734af import OfChannelSessionPeersLearnedInformation
-        if self._properties.get('OfChannelSessionPeersLearnedInformation', None) is not None:
-            return self._properties.get('OfChannelSessionPeersLearnedInformation')
-        else:
-            return OfChannelSessionPeersLearnedInformation(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('OfChannelSessionPeersLearnedInformation', None) is not None:
+                return self._properties.get('OfChannelSessionPeersLearnedInformation')
+        return OfChannelSessionPeersLearnedInformation(self)
 
     @property
     def ActionsSupported(self):
