@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class OfTopologyLearnedInformation(Base):
@@ -56,10 +58,10 @@ class OfTopologyLearnedInformation(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.topologylearnedinfo_32a09f78d836778332eb6d186e001e53 import TopologyLearnedInfo
-        if self._properties.get('TopologyLearnedInfo', None) is not None:
-            return self._properties.get('TopologyLearnedInfo')
-        else:
-            return TopologyLearnedInfo(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('TopologyLearnedInfo', None) is not None:
+                return self._properties.get('TopologyLearnedInfo')
+        return TopologyLearnedInfo(self)
 
     @property
     def EnableInstallLldpFlow(self):
@@ -144,6 +146,50 @@ class OfTopologyLearnedInformation(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, EnableInstallLldpFlow=None, EnableRefreshLldpLearnedInformation=None, IsOfTopologyLearnedInformationRefreshed=None, LldpDestinationMac=None, LldpResponseTimeOut=None):
+        # type: (bool, bool, bool, str, int) -> OfTopologyLearnedInformation
+        """Finds and retrieves ofTopologyLearnedInformation resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve ofTopologyLearnedInformation resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all ofTopologyLearnedInformation resources from the server.
+
+        Args
+        ----
+        - EnableInstallLldpFlow (bool): If true, Install Flow in Switch for LLDP Packets to explicitly send to Controller.
+        - EnableRefreshLldpLearnedInformation (bool): If true, the LLDP trigger configuration parameters are available.
+        - IsOfTopologyLearnedInformationRefreshed (bool): If true, it denotes that the Topology Learned Info is received.
+        - LldpDestinationMac (str): Indicates the Destination MAC Address for LLDP PacketOut.
+        - LldpResponseTimeOut (number): Indicates the duration in milliseconds after which the trigger request times out if no Topology learned info response is received.
+
+        Returns
+        -------
+        - self: This instance with matching ofTopologyLearnedInformation resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of ofTopologyLearnedInformation data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the ofTopologyLearnedInformation resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def RefreshOfTopology(self, *args, **kwargs):
         # type: (*Any, **Any) -> Union[int, None]
         """Executes the refreshOfTopology operation on the server.
