@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class OriginIpInfo(Base):
@@ -53,10 +55,10 @@ class OriginIpInfo(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.rdinfo_5d0e7b1db6cf0b7daa15e78fa449470c import RdInfo
-        if self._properties.get('RdInfo', None) is not None:
-            return self._properties.get('RdInfo')
-        else:
-            return RdInfo(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('RdInfo', None) is not None:
+                return self._properties.get('RdInfo')
+        return RdInfo(self)
 
     @property
     def OriginIp(self):
