@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class OspfV3(Base):
@@ -55,10 +57,10 @@ class OspfV3(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.router_47de08a5e549c3a3ba83f5006b81e108 import Router
-        if self._properties.get('Router', None) is not None:
-            return self._properties.get('Router')
-        else:
-            return Router(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Router', None) is not None:
+                return self._properties.get('Router')
+        return Router(self)
 
     @property
     def EnableDrOrBdr(self):
@@ -113,6 +115,48 @@ class OspfV3(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, EnableDrOrBdr=None, Enabled=None, RunningState=None):
+        # type: (bool, bool, str) -> OspfV3
+        """Finds and retrieves ospfV3 resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve ospfV3 resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all ospfV3 resources from the server.
+
+        Args
+        ----
+        - EnableDrOrBdr (bool): Enables the OSPF Router to participate in DR/BDR election process
+        - Enabled (bool): Enables this emulated OSPFv3 router.
+        - RunningState (str(unknown | stopped | stopping | starting | started)): The current state of the OSPFv6 router.
+
+        Returns
+        -------
+        - self: This instance with matching ospfV3 resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of ospfV3 data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the ospfV3 resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def GracefulRouterRestart(self, *args, **kwargs):
         # type: (*Any, **Any) -> Union[str, None]
         """Executes the gracefulRouterRestart operation on the server.
