@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class PeriodicOamLtLearnedInfo(Base):
@@ -65,10 +67,10 @@ class PeriodicOamLtLearnedInfo(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ltlearnedhop_c9dfd2b401fd7b7df6753d431bdbe5b5 import LtLearnedHop
-        if self._properties.get('LtLearnedHop', None) is not None:
-            return self._properties.get('LtLearnedHop')
-        else:
-            return LtLearnedHop(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('LtLearnedHop', None) is not None:
+                return self._properties.get('LtLearnedHop')
+        return LtLearnedHop(self)
 
     @property
     def AverageHopCount(self):
