@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Protocols(Base):
@@ -53,10 +55,10 @@ class Protocols(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.arp_067eba21ef07a3fc09f15f554aa27f62 import Arp
-        if self._properties.get('Arp', None) is not None:
-            return self._properties.get('Arp')
-        else:
-            return Arp(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Arp', None) is not None:
+                return self._properties.get('Arp')
+        return Arp(self)
 
     @property
     def Bfd(self):
@@ -70,10 +72,10 @@ class Protocols(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bfd_13635869671ecd9754ea8412fc59454e import Bfd
-        if self._properties.get('Bfd', None) is not None:
-            return self._properties.get('Bfd')
-        else:
-            return Bfd(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Bfd', None) is not None:
+                return self._properties.get('Bfd')
+        return Bfd(self)._select()
 
     @property
     def Bgp(self):
@@ -87,10 +89,10 @@ class Protocols(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp_3e6d8e0b1b17db8a0c58ab51996aae2b import Bgp
-        if self._properties.get('Bgp', None) is not None:
-            return self._properties.get('Bgp')
-        else:
-            return Bgp(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Bgp', None) is not None:
+                return self._properties.get('Bgp')
+        return Bgp(self)._select()
 
     @property
     def Cfm(self):
@@ -104,10 +106,10 @@ class Protocols(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.cfm_f86ba26f5f0b238d459dfdf495bb75c0 import Cfm
-        if self._properties.get('Cfm', None) is not None:
-            return self._properties.get('Cfm')
-        else:
-            return Cfm(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Cfm', None) is not None:
+                return self._properties.get('Cfm')
+        return Cfm(self)._select()
 
     @property
     def Eigrp(self):
@@ -121,10 +123,10 @@ class Protocols(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.eigrp_87f33acf176dcbe78849cf8e8791c70d import Eigrp
-        if self._properties.get('Eigrp', None) is not None:
-            return self._properties.get('Eigrp')
-        else:
-            return Eigrp(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Eigrp', None) is not None:
+                return self._properties.get('Eigrp')
+        return Eigrp(self)._select()
 
     @property
     def Elmi(self):
@@ -138,10 +140,10 @@ class Protocols(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.elmi_701893b9b99429bda254793bfb384df2 import Elmi
-        if self._properties.get('Elmi', None) is not None:
-            return self._properties.get('Elmi')
-        else:
-            return Elmi(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Elmi', None) is not None:
+                return self._properties.get('Elmi')
+        return Elmi(self)._select()
 
     @property
     def Igmp(self):
@@ -155,10 +157,10 @@ class Protocols(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.igmp_5181803aa94412c9279b9f387c23a716 import Igmp
-        if self._properties.get('Igmp', None) is not None:
-            return self._properties.get('Igmp')
-        else:
-            return Igmp(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Igmp', None) is not None:
+                return self._properties.get('Igmp')
+        return Igmp(self)._select()
 
     @property
     def Isis(self):
@@ -172,10 +174,10 @@ class Protocols(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis_050bb4482a1df0a3d61c7b64496e330d import Isis
-        if self._properties.get('Isis', None) is not None:
-            return self._properties.get('Isis')
-        else:
-            return Isis(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Isis', None) is not None:
+                return self._properties.get('Isis')
+        return Isis(self)._select()
 
     @property
     def Lacp(self):
@@ -189,10 +191,10 @@ class Protocols(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.lacp_2de629e1f1c006bff7fad33825e4d91b import Lacp
-        if self._properties.get('Lacp', None) is not None:
-            return self._properties.get('Lacp')
-        else:
-            return Lacp(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Lacp', None) is not None:
+                return self._properties.get('Lacp')
+        return Lacp(self)._select()
 
     @property
     def Ldp(self):
@@ -206,10 +208,10 @@ class Protocols(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ldp_da338dbe787e89d2068f6bd186367c37 import Ldp
-        if self._properties.get('Ldp', None) is not None:
-            return self._properties.get('Ldp')
-        else:
-            return Ldp(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Ldp', None) is not None:
+                return self._properties.get('Ldp')
+        return Ldp(self)._select()
 
     @property
     def LinkOam(self):
@@ -223,10 +225,10 @@ class Protocols(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.linkoam_efc27e762f17d4ddecbc0652ec4c7ac4 import LinkOam
-        if self._properties.get('LinkOam', None) is not None:
-            return self._properties.get('LinkOam')
-        else:
-            return LinkOam(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('LinkOam', None) is not None:
+                return self._properties.get('LinkOam')
+        return LinkOam(self)._select()
 
     @property
     def Lisp(self):
@@ -240,10 +242,10 @@ class Protocols(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.lisp_cfcf8310ab534e86e05d76bfc192cb8f import Lisp
-        if self._properties.get('Lisp', None) is not None:
-            return self._properties.get('Lisp')
-        else:
-            return Lisp(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Lisp', None) is not None:
+                return self._properties.get('Lisp')
+        return Lisp(self)._select()
 
     @property
     def Mld(self):
@@ -257,10 +259,10 @@ class Protocols(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.mld_addc243f110a2e6cdaa60cfde19d5efe import Mld
-        if self._properties.get('Mld', None) is not None:
-            return self._properties.get('Mld')
-        else:
-            return Mld(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Mld', None) is not None:
+                return self._properties.get('Mld')
+        return Mld(self)._select()
 
     @property
     def MplsOam(self):
@@ -274,10 +276,10 @@ class Protocols(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.mplsoam_e3ac69344e2bf92870f02216ee81dec3 import MplsOam
-        if self._properties.get('MplsOam', None) is not None:
-            return self._properties.get('MplsOam')
-        else:
-            return MplsOam(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('MplsOam', None) is not None:
+                return self._properties.get('MplsOam')
+        return MplsOam(self)._select()
 
     @property
     def MplsTp(self):
@@ -291,10 +293,10 @@ class Protocols(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.mplstp_8fb90eb694dc0efb0ff6a231453357c5 import MplsTp
-        if self._properties.get('MplsTp', None) is not None:
-            return self._properties.get('MplsTp')
-        else:
-            return MplsTp(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('MplsTp', None) is not None:
+                return self._properties.get('MplsTp')
+        return MplsTp(self)._select()
 
     @property
     def OpenFlow(self):
@@ -308,10 +310,10 @@ class Protocols(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow_81b0892fb793919c2b8ec714a09eb3dc import OpenFlow
-        if self._properties.get('OpenFlow', None) is not None:
-            return self._properties.get('OpenFlow')
-        else:
-            return OpenFlow(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('OpenFlow', None) is not None:
+                return self._properties.get('OpenFlow')
+        return OpenFlow(self)._select()
 
     @property
     def Ospf(self):
@@ -325,10 +327,10 @@ class Protocols(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ospf_e7cbc892bf16b0ebe7b056298a38b949 import Ospf
-        if self._properties.get('Ospf', None) is not None:
-            return self._properties.get('Ospf')
-        else:
-            return Ospf(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Ospf', None) is not None:
+                return self._properties.get('Ospf')
+        return Ospf(self)._select()
 
     @property
     def OspfV3(self):
@@ -342,10 +344,10 @@ class Protocols(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ospfv3_fd46b6ab89f8ad7a237ac12140f8a863 import OspfV3
-        if self._properties.get('OspfV3', None) is not None:
-            return self._properties.get('OspfV3')
-        else:
-            return OspfV3(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('OspfV3', None) is not None:
+                return self._properties.get('OspfV3')
+        return OspfV3(self)._select()
 
     @property
     def Pimsm(self):
@@ -359,10 +361,10 @@ class Protocols(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.pimsm_5b2c0eab6298f36b1362558022b2d248 import Pimsm
-        if self._properties.get('Pimsm', None) is not None:
-            return self._properties.get('Pimsm')
-        else:
-            return Pimsm(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Pimsm', None) is not None:
+                return self._properties.get('Pimsm')
+        return Pimsm(self)._select()
 
     @property
     def Ping(self):
@@ -376,10 +378,10 @@ class Protocols(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ping_95a393f5ad3a6b0c563501c39f382cae import Ping
-        if self._properties.get('Ping', None) is not None:
-            return self._properties.get('Ping')
-        else:
-            return Ping(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Ping', None) is not None:
+                return self._properties.get('Ping')
+        return Ping(self)
 
     @property
     def Rip(self):
@@ -393,10 +395,10 @@ class Protocols(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.rip_e819d24fd3ca51fc2aa4d2bb9ad9b9e2 import Rip
-        if self._properties.get('Rip', None) is not None:
-            return self._properties.get('Rip')
-        else:
-            return Rip(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Rip', None) is not None:
+                return self._properties.get('Rip')
+        return Rip(self)._select()
 
     @property
     def Ripng(self):
@@ -410,10 +412,10 @@ class Protocols(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ripng_ba15454897784b789bbbbfa92adc4ccd import Ripng
-        if self._properties.get('Ripng', None) is not None:
-            return self._properties.get('Ripng')
-        else:
-            return Ripng(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Ripng', None) is not None:
+                return self._properties.get('Ripng')
+        return Ripng(self)._select()
 
     @property
     def Rsvp(self):
@@ -427,10 +429,10 @@ class Protocols(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.rsvp_1a88cb229a9aae7ce8ea61139e8fb910 import Rsvp
-        if self._properties.get('Rsvp', None) is not None:
-            return self._properties.get('Rsvp')
-        else:
-            return Rsvp(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Rsvp', None) is not None:
+                return self._properties.get('Rsvp')
+        return Rsvp(self)._select()
 
     @property
     def Static(self):
@@ -444,10 +446,10 @@ class Protocols(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.static_5795de030fada71c167436cb330786b5 import Static
-        if self._properties.get('Static', None) is not None:
-            return self._properties.get('Static')
-        else:
-            return Static(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Static', None) is not None:
+                return self._properties.get('Static')
+        return Static(self)._select()
 
     @property
     def Stp(self):
@@ -461,10 +463,10 @@ class Protocols(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.stp_af850ad90f47656e0033090898ef0f0c import Stp
-        if self._properties.get('Stp', None) is not None:
-            return self._properties.get('Stp')
-        else:
-            return Stp(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Stp', None) is not None:
+                return self._properties.get('Stp')
+        return Stp(self)._select()
 
     @property
     def ProtocolMaxNodeCount(self):
