@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Querier(Base):
@@ -75,10 +77,10 @@ class Querier(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.learnedgroupinfo_2a29d64cca00be921881c56ed37adcf6 import LearnedGroupInfo
-        if self._properties.get('LearnedGroupInfo', None) is not None:
-            return self._properties.get('LearnedGroupInfo')
-        else:
-            return LearnedGroupInfo(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('LearnedGroupInfo', None) is not None:
+                return self._properties.get('LearnedGroupInfo')
+        return LearnedGroupInfo(self)
 
     @property
     def DiscardLearnedInfo(self):
