@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Router(Base):
@@ -72,10 +74,10 @@ class Router(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.interface_c3c911144789a78964958c3c7bd601dc import Interface
-        if self._properties.get('Interface', None) is not None:
-            return self._properties.get('Interface')
-        else:
-            return Interface(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Interface', None) is not None:
+                return self._properties.get('Interface')
+        return Interface(self)
 
     @property
     def LearnedRoute(self):
@@ -89,10 +91,10 @@ class Router(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.learnedroute_d56ac825d7af435a1cbaf25c843e97e3 import LearnedRoute
-        if self._properties.get('LearnedRoute', None) is not None:
-            return self._properties.get('LearnedRoute')
-        else:
-            return LearnedRoute(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('LearnedRoute', None) is not None:
+                return self._properties.get('LearnedRoute')
+        return LearnedRoute(self)
 
     @property
     def RouteRange(self):
@@ -106,10 +108,10 @@ class Router(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.routerange_de59685b76fa73e61393f9afda789105 import RouteRange
-        if self._properties.get('RouteRange', None) is not None:
-            return self._properties.get('RouteRange')
-        else:
-            return RouteRange(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('RouteRange', None) is not None:
+                return self._properties.get('RouteRange')
+        return RouteRange(self)
 
     @property
     def ActiveTime(self):
