@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class RouteRange(Base):
@@ -97,10 +99,10 @@ class RouteRange(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.assegment_25ab3214c0c84c6c786d9e2b3d4cdf0e import AsSegment
-        if self._properties.get('AsSegment', None) is not None:
-            return self._properties.get('AsSegment')
-        else:
-            return AsSegment(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('AsSegment', None) is not None:
+                return self._properties.get('AsSegment')
+        return AsSegment(self)._select()
 
     @property
     def Cluster(self):
@@ -114,10 +116,10 @@ class RouteRange(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.cluster_68bd2583b0e1823a0ae210f6a0c8d70c import Cluster
-        if self._properties.get('Cluster', None) is not None:
-            return self._properties.get('Cluster')
-        else:
-            return Cluster(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Cluster', None) is not None:
+                return self._properties.get('Cluster')
+        return Cluster(self)._select()
 
     @property
     def Community(self):
@@ -131,10 +133,10 @@ class RouteRange(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.community_95636df7171c99766f0e15bfbccad02d import Community
-        if self._properties.get('Community', None) is not None:
-            return self._properties.get('Community')
-        else:
-            return Community(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Community', None) is not None:
+                return self._properties.get('Community')
+        return Community(self)._select()
 
     @property
     def ExtendedCommunity(self):
@@ -148,10 +150,10 @@ class RouteRange(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.extendedcommunity_1dea3b4b2127a9e11303811fee71411b import ExtendedCommunity
-        if self._properties.get('ExtendedCommunity', None) is not None:
-            return self._properties.get('ExtendedCommunity')
-        else:
-            return ExtendedCommunity(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('ExtendedCommunity', None) is not None:
+                return self._properties.get('ExtendedCommunity')
+        return ExtendedCommunity(self)._select()
 
     @property
     def Flapping(self):
@@ -165,10 +167,10 @@ class RouteRange(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.flapping_7cd710597ec8a94d40bed7d06822e7f9 import Flapping
-        if self._properties.get('Flapping', None) is not None:
-            return self._properties.get('Flapping')
-        else:
-            return Flapping(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Flapping', None) is not None:
+                return self._properties.get('Flapping')
+        return Flapping(self)._select()
 
     @property
     def AdvertiseNextHopAsV4(self):
