@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Source(Base):
@@ -71,10 +73,10 @@ class Source(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.learnedsgstate_c1d817b3ff4555626a3e21c83fda8c45 import LearnedSgState
-        if self._properties.get('LearnedSgState', None) is not None:
-            return self._properties.get('LearnedSgState')
-        else:
-            return LearnedSgState(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('LearnedSgState', None) is not None:
+                return self._properties.get('LearnedSgState')
+        return LearnedSgState(self)
 
     @property
     def DiscardSgJoinStates(self):
