@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class SpbBaseVidRange(Base):
@@ -60,10 +62,10 @@ class SpbBaseVidRange(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.spbisidrange_31c007fedf45d93a5e16f9377610bf83 import SpbIsIdRange
-        if self._properties.get('SpbIsIdRange', None) is not None:
-            return self._properties.get('SpbIsIdRange')
-        else:
-            return SpbIsIdRange(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('SpbIsIdRange', None) is not None:
+                return self._properties.get('SpbIsIdRange')
+        return SpbIsIdRange(self)
 
     @property
     def BMacAddress(self):
