@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class SpbmNodeBaseVidRange(Base):
@@ -58,10 +60,10 @@ class SpbmNodeBaseVidRange(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.spbmnodeisidrange_ce5aa3fd54769fa53d910c12b9b3cddb import SpbmNodeIsIdRange
-        if self._properties.get('SpbmNodeIsIdRange', None) is not None:
-            return self._properties.get('SpbmNodeIsIdRange')
-        else:
-            return SpbmNodeIsIdRange(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('SpbmNodeIsIdRange', None) is not None:
+                return self._properties.get('SpbmNodeIsIdRange')
+        return SpbmNodeIsIdRange(self)
 
     @property
     def BVlanPriority(self):
