@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class SpbmNodeTopologyRange(Base):
@@ -64,10 +66,10 @@ class SpbmNodeTopologyRange(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.spbmnodebasevidrange_85f95f8cdb0a1237fbe8b8d83aa8f732 import SpbmNodeBaseVidRange
-        if self._properties.get('SpbmNodeBaseVidRange', None) is not None:
-            return self._properties.get('SpbmNodeBaseVidRange')
-        else:
-            return SpbmNodeBaseVidRange(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('SpbmNodeBaseVidRange', None) is not None:
+                return self._properties.get('SpbmNodeBaseVidRange')
+        return SpbmNodeBaseVidRange(self)
 
     @property
     def BridgePriority(self):
