@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class SwitchGroupLearnedInfo(Base):
@@ -64,10 +66,10 @@ class SwitchGroupLearnedInfo(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.switchgroupbucketlearnedinfo_9a65c5052010d8a7d3ba2272e133999d import SwitchGroupBucketLearnedInfo
-        if self._properties.get('SwitchGroupBucketLearnedInfo', None) is not None:
-            return self._properties.get('SwitchGroupBucketLearnedInfo')
-        else:
-            return SwitchGroupBucketLearnedInfo(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('SwitchGroupBucketLearnedInfo', None) is not None:
+                return self._properties.get('SwitchGroupBucketLearnedInfo')
+        return SwitchGroupBucketLearnedInfo(self)
 
     @property
     def ByteCount(self):
