@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class SwitchHostRangeLearnedInfo(Base):
@@ -59,10 +61,10 @@ class SwitchHostRangeLearnedInfo(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.switchhostrangehopslearnedinfo_644eba5a33f6c4a8b40b153ae361c253 import SwitchHostRangeHopsLearnedInfo
-        if self._properties.get('SwitchHostRangeHopsLearnedInfo', None) is not None:
-            return self._properties.get('SwitchHostRangeHopsLearnedInfo')
-        else:
-            return SwitchHostRangeHopsLearnedInfo(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('SwitchHostRangeHopsLearnedInfo', None) is not None:
+                return self._properties.get('SwitchHostRangeHopsLearnedInfo')
+        return SwitchHostRangeHopsLearnedInfo(self)
 
     @property
     def DestinationHostIpv4Address(self):
