@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class SwitchOfChannel(Base):
@@ -56,10 +58,10 @@ class SwitchOfChannel(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.auxiliaryconnection_11b6533324088391328dd0b4470f73c4 import AuxiliaryConnection
-        if self._properties.get('AuxiliaryConnection', None) is not None:
-            return self._properties.get('AuxiliaryConnection')
-        else:
-            return AuxiliaryConnection(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('AuxiliaryConnection', None) is not None:
+                return self._properties.get('AuxiliaryConnection')
+        return AuxiliaryConnection(self)
 
     @property
     def Description(self):
