@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class SwitchTables(Base):
@@ -57,10 +59,10 @@ class SwitchTables(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.wildcardssupported_7f90a3dda0d8f10c99f0019fb1ddbad1 import WildcardsSupported
-        if self._properties.get('WildcardsSupported', None) is not None:
-            return self._properties.get('WildcardsSupported')
-        else:
-            return WildcardsSupported(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('WildcardsSupported', None) is not None:
+                return self._properties.get('WildcardsSupported')
+        return WildcardsSupported(self)._select()
 
     @property
     def MaxEntries(self):
