@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class UniStatus(Base):
@@ -58,10 +60,10 @@ class UniStatus(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bwprofile_2186baa3e35d08e24139c4a9eabaaaca import BwProfile
-        if self._properties.get('BwProfile', None) is not None:
-            return self._properties.get('BwProfile')
-        else:
-            return BwProfile(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('BwProfile', None) is not None:
+                return self._properties.get('BwProfile')
+        return BwProfile(self)
 
     @property
     def CeVlanIdEvcMapType(self):
