@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Vlans(Base):
@@ -62,10 +64,10 @@ class Vlans(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.macranges_7d9b9c7989bc1d3958915290660de5e7 import MacRanges
-        if self._properties.get('MacRanges', None) is not None:
-            return self._properties.get('MacRanges')
-        else:
-            return MacRanges(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('MacRanges', None) is not None:
+                return self._properties.get('MacRanges')
+        return MacRanges(self)
 
     @property
     def CVlanId(self):
