@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Wildcards(Base):
@@ -56,10 +58,10 @@ class Wildcards(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.wildcardsfields_a9d755a9e53cafc314f8e288acc0e118 import WildcardsFields
-        if self._properties.get('WildcardsFields', None) is not None:
-            return self._properties.get('WildcardsFields')
-        else:
-            return WildcardsFields(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('WildcardsFields', None) is not None:
+                return self._properties.get('WildcardsFields')
+        return WildcardsFields(self)._select()
 
     @property
     def ExperimenterData(self):
@@ -148,3 +150,47 @@ class Wildcards(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def find(self, ExperimenterData=None, ExperimenterDataLength=None, ExperimenterField=None, ExperimenterHasMask=None, ExperimenterId=None):
+        # type: (str, int, int, bool, int) -> Wildcards
+        """Finds and retrieves wildcards resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve wildcards resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all wildcards resources from the server.
+
+        Args
+        ----
+        - ExperimenterData (str): NOT DEFINED
+        - ExperimenterDataLength (number): NOT DEFINED
+        - ExperimenterField (number): NOT DEFINED
+        - ExperimenterHasMask (bool): NOT DEFINED
+        - ExperimenterId (number): NOT DEFINED
+
+        Returns
+        -------
+        - self: This instance with matching wildcards resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of wildcards data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the wildcards resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
