@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class WriteSetField(Base):
@@ -51,10 +53,10 @@ class WriteSetField(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.fields_28cbe17a5108f2df364f0596858829d7 import Fields
-        if self._properties.get('Fields', None) is not None:
-            return self._properties.get('Fields')
-        else:
-            return Fields(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Fields', None) is not None:
+                return self._properties.get('Fields')
+        return Fields(self)._select()
 
     @property
     def MissFields(self):
@@ -68,7 +70,42 @@ class WriteSetField(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.missfields_2a6ef672a75b7629c32ad54be7848261 import MissFields
-        if self._properties.get('MissFields', None) is not None:
-            return self._properties.get('MissFields')
-        else:
-            return MissFields(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('MissFields', None) is not None:
+                return self._properties.get('MissFields')
+        return MissFields(self)._select()
+
+    def find(self):
+        """Finds and retrieves writeSetField resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve writeSetField resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all writeSetField resources from the server.
+
+        Returns
+        -------
+        - self: This instance with matching writeSetField resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of writeSetField data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the writeSetField resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
