@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class DcbxTlvAppQaz(Base):
@@ -52,10 +54,10 @@ class DcbxTlvAppQaz(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.dcbxapppriorityatt_ad5afe5a2771fcd58c880d8c0a2d3eac import DcbxAppPriorityAtt
-        if self._properties.get('DcbxAppPriorityAtt', None) is not None:
-            return self._properties.get('DcbxAppPriorityAtt')
-        else:
-            return DcbxAppPriorityAtt(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('DcbxAppPriorityAtt', None) is not None:
+                return self._properties.get('DcbxAppPriorityAtt')
+        return DcbxAppPriorityAtt(self)
 
     @property
     def ObjectId(self):
@@ -67,6 +69,46 @@ class DcbxTlvAppQaz(Base):
         """
         return self._get_attribute(self._SDM_ATT_MAP['ObjectId'])
 
+    def find(self, ObjectId=None):
+        # type: (str) -> DcbxTlvAppQaz
+        """Finds and retrieves dcbxTlvAppQaz resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve dcbxTlvAppQaz resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all dcbxTlvAppQaz resources from the server.
+
+        Args
+        ----
+        - ObjectId (str): Unique identifier for this object
+
+        Returns
+        -------
+        - self: This instance with matching dcbxTlvAppQaz resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of dcbxTlvAppQaz data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the dcbxTlvAppQaz resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def CustomProtocolStack(self, *args, **kwargs):
         # type: (*Any, **Any) -> None
         """Executes the customProtocolStack operation on the server.
