@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class DcbxTlvFcoeIeee(Base):
@@ -54,10 +56,10 @@ class DcbxTlvFcoeIeee(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.dcbxappprotocolatt_2e346b595f8b35ca6c55e19c7a16f30b import DcbxAppProtocolAtt
-        if self._properties.get('DcbxAppProtocolAtt', None) is not None:
-            return self._properties.get('DcbxAppProtocolAtt')
-        else:
-            return DcbxAppProtocolAtt(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('DcbxAppProtocolAtt', None) is not None:
+                return self._properties.get('DcbxAppProtocolAtt')
+        return DcbxAppProtocolAtt(self)
 
     @property
     def ApplicationProtocolId(self):
@@ -112,6 +114,48 @@ class DcbxTlvFcoeIeee(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, ApplicationProtocolId=None, ObjectId=None, PriorityMap=None):
+        # type: (int, str, List[int]) -> DcbxTlvFcoeIeee
+        """Finds and retrieves dcbxTlvFcoeIeee resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve dcbxTlvFcoeIeee resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all dcbxTlvFcoeIeee resources from the server.
+
+        Args
+        ----
+        - ApplicationProtocolId (number): Identifies protocol supported by DCB node.
+        - ObjectId (str): Unique identifier for this object
+        - PriorityMap (list(number)): 
+
+        Returns
+        -------
+        - self: This instance with matching dcbxTlvFcoeIeee resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of dcbxTlvFcoeIeee data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the dcbxTlvFcoeIeee resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def CustomProtocolStack(self, *args, **kwargs):
         # type: (*Any, **Any) -> None
         """Executes the customProtocolStack operation on the server.
