@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class DcbxTlvPgIeee(Base):
@@ -111,6 +113,49 @@ class DcbxTlvPgIeee(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, ObjectId=None, PriorityGroupIdMap=None, PriorityGroupPercentageMap=None, TcsSupported=None):
+        # type: (str, List[int], List[int], int) -> DcbxTlvPgIeee
+        """Finds and retrieves dcbxTlvPgIeee resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve dcbxTlvPgIeee resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all dcbxTlvPgIeee resources from the server.
+
+        Args
+        ----
+        - ObjectId (str): Unique identifier for this object
+        - PriorityGroupIdMap (list(number)): Priority group ID associated to each priority.
+        - PriorityGroupPercentageMap (list(number)): Percentage associated to each priority group id.
+        - TcsSupported (number): Number of traffic classes supported by device.
+
+        Returns
+        -------
+        - self: This instance with matching dcbxTlvPgIeee resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of dcbxTlvPgIeee data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the dcbxTlvPgIeee resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def CustomProtocolStack(self, *args, **kwargs):
         # type: (*Any, **Any) -> None
         """Executes the customProtocolStack operation on the server.
