@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class DcbxTlvPgIntel(Base):
@@ -53,10 +55,10 @@ class DcbxTlvPgIntel(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.dcbxbandwidthatt_cad3437aaadac972672f666f54aba6c1 import DcbxBandwidthAtt
-        if self._properties.get('DcbxBandwidthAtt', None) is not None:
-            return self._properties.get('DcbxBandwidthAtt')
-        else:
-            return DcbxBandwidthAtt(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('DcbxBandwidthAtt', None) is not None:
+                return self._properties.get('DcbxBandwidthAtt')
+        return DcbxBandwidthAtt(self)
 
     @property
     def BwGroupPercentageMap(self):
@@ -96,6 +98,47 @@ class DcbxTlvPgIntel(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, BwGroupPercentageMap=None, ObjectId=None):
+        # type: (List[int], str) -> DcbxTlvPgIntel
+        """Finds and retrieves dcbxTlvPgIntel resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve dcbxTlvPgIntel resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all dcbxTlvPgIntel resources from the server.
+
+        Args
+        ----
+        - BwGroupPercentageMap (list(number)): Percentage associated to each bandwidth group id.
+        - ObjectId (str): Unique identifier for this object
+
+        Returns
+        -------
+        - self: This instance with matching dcbxTlvPgIntel resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of dcbxTlvPgIntel data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the dcbxTlvPgIntel resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def CustomProtocolStack(self, *args, **kwargs):
         # type: (*Any, **Any) -> None
         """Executes the customProtocolStack operation on the server.
