@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class LldpTlvOui(Base):
@@ -111,6 +113,49 @@ class LldpTlvOui(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, Info=None, ObjectId=None, Oui=None, Subtype=None):
+        # type: (str, str, str, int) -> LldpTlvOui
+        """Finds and retrieves lldpTlvOui resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve lldpTlvOui resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all lldpTlvOui resources from the server.
+
+        Args
+        ----
+        - Info (str): Information String.
+        - ObjectId (str): Unique identifier for this object
+        - Oui (str): OUI.
+        - Subtype (number): OUI Subtype
+
+        Returns
+        -------
+        - self: This instance with matching lldpTlvOui resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of lldpTlvOui data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the lldpTlvOui resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def CustomProtocolStack(self, *args, **kwargs):
         # type: (*Any, **Any) -> None
         """Executes the customProtocolStack operation on the server.
