@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class PcrfSecondaryRange(Base):
@@ -53,10 +55,10 @@ class PcrfSecondaryRange(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.egtpsgwrange_a17afcadb647de23d7549f587f45d27e import EgtpSgwRange
-        if self._properties.get('EgtpSgwRange', None) is not None:
-            return self._properties.get('EgtpSgwRange')
-        else:
-            return EgtpSgwRange(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('EgtpSgwRange', None) is not None:
+                return self._properties.get('EgtpSgwRange')
+        return EgtpSgwRange(self)._select()
 
     def add(self):
         """Adds a new pcrfSecondaryRange resource on the server and adds it to the container.
