@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class ProtocolStack(Base):
@@ -52,10 +54,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.amtoptions_b8687d0aa450eedabad5937a3dd0d921 import AmtOptions
-        if self._properties.get('AmtOptions', None) is not None:
-            return self._properties.get('AmtOptions')
-        else:
-            return AmtOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('AmtOptions', None) is not None:
+                return self._properties.get('AmtOptions')
+        return AmtOptions(self)
 
     @property
     def AncpOptions(self):
@@ -69,10 +71,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.ancpoptions_60d2d5e33cccc1428aa5ab66090e545f import AncpOptions
-        if self._properties.get('AncpOptions', None) is not None:
-            return self._properties.get('AncpOptions')
-        else:
-            return AncpOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('AncpOptions', None) is not None:
+                return self._properties.get('AncpOptions')
+        return AncpOptions(self)
 
     @property
     def DhcpHostsOptions(self):
@@ -86,10 +88,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.dhcphostsoptions_191fedb8ef50cd521c12d7ded5cc3bc5 import DhcpHostsOptions
-        if self._properties.get('DhcpHostsOptions', None) is not None:
-            return self._properties.get('DhcpHostsOptions')
-        else:
-            return DhcpHostsOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('DhcpHostsOptions', None) is not None:
+                return self._properties.get('DhcpHostsOptions')
+        return DhcpHostsOptions(self)
 
     @property
     def DhcpOptions(self):
@@ -103,10 +105,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.dhcpoptions_9729e8bd162874e29097793e120e81b6 import DhcpOptions
-        if self._properties.get('DhcpOptions', None) is not None:
-            return self._properties.get('DhcpOptions')
-        else:
-            return DhcpOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('DhcpOptions', None) is not None:
+                return self._properties.get('DhcpOptions')
+        return DhcpOptions(self)
 
     @property
     def Dhcpv6ClientOptions(self):
@@ -120,10 +122,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.dhcpv6clientoptions_132f5e3e6310e86ccbbac482ccd94671 import Dhcpv6ClientOptions
-        if self._properties.get('Dhcpv6ClientOptions', None) is not None:
-            return self._properties.get('Dhcpv6ClientOptions')
-        else:
-            return Dhcpv6ClientOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Dhcpv6ClientOptions', None) is not None:
+                return self._properties.get('Dhcpv6ClientOptions')
+        return Dhcpv6ClientOptions(self)
 
     @property
     def Dhcpv6PdClientOptions(self):
@@ -137,10 +139,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.dhcpv6pdclientoptions_bd222f1628f075889e823bc4a6e1f541 import Dhcpv6PdClientOptions
-        if self._properties.get('Dhcpv6PdClientOptions', None) is not None:
-            return self._properties.get('Dhcpv6PdClientOptions')
-        else:
-            return Dhcpv6PdClientOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Dhcpv6PdClientOptions', None) is not None:
+                return self._properties.get('Dhcpv6PdClientOptions')
+        return Dhcpv6PdClientOptions(self)
 
     @property
     def Dhcpv6ServerOptions(self):
@@ -154,10 +156,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.dhcpv6serveroptions_53ee0b2472ff273e656afeded14cc6a7 import Dhcpv6ServerOptions
-        if self._properties.get('Dhcpv6ServerOptions', None) is not None:
-            return self._properties.get('Dhcpv6ServerOptions')
-        else:
-            return Dhcpv6ServerOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Dhcpv6ServerOptions', None) is not None:
+                return self._properties.get('Dhcpv6ServerOptions')
+        return Dhcpv6ServerOptions(self)
 
     @property
     def Dot1xOptions(self):
@@ -171,10 +173,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.dot1xoptions_c27d674f9a6209c0c34607209e0a9bac import Dot1xOptions
-        if self._properties.get('Dot1xOptions', None) is not None:
-            return self._properties.get('Dot1xOptions')
-        else:
-            return Dot1xOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Dot1xOptions', None) is not None:
+                return self._properties.get('Dot1xOptions')
+        return Dot1xOptions(self)
 
     @property
     def EapoUdpOptions(self):
@@ -188,10 +190,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.eapoudpoptions_f04b43d99a8c8e63cc9e7d622d06bfd6 import EapoUdpOptions
-        if self._properties.get('EapoUdpOptions', None) is not None:
-            return self._properties.get('EapoUdpOptions')
-        else:
-            return EapoUdpOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('EapoUdpOptions', None) is not None:
+                return self._properties.get('EapoUdpOptions')
+        return EapoUdpOptions(self)
 
     @property
     def EgtpClientOptions(self):
@@ -205,10 +207,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.egtpclientoptions_31e0757ccf11d7e1c6855fdd46442542 import EgtpClientOptions
-        if self._properties.get('EgtpClientOptions', None) is not None:
-            return self._properties.get('EgtpClientOptions')
-        else:
-            return EgtpClientOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('EgtpClientOptions', None) is not None:
+                return self._properties.get('EgtpClientOptions')
+        return EgtpClientOptions(self)
 
     @property
     def EgtpOptionsBase(self):
@@ -222,10 +224,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.egtpoptionsbase_32e4941bfba82166b4f883cdd51ee159 import EgtpOptionsBase
-        if self._properties.get('EgtpOptionsBase', None) is not None:
-            return self._properties.get('EgtpOptionsBase')
-        else:
-            return EgtpOptionsBase(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('EgtpOptionsBase', None) is not None:
+                return self._properties.get('EgtpOptionsBase')
+        return EgtpOptionsBase(self)
 
     @property
     def EgtpS5S8PgwOptions(self):
@@ -239,10 +241,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.egtps5s8pgwoptions_dadee44b5f7ce54b3b4f2cf31bab949e import EgtpS5S8PgwOptions
-        if self._properties.get('EgtpS5S8PgwOptions', None) is not None:
-            return self._properties.get('EgtpS5S8PgwOptions')
-        else:
-            return EgtpS5S8PgwOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('EgtpS5S8PgwOptions', None) is not None:
+                return self._properties.get('EgtpS5S8PgwOptions')
+        return EgtpS5S8PgwOptions(self)
 
     @property
     def EgtpS5S8SgwOptions(self):
@@ -256,10 +258,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.egtps5s8sgwoptions_9c9b6793368b14b5dae66276ece6b8df import EgtpS5S8SgwOptions
-        if self._properties.get('EgtpS5S8SgwOptions', None) is not None:
-            return self._properties.get('EgtpS5S8SgwOptions')
-        else:
-            return EgtpS5S8SgwOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('EgtpS5S8SgwOptions', None) is not None:
+                return self._properties.get('EgtpS5S8SgwOptions')
+        return EgtpS5S8SgwOptions(self)
 
     @property
     def EgtpServerOptions(self):
@@ -273,10 +275,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.egtpserveroptions_f4463e6fa600456177448ed49c1d5b23 import EgtpServerOptions
-        if self._properties.get('EgtpServerOptions', None) is not None:
-            return self._properties.get('EgtpServerOptions')
-        else:
-            return EgtpServerOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('EgtpServerOptions', None) is not None:
+                return self._properties.get('EgtpServerOptions')
+        return EgtpServerOptions(self)
 
     @property
     def EgtpSgwOptions(self):
@@ -290,10 +292,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.egtpsgwoptions_d547c3e160d4f868199b7631c4804e68 import EgtpSgwOptions
-        if self._properties.get('EgtpSgwOptions', None) is not None:
-            return self._properties.get('EgtpSgwOptions')
-        else:
-            return EgtpSgwOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('EgtpSgwOptions', None) is not None:
+                return self._properties.get('EgtpSgwOptions')
+        return EgtpSgwOptions(self)
 
     @property
     def Ethernet(self):
@@ -307,10 +309,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.ethernet_d38c7e88fb6f87dcc64e871cf7fb904c import Ethernet
-        if self._properties.get('Ethernet', None) is not None:
-            return self._properties.get('Ethernet')
-        else:
-            return Ethernet(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Ethernet', None) is not None:
+                return self._properties.get('Ethernet')
+        return Ethernet(self)
 
     @property
     def EthernetEndpoint(self):
@@ -324,10 +326,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.ethernetendpoint_07ba999c5a07ba0fd133662d8bd1eae1 import EthernetEndpoint
-        if self._properties.get('EthernetEndpoint', None) is not None:
-            return self._properties.get('EthernetEndpoint')
-        else:
-            return EthernetEndpoint(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('EthernetEndpoint', None) is not None:
+                return self._properties.get('EthernetEndpoint')
+        return EthernetEndpoint(self)
 
     @property
     def EthernetOptions(self):
@@ -341,10 +343,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.ethernetoptions_99c7302b2004441d3a0f14c74b218a11 import EthernetOptions
-        if self._properties.get('EthernetOptions', None) is not None:
-            return self._properties.get('EthernetOptions')
-        else:
-            return EthernetOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('EthernetOptions', None) is not None:
+                return self._properties.get('EthernetOptions')
+        return EthernetOptions(self)
 
     @property
     def FcClientEndpoint(self):
@@ -358,10 +360,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.fcclientendpoint_0bb27e24785b640285fd4c28890701c0 import FcClientEndpoint
-        if self._properties.get('FcClientEndpoint', None) is not None:
-            return self._properties.get('FcClientEndpoint')
-        else:
-            return FcClientEndpoint(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('FcClientEndpoint', None) is not None:
+                return self._properties.get('FcClientEndpoint')
+        return FcClientEndpoint(self)
 
     @property
     def FcClientOptions(self):
@@ -375,10 +377,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.fcclientoptions_27e93046b19664cb9a7956d0ce172eda import FcClientOptions
-        if self._properties.get('FcClientOptions', None) is not None:
-            return self._properties.get('FcClientOptions')
-        else:
-            return FcClientOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('FcClientOptions', None) is not None:
+                return self._properties.get('FcClientOptions')
+        return FcClientOptions(self)
 
     @property
     def FcFportFwdEndpoint(self):
@@ -392,10 +394,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.fcfportfwdendpoint_a42123f17fd448b552a019e1e0aaa650 import FcFportFwdEndpoint
-        if self._properties.get('FcFportFwdEndpoint', None) is not None:
-            return self._properties.get('FcFportFwdEndpoint')
-        else:
-            return FcFportFwdEndpoint(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('FcFportFwdEndpoint', None) is not None:
+                return self._properties.get('FcFportFwdEndpoint')
+        return FcFportFwdEndpoint(self)
 
     @property
     def FcFportOptions(self):
@@ -409,10 +411,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.fcfportoptions_a1c0042e98ef427e823313e5fbd2ff5c import FcFportOptions
-        if self._properties.get('FcFportOptions', None) is not None:
-            return self._properties.get('FcFportOptions')
-        else:
-            return FcFportOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('FcFportOptions', None) is not None:
+                return self._properties.get('FcFportOptions')
+        return FcFportOptions(self)
 
     @property
     def FcoeClientOptions(self):
@@ -426,10 +428,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.fcoeclientoptions_ddeb39bc9d33553718e9d9d5c5615515 import FcoeClientOptions
-        if self._properties.get('FcoeClientOptions', None) is not None:
-            return self._properties.get('FcoeClientOptions')
-        else:
-            return FcoeClientOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('FcoeClientOptions', None) is not None:
+                return self._properties.get('FcoeClientOptions')
+        return FcoeClientOptions(self)
 
     @property
     def FcoeFwdOptions(self):
@@ -443,10 +445,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.fcoefwdoptions_bc0e3c0717da470b08da39ad2c23c3e9 import FcoeFwdOptions
-        if self._properties.get('FcoeFwdOptions', None) is not None:
-            return self._properties.get('FcoeFwdOptions')
-        else:
-            return FcoeFwdOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('FcoeFwdOptions', None) is not None:
+                return self._properties.get('FcoeFwdOptions')
+        return FcoeFwdOptions(self)
 
     @property
     def IgmpOptions(self):
@@ -460,10 +462,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.igmpoptions_058462c51a289a750bb5b00d4485513a import IgmpOptions
-        if self._properties.get('IgmpOptions', None) is not None:
-            return self._properties.get('IgmpOptions')
-        else:
-            return IgmpOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('IgmpOptions', None) is not None:
+                return self._properties.get('IgmpOptions')
+        return IgmpOptions(self)
 
     @property
     def IpRangeOptions(self):
@@ -477,10 +479,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.iprangeoptions_54247ca6e830355df00053fbf4e307d5 import IpRangeOptions
-        if self._properties.get('IpRangeOptions', None) is not None:
-            return self._properties.get('IpRangeOptions')
-        else:
-            return IpRangeOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('IpRangeOptions', None) is not None:
+                return self._properties.get('IpRangeOptions')
+        return IpRangeOptions(self)
 
     @property
     def L2tpOptions(self):
@@ -494,10 +496,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.l2tpoptions_eeef014542cbd357c0dcccccc57550fc import L2tpOptions
-        if self._properties.get('L2tpOptions', None) is not None:
-            return self._properties.get('L2tpOptions')
-        else:
-            return L2tpOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('L2tpOptions', None) is not None:
+                return self._properties.get('L2tpOptions')
+        return L2tpOptions(self)
 
     @property
     def Options(self):
@@ -511,10 +513,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.options_b95a6091b48575c48d8806df541b4653 import Options
-        if self._properties.get('Options', None) is not None:
-            return self._properties.get('Options')
-        else:
-            return Options(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Options', None) is not None:
+                return self._properties.get('Options')
+        return Options(self)._select()
 
     @property
     def PppoxOptions(self):
@@ -528,10 +530,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.pppoxoptions_339cf64ae99c79e1d1492d14520ab152 import PppoxOptions
-        if self._properties.get('PppoxOptions', None) is not None:
-            return self._properties.get('PppoxOptions')
-        else:
-            return PppoxOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('PppoxOptions', None) is not None:
+                return self._properties.get('PppoxOptions')
+        return PppoxOptions(self)
 
     @property
     def PtpOptions(self):
@@ -545,10 +547,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.ptpoptions_4431aed535b415be014c5a79217aa3be import PtpOptions
-        if self._properties.get('PtpOptions', None) is not None:
-            return self._properties.get('PtpOptions')
-        else:
-            return PtpOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('PtpOptions', None) is not None:
+                return self._properties.get('PtpOptions')
+        return PtpOptions(self)
 
     @property
     def SmDnsOptions(self):
@@ -562,10 +564,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.smdnsoptions_100fbc7c6145703d8f1639aa93d794c3 import SmDnsOptions
-        if self._properties.get('SmDnsOptions', None) is not None:
-            return self._properties.get('SmDnsOptions')
-        else:
-            return SmDnsOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('SmDnsOptions', None) is not None:
+                return self._properties.get('SmDnsOptions')
+        return SmDnsOptions(self)
 
     @property
     def StaticHostsOptions(self):
@@ -579,10 +581,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.statichostsoptions_6108d519c1b8726625e78e54ace41b4d import StaticHostsOptions
-        if self._properties.get('StaticHostsOptions', None) is not None:
-            return self._properties.get('StaticHostsOptions')
-        else:
-            return StaticHostsOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('StaticHostsOptions', None) is not None:
+                return self._properties.get('StaticHostsOptions')
+        return StaticHostsOptions(self)
 
     @property
     def TwampOptions(self):
@@ -596,10 +598,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.twampoptions_7b39fa6f24cf29a2ce58f94dd349a195 import TwampOptions
-        if self._properties.get('TwampOptions', None) is not None:
-            return self._properties.get('TwampOptions')
-        else:
-            return TwampOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('TwampOptions', None) is not None:
+                return self._properties.get('TwampOptions')
+        return TwampOptions(self)
 
     @property
     def TwampServerOptions(self):
@@ -613,10 +615,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.twampserveroptions_b3351876a5276da5b361125d722f4b5a import TwampServerOptions
-        if self._properties.get('TwampServerOptions', None) is not None:
-            return self._properties.get('TwampServerOptions')
-        else:
-            return TwampServerOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('TwampServerOptions', None) is not None:
+                return self._properties.get('TwampServerOptions')
+        return TwampServerOptions(self)
 
     @property
     def VepaOptions(self):
@@ -630,10 +632,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.vepaoptions_bf2ac7071874877a35a42a8b0e4ce52c import VepaOptions
-        if self._properties.get('VepaOptions', None) is not None:
-            return self._properties.get('VepaOptions')
-        else:
-            return VepaOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('VepaOptions', None) is not None:
+                return self._properties.get('VepaOptions')
+        return VepaOptions(self)
 
     @property
     def WebAuthOptions(self):
@@ -647,10 +649,10 @@ class ProtocolStack(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.webauthoptions_57296c855047b64842a042992661d642 import WebAuthOptions
-        if self._properties.get('WebAuthOptions', None) is not None:
-            return self._properties.get('WebAuthOptions')
-        else:
-            return WebAuthOptions(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('WebAuthOptions', None) is not None:
+                return self._properties.get('WebAuthOptions')
+        return WebAuthOptions(self)
 
     @property
     def ObjectId(self):
@@ -662,6 +664,46 @@ class ProtocolStack(Base):
         """
         return self._get_attribute(self._SDM_ATT_MAP['ObjectId'])
 
+    def find(self, ObjectId=None):
+        # type: (str) -> ProtocolStack
+        """Finds and retrieves protocolStack resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve protocolStack resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all protocolStack resources from the server.
+
+        Args
+        ----
+        - ObjectId (str): Unique identifier for this object
+
+        Returns
+        -------
+        - self: This instance with matching protocolStack resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of protocolStack data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the protocolStack resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def CustomProtocolStack(self, *args, **kwargs):
         # type: (*Any, **Any) -> None
         """Executes the customProtocolStack operation on the server.
