@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class TlvSettings(Base):
@@ -52,10 +54,10 @@ class TlvSettings(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.dcbxtlvappqaz_02a35dfd3b5f648c7f668c46bd448d56 import DcbxTlvAppQaz
-        if self._properties.get('DcbxTlvAppQaz', None) is not None:
-            return self._properties.get('DcbxTlvAppQaz')
-        else:
-            return DcbxTlvAppQaz(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('DcbxTlvAppQaz', None) is not None:
+                return self._properties.get('DcbxTlvAppQaz')
+        return DcbxTlvAppQaz(self)._select()
 
     @property
     def DcbxTlvBcn(self):
@@ -69,10 +71,10 @@ class TlvSettings(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.dcbxtlvbcn_a1a91400db1d9914d85f42e65e5fca2b import DcbxTlvBcn
-        if self._properties.get('DcbxTlvBcn', None) is not None:
-            return self._properties.get('DcbxTlvBcn')
-        else:
-            return DcbxTlvBcn(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('DcbxTlvBcn', None) is not None:
+                return self._properties.get('DcbxTlvBcn')
+        return DcbxTlvBcn(self)._select()
 
     @property
     def DcbxTlvCustom(self):
@@ -86,10 +88,10 @@ class TlvSettings(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.dcbxtlvcustom_b8d4729d6e36738e0b8dea24089fa803 import DcbxTlvCustom
-        if self._properties.get('DcbxTlvCustom', None) is not None:
-            return self._properties.get('DcbxTlvCustom')
-        else:
-            return DcbxTlvCustom(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('DcbxTlvCustom', None) is not None:
+                return self._properties.get('DcbxTlvCustom')
+        return DcbxTlvCustom(self)._select()
 
     @property
     def DcbxTlvEtsQaz(self):
@@ -103,10 +105,10 @@ class TlvSettings(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.dcbxtlvetsqaz_721d7b3f4bd0a8d3b1cf166224740621 import DcbxTlvEtsQaz
-        if self._properties.get('DcbxTlvEtsQaz', None) is not None:
-            return self._properties.get('DcbxTlvEtsQaz')
-        else:
-            return DcbxTlvEtsQaz(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('DcbxTlvEtsQaz', None) is not None:
+                return self._properties.get('DcbxTlvEtsQaz')
+        return DcbxTlvEtsQaz(self)._select()
 
     @property
     def DcbxTlvFcoeIeee(self):
@@ -120,10 +122,10 @@ class TlvSettings(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.dcbxtlvfcoeieee_221a9d9374d868c351a083f39264f5c2 import DcbxTlvFcoeIeee
-        if self._properties.get('DcbxTlvFcoeIeee', None) is not None:
-            return self._properties.get('DcbxTlvFcoeIeee')
-        else:
-            return DcbxTlvFcoeIeee(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('DcbxTlvFcoeIeee', None) is not None:
+                return self._properties.get('DcbxTlvFcoeIeee')
+        return DcbxTlvFcoeIeee(self)._select()
 
     @property
     def DcbxTlvFcoeIntel(self):
@@ -137,10 +139,10 @@ class TlvSettings(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.dcbxtlvfcoeintel_49a1ef98a6702422b88b29433daab98c import DcbxTlvFcoeIntel
-        if self._properties.get('DcbxTlvFcoeIntel', None) is not None:
-            return self._properties.get('DcbxTlvFcoeIntel')
-        else:
-            return DcbxTlvFcoeIntel(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('DcbxTlvFcoeIntel', None) is not None:
+                return self._properties.get('DcbxTlvFcoeIntel')
+        return DcbxTlvFcoeIntel(self)._select()
 
     @property
     def DcbxTlvLogicalLink(self):
@@ -154,10 +156,10 @@ class TlvSettings(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.dcbxtlvlogicallink_4c1f796d4253ef800f469182f860034e import DcbxTlvLogicalLink
-        if self._properties.get('DcbxTlvLogicalLink', None) is not None:
-            return self._properties.get('DcbxTlvLogicalLink')
-        else:
-            return DcbxTlvLogicalLink(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('DcbxTlvLogicalLink', None) is not None:
+                return self._properties.get('DcbxTlvLogicalLink')
+        return DcbxTlvLogicalLink(self)._select()
 
     @property
     def DcbxTlvNivIeee(self):
@@ -171,10 +173,10 @@ class TlvSettings(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.dcbxtlvnivieee_bfda4ebaca3805fd204108031bec7a2c import DcbxTlvNivIeee
-        if self._properties.get('DcbxTlvNivIeee', None) is not None:
-            return self._properties.get('DcbxTlvNivIeee')
-        else:
-            return DcbxTlvNivIeee(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('DcbxTlvNivIeee', None) is not None:
+                return self._properties.get('DcbxTlvNivIeee')
+        return DcbxTlvNivIeee(self)._select()
 
     @property
     def DcbxTlvNivIntel(self):
@@ -188,10 +190,10 @@ class TlvSettings(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.dcbxtlvnivintel_9bc6d9fd29e6e3c4fb53c1924f821086 import DcbxTlvNivIntel
-        if self._properties.get('DcbxTlvNivIntel', None) is not None:
-            return self._properties.get('DcbxTlvNivIntel')
-        else:
-            return DcbxTlvNivIntel(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('DcbxTlvNivIntel', None) is not None:
+                return self._properties.get('DcbxTlvNivIntel')
+        return DcbxTlvNivIntel(self)._select()
 
     @property
     def DcbxTlvPfcIeee(self):
@@ -205,10 +207,10 @@ class TlvSettings(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.dcbxtlvpfcieee_5859cbed593a119684ed73bad3546ba3 import DcbxTlvPfcIeee
-        if self._properties.get('DcbxTlvPfcIeee', None) is not None:
-            return self._properties.get('DcbxTlvPfcIeee')
-        else:
-            return DcbxTlvPfcIeee(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('DcbxTlvPfcIeee', None) is not None:
+                return self._properties.get('DcbxTlvPfcIeee')
+        return DcbxTlvPfcIeee(self)._select()
 
     @property
     def DcbxTlvPfcIntel(self):
@@ -222,10 +224,10 @@ class TlvSettings(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.dcbxtlvpfcintel_aafbda8e30a51d7a9024ecc7f6790159 import DcbxTlvPfcIntel
-        if self._properties.get('DcbxTlvPfcIntel', None) is not None:
-            return self._properties.get('DcbxTlvPfcIntel')
-        else:
-            return DcbxTlvPfcIntel(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('DcbxTlvPfcIntel', None) is not None:
+                return self._properties.get('DcbxTlvPfcIntel')
+        return DcbxTlvPfcIntel(self)._select()
 
     @property
     def DcbxTlvPfcQaz(self):
@@ -239,10 +241,10 @@ class TlvSettings(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.dcbxtlvpfcqaz_ee356b2f3ec6d2356abbb8171f736027 import DcbxTlvPfcQaz
-        if self._properties.get('DcbxTlvPfcQaz', None) is not None:
-            return self._properties.get('DcbxTlvPfcQaz')
-        else:
-            return DcbxTlvPfcQaz(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('DcbxTlvPfcQaz', None) is not None:
+                return self._properties.get('DcbxTlvPfcQaz')
+        return DcbxTlvPfcQaz(self)._select()
 
     @property
     def DcbxTlvPgIeee(self):
@@ -256,10 +258,10 @@ class TlvSettings(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.dcbxtlvpgieee_fe6ebf156acf4a283f3e8df9f75b9783 import DcbxTlvPgIeee
-        if self._properties.get('DcbxTlvPgIeee', None) is not None:
-            return self._properties.get('DcbxTlvPgIeee')
-        else:
-            return DcbxTlvPgIeee(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('DcbxTlvPgIeee', None) is not None:
+                return self._properties.get('DcbxTlvPgIeee')
+        return DcbxTlvPgIeee(self)._select()
 
     @property
     def DcbxTlvPgIntel(self):
@@ -273,10 +275,10 @@ class TlvSettings(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.dcbxtlvpgintel_c3943ff77b2764ca73fd9869d6fcd7c8 import DcbxTlvPgIntel
-        if self._properties.get('DcbxTlvPgIntel', None) is not None:
-            return self._properties.get('DcbxTlvPgIntel')
-        else:
-            return DcbxTlvPgIntel(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('DcbxTlvPgIntel', None) is not None:
+                return self._properties.get('DcbxTlvPgIntel')
+        return DcbxTlvPgIntel(self)._select()
 
     @property
     def ObjectId(self):
@@ -288,6 +290,46 @@ class TlvSettings(Base):
         """
         return self._get_attribute(self._SDM_ATT_MAP['ObjectId'])
 
+    def find(self, ObjectId=None):
+        # type: (str) -> TlvSettings
+        """Finds and retrieves tlvSettings resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve tlvSettings resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all tlvSettings resources from the server.
+
+        Args
+        ----
+        - ObjectId (str): Unique identifier for this object
+
+        Returns
+        -------
+        - self: This instance with matching tlvSettings resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of tlvSettings data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the tlvSettings resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def CustomProtocolStack(self, *args, **kwargs):
         # type: (*Any, **Any) -> None
         """Executes the customProtocolStack operation on the server.
