@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class VsiRange(Base):
@@ -72,10 +74,10 @@ class VsiRange(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocolstack.vsifiltersinfo_aaa9868e9b18d75d2379e981b80d0b96 import VsiFiltersInfo
-        if self._properties.get('VsiFiltersInfo', None) is not None:
-            return self._properties.get('VsiFiltersInfo')
-        else:
-            return VsiFiltersInfo(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('VsiFiltersInfo', None) is not None:
+                return self._properties.get('VsiFiltersInfo')
+        return VsiFiltersInfo(self)
 
     @property
     def Count(self):
