@@ -19,13 +19,15 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class TapSettings(Base):
-    """
+    """The TAP values.
     The TapSettings class encapsulates a list of tapSettings resources that are managed by the system.
     A list of resources can be retrieved from the server using the TapSettings.find() method.
     """
@@ -52,10 +54,10 @@ class TapSettings(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.tapsettings.parameter.parameter import Parameter
-        if self._properties.get('Parameter', None) is not None:
-            return self._properties.get('Parameter')
-        else:
-            return Parameter(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Parameter', None) is not None:
+                return self._properties.get('Parameter')
+        return Parameter(self)
 
     def add(self):
         """Adds a new tapSettings resource on the json, only valid with config assistant
