@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from ixnetwork_restpy.base import Base
 from ixnetwork_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Watch(Base):
@@ -52,10 +54,10 @@ class Watch(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.watch.attributewatch.attributewatch import AttributeWatch
-        if self._properties.get('AttributeWatch', None) is not None:
-            return self._properties.get('AttributeWatch')
-        else:
-            return AttributeWatch(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('AttributeWatch', None) is not None:
+                return self._properties.get('AttributeWatch')
+        return AttributeWatch(self)
 
     @property
     def ExecWatch(self):
@@ -69,10 +71,10 @@ class Watch(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.watch.execwatch.execwatch import ExecWatch
-        if self._properties.get('ExecWatch', None) is not None:
-            return self._properties.get('ExecWatch')
-        else:
-            return ExecWatch(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('ExecWatch', None) is not None:
+                return self._properties.get('ExecWatch')
+        return ExecWatch(self)
 
     @property
     def ListWatch(self):
@@ -86,10 +88,10 @@ class Watch(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.watch.listwatch.listwatch import ListWatch
-        if self._properties.get('ListWatch', None) is not None:
-            return self._properties.get('ListWatch')
-        else:
-            return ListWatch(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('ListWatch', None) is not None:
+                return self._properties.get('ListWatch')
+        return ListWatch(self)
 
     @property
     def SelectWatch(self):
@@ -103,10 +105,10 @@ class Watch(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from ixnetwork_restpy.testplatform.sessions.ixnetwork.watch.selectwatch.selectwatch import SelectWatch
-        if self._properties.get('SelectWatch', None) is not None:
-            return self._properties.get('SelectWatch')
-        else:
-            return SelectWatch(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('SelectWatch', None) is not None:
+                return self._properties.get('SelectWatch')
+        return SelectWatch(self)
 
     @property
     def Topics(self):
@@ -118,6 +120,46 @@ class Watch(Base):
         """
         return self._get_attribute(self._SDM_ATT_MAP['Topics'])
 
+    def find(self, Topics=None):
+        # type: (List[str]) -> Watch
+        """Finds and retrieves watch resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve watch resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all watch resources from the server.
+
+        Args
+        ----
+        - Topics (list(str)): 
+
+        Returns
+        -------
+        - self: This instance with matching watch resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of watch data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the watch resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def AddAttributeWatch(self, *args, **kwargs):
         """Executes the addAttributeWatch operation on the server.
 
@@ -200,6 +242,24 @@ class Watch(Base):
         for item in kwargs.items(): payload[item[0]] = item[1]
         return self._execute('addSelectWatch', payload=payload, response_object=None)
 
+    def ClearScriptWatchMessages(self, *args, **kwargs):
+        # type: (*Any, **Any) -> None
+        """Executes the clearScriptWatchMessages operation on the server.
+
+        clearScriptWatchMessages(async_operation=bool)
+        ----------------------------------------------
+        - async_operation (bool=False): True to execute the operation asynchronously. Any subsequent rest api calls made through the Connection class will block until the operation is complete.
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        payload = { "Arg1": self.href }
+        for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
+        for item in kwargs.items(): payload[item[0]] = item[1]
+        return self._execute('clearScriptWatchMessages', payload=payload, response_object=None)
+
     def RemoveWatches(self, *args, **kwargs):
         # type: (*Any, **Any) -> None
         """Executes the removeWatches operation on the server.
