@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from uhd_restpy.base import Base
 from uhd_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class AppErrors(Base):
@@ -55,10 +57,10 @@ class AppErrors(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.globals.apperrors.error.error import Error
-        if self._properties.get('Error', None) is not None:
-            return self._properties.get('Error')
-        else:
-            return Error(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Error', None) is not None:
+                return self._properties.get('Error')
+        return Error(self)
 
     @property
     def ErrorCount(self):
