@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from uhd_restpy.base import Base
 from uhd_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Topology(Base):
@@ -61,10 +63,10 @@ class Topology(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.globals.topology.bgpipv4peer.bgpipv4peer_439a44dd340bf6fd724df996ab26569d import BgpIpv4Peer
-        if self._properties.get('BgpIpv4Peer', None) is not None:
-            return self._properties.get('BgpIpv4Peer')
-        else:
-            return BgpIpv4Peer(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('BgpIpv4Peer', None) is not None:
+                return self._properties.get('BgpIpv4Peer')
+        return BgpIpv4Peer(self)._select()
 
     @property
     def BgpIpv6Peer(self):
@@ -78,10 +80,10 @@ class Topology(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.globals.topology.bgpipv6peer.bgpipv6peer_7e5e36454dedaa483fd7dd20abef422b import BgpIpv6Peer
-        if self._properties.get('BgpIpv6Peer', None) is not None:
-            return self._properties.get('BgpIpv6Peer')
-        else:
-            return BgpIpv6Peer(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('BgpIpv6Peer', None) is not None:
+                return self._properties.get('BgpIpv6Peer')
+        return BgpIpv6Peer(self)._select()
 
     @property
     def Esmc(self):
@@ -95,10 +97,10 @@ class Topology(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.globals.topology.esmc.esmc_a6e91ae9ab0a9252a7e1dbcd069fcc86 import Esmc
-        if self._properties.get('Esmc', None) is not None:
-            return self._properties.get('Esmc')
-        else:
-            return Esmc(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Esmc', None) is not None:
+                return self._properties.get('Esmc')
+        return Esmc(self)._select()
 
     @property
     def Ethernet(self):
@@ -112,10 +114,10 @@ class Topology(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.globals.topology.ethernet.ethernet_ccd3a65106ab16a2364be51d1a412f05 import Ethernet
-        if self._properties.get('Ethernet', None) is not None:
-            return self._properties.get('Ethernet')
-        else:
-            return Ethernet(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Ethernet', None) is not None:
+                return self._properties.get('Ethernet')
+        return Ethernet(self)._select()
 
     @property
     def Ipv4(self):
@@ -129,10 +131,10 @@ class Topology(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.globals.topology.ipv4.ipv4_d3982d161b434ec799d31ef7237a4b96 import Ipv4
-        if self._properties.get('Ipv4', None) is not None:
-            return self._properties.get('Ipv4')
-        else:
-            return Ipv4(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Ipv4', None) is not None:
+                return self._properties.get('Ipv4')
+        return Ipv4(self)._select()
 
     @property
     def Ipv6(self):
@@ -146,10 +148,10 @@ class Topology(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.globals.topology.ipv6.ipv6_a9f2dfb33a5d9c10d60b9830b8455095 import Ipv6
-        if self._properties.get('Ipv6', None) is not None:
-            return self._properties.get('Ipv6')
-        else:
-            return Ipv6(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Ipv6', None) is not None:
+                return self._properties.get('Ipv6')
+        return Ipv6(self)._select()
 
     @property
     def Ipv6Autoconfiguration(self):
@@ -163,10 +165,10 @@ class Topology(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.globals.topology.ipv6autoconfiguration.ipv6autoconfiguration_186fdf3eb8d47323f28ec9e4d4c3e927 import Ipv6Autoconfiguration
-        if self._properties.get('Ipv6Autoconfiguration', None) is not None:
-            return self._properties.get('Ipv6Autoconfiguration')
-        else:
-            return Ipv6Autoconfiguration(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Ipv6Autoconfiguration', None) is not None:
+                return self._properties.get('Ipv6Autoconfiguration')
+        return Ipv6Autoconfiguration(self)._select()
 
     @property
     def IsisL3Router(self):
@@ -180,10 +182,10 @@ class Topology(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.globals.topology.isisl3router.isisl3router_b5c245f4973246022b20f2613546d45a import IsisL3Router
-        if self._properties.get('IsisL3Router', None) is not None:
-            return self._properties.get('IsisL3Router')
-        else:
-            return IsisL3Router(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('IsisL3Router', None) is not None:
+                return self._properties.get('IsisL3Router')
+        return IsisL3Router(self)
 
     @property
     def Lac(self):
@@ -197,10 +199,10 @@ class Topology(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.globals.topology.lac.lac_8a6ae7a66f1fba21c9a7af820795ad38 import Lac
-        if self._properties.get('Lac', None) is not None:
-            return self._properties.get('Lac')
-        else:
-            return Lac(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Lac', None) is not None:
+                return self._properties.get('Lac')
+        return Lac(self)._select()
 
     @property
     def Lacp(self):
@@ -214,10 +216,10 @@ class Topology(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.globals.topology.lacp.lacp_8a53bc5dca056354ad9594ab602dbf11 import Lacp
-        if self._properties.get('Lacp', None) is not None:
-            return self._properties.get('Lacp')
-        else:
-            return Lacp(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Lacp', None) is not None:
+                return self._properties.get('Lacp')
+        return Lacp(self)._select()
 
     @property
     def Lagportlacp(self):
@@ -231,10 +233,10 @@ class Topology(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.globals.topology.lagportlacp.lagportlacp_7a4a0d1aa284610bc44568a967d49355 import Lagportlacp
-        if self._properties.get('Lagportlacp', None) is not None:
-            return self._properties.get('Lagportlacp')
-        else:
-            return Lagportlacp(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Lagportlacp', None) is not None:
+                return self._properties.get('Lagportlacp')
+        return Lagportlacp(self)._select()
 
     @property
     def Lagportstaticlag(self):
@@ -248,10 +250,10 @@ class Topology(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.globals.topology.lagportstaticlag.lagportstaticlag_e722ffdff0d9b2f5175aa99e8f6c6166 import Lagportstaticlag
-        if self._properties.get('Lagportstaticlag', None) is not None:
-            return self._properties.get('Lagportstaticlag')
-        else:
-            return Lagportstaticlag(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Lagportstaticlag', None) is not None:
+                return self._properties.get('Lagportstaticlag')
+        return Lagportstaticlag(self)._select()
 
     @property
     def Macsec(self):
@@ -265,10 +267,10 @@ class Topology(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.globals.topology.macsec.macsec_8998c1b41f29384c2c688534cb45d85d import Macsec
-        if self._properties.get('Macsec', None) is not None:
-            return self._properties.get('Macsec')
-        else:
-            return Macsec(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Macsec', None) is not None:
+                return self._properties.get('Macsec')
+        return Macsec(self)._select()
 
     @property
     def Mka(self):
@@ -282,10 +284,10 @@ class Topology(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.globals.topology.mka.mka_aedde1a3ca5c00a7f6b976a4fce2c20d import Mka
-        if self._properties.get('Mka', None) is not None:
-            return self._properties.get('Mka')
-        else:
-            return Mka(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Mka', None) is not None:
+                return self._properties.get('Mka')
+        return Mka(self)._select()
 
     @property
     def Ospfv2Router(self):
@@ -299,10 +301,10 @@ class Topology(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.globals.topology.ospfv2router.ospfv2router_74c05cad626e75b691d6431d3166eb2c import Ospfv2Router
-        if self._properties.get('Ospfv2Router', None) is not None:
-            return self._properties.get('Ospfv2Router')
-        else:
-            return Ospfv2Router(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Ospfv2Router', None) is not None:
+                return self._properties.get('Ospfv2Router')
+        return Ospfv2Router(self)
 
     @property
     def Ospfv3Router(self):
@@ -316,10 +318,10 @@ class Topology(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.globals.topology.ospfv3router.ospfv3router_4c45a88f00fdf201bca989331894ee2f import Ospfv3Router
-        if self._properties.get('Ospfv3Router', None) is not None:
-            return self._properties.get('Ospfv3Router')
-        else:
-            return Ospfv3Router(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Ospfv3Router', None) is not None:
+                return self._properties.get('Ospfv3Router')
+        return Ospfv3Router(self)._select()
 
     @property
     def Pce(self):
@@ -333,10 +335,10 @@ class Topology(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.globals.topology.pce.pce_5defd13c57ea406c73fd4b2cb010a30f import Pce
-        if self._properties.get('Pce', None) is not None:
-            return self._properties.get('Pce')
-        else:
-            return Pce(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Pce', None) is not None:
+                return self._properties.get('Pce')
+        return Pce(self)._select()
 
     @property
     def StaticLag(self):
@@ -350,10 +352,10 @@ class Topology(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.globals.topology.staticlag.staticlag_bb394020ab7d7a51040dbbf42e2f75d1 import StaticLag
-        if self._properties.get('StaticLag', None) is not None:
-            return self._properties.get('StaticLag')
-        else:
-            return StaticLag(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('StaticLag', None) is not None:
+                return self._properties.get('StaticLag')
+        return StaticLag(self)._select()
 
     @property
     def StaticMacsec(self):
@@ -367,10 +369,10 @@ class Topology(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.globals.topology.staticmacsec.staticmacsec_9ab47bdf2b3b33d22965d0aa28f2bb3d import StaticMacsec
-        if self._properties.get('StaticMacsec', None) is not None:
-            return self._properties.get('StaticMacsec')
-        else:
-            return StaticMacsec(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('StaticMacsec', None) is not None:
+                return self._properties.get('StaticMacsec')
+        return StaticMacsec(self)._select()
 
     @property
     def ApplyOnTheFlyState(self):
@@ -455,6 +457,51 @@ class Topology(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, ApplyOnTheFlyState=None, NgpfProtocolRateMode=None, ProtocolActionsInProgress=None, ProtocolStackingMode=None, Status=None, Vports=None):
+        # type: (str, str, List[str], str, str, List[str]) -> Topology
+        """Finds and retrieves topology resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve topology resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all topology resources from the server.
+
+        Args
+        ----
+        - ApplyOnTheFlyState (str(allowed | notAllowed | nothingToApply)): Checks whether the apply changes operation is allowed
+        - NgpfProtocolRateMode (str(basic | smooth)): Decides whether protocol's sessions will started in normal or smooth mode
+        - ProtocolActionsInProgress (list(str)): Lists all current protocol actions in progress
+        - ProtocolStackingMode (str(parallel | sequential)): Decides whether protocol's sessions will started sequentially or parallelly across the layers
+        - Status (str(configured | error | mixed | notStarted | started | starting | stopping)): The current state of the scenario
+        - Vports (list(str[None | /api/v1/sessions/1/ixnetwork/vport])): List of virtual ports included in the port level configuration
+
+        Returns
+        -------
+        - self: This instance with matching topology resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of topology data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the topology resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def AbortApplyOnTheFly(self, *args, **kwargs):
         # type: (*Any, **Any) -> None
         """Executes the abortApplyOnTheFly operation on the server.
