@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from uhd_restpy.base import Base
 from uhd_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class FixedClassifier(Base):
@@ -53,10 +55,10 @@ class FixedClassifier(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.impairment.profile.fixedclassifier.pattern.pattern import Pattern
-        if self._properties.get('Pattern', None) is not None:
-            return self._properties.get('Pattern')
-        else:
-            return Pattern(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Pattern', None) is not None:
+                return self._properties.get('Pattern')
+        return Pattern(self)
 
     def add(self):
         """Adds a new fixedClassifier resource on the server and adds it to the container.
