@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from uhd_restpy.base import Base
 from uhd_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class QuickTest(Base):
@@ -54,10 +56,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.asymmetricframeloss_9e26b411ea07830a6774d24261df4537 import AsymmetricFrameLoss
-        if self._properties.get('AsymmetricFrameLoss', None) is not None:
-            return self._properties.get('AsymmetricFrameLoss')
-        else:
-            return AsymmetricFrameLoss(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('AsymmetricFrameLoss', None) is not None:
+                return self._properties.get('AsymmetricFrameLoss')
+        return AsymmetricFrameLoss(self)
 
     @property
     def AsymmetricThroughput(self):
@@ -71,10 +73,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.asymmetricthroughput_0177e577de3fcef100ee4736ed5038fc import AsymmetricThroughput
-        if self._properties.get('AsymmetricThroughput', None) is not None:
-            return self._properties.get('AsymmetricThroughput')
-        else:
-            return AsymmetricThroughput(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('AsymmetricThroughput', None) is not None:
+                return self._properties.get('AsymmetricThroughput')
+        return AsymmetricThroughput(self)
 
     @property
     def CloudPerf(self):
@@ -88,10 +90,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.cloudperf_fdd110ba22283c5cbf388c5117f9a96a import CloudPerf
-        if self._properties.get('CloudPerf', None) is not None:
-            return self._properties.get('CloudPerf')
-        else:
-            return CloudPerf(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('CloudPerf', None) is not None:
+                return self._properties.get('CloudPerf')
+        return CloudPerf(self)
 
     @property
     def CustomContDuration(self):
@@ -105,10 +107,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.customcontduration_589f53152bfa0216c8e0994d79e08373 import CustomContDuration
-        if self._properties.get('CustomContDuration', None) is not None:
-            return self._properties.get('CustomContDuration')
-        else:
-            return CustomContDuration(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('CustomContDuration', None) is not None:
+                return self._properties.get('CustomContDuration')
+        return CustomContDuration(self)
 
     @property
     def CustomFixedDuration(self):
@@ -122,10 +124,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.customfixedduration_61d433fa46ead4fbcc08caaf30608356 import CustomFixedDuration
-        if self._properties.get('CustomFixedDuration', None) is not None:
-            return self._properties.get('CustomFixedDuration')
-        else:
-            return CustomFixedDuration(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('CustomFixedDuration', None) is not None:
+                return self._properties.get('CustomFixedDuration')
+        return CustomFixedDuration(self)
 
     @property
     def CustomStep(self):
@@ -139,10 +141,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.customstep_98f1ecce7c2d88439541c6c12fb66c1d import CustomStep
-        if self._properties.get('CustomStep', None) is not None:
-            return self._properties.get('CustomStep')
-        else:
-            return CustomStep(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('CustomStep', None) is not None:
+                return self._properties.get('CustomStep')
+        return CustomStep(self)
 
     @property
     def CustomThroughput(self):
@@ -156,10 +158,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.customthroughput_43392709d9d2c48c1b386a084571fdf5 import CustomThroughput
-        if self._properties.get('CustomThroughput', None) is not None:
-            return self._properties.get('CustomThroughput')
-        else:
-            return CustomThroughput(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('CustomThroughput', None) is not None:
+                return self._properties.get('CustomThroughput')
+        return CustomThroughput(self)
 
     @property
     def DhcpRate(self):
@@ -173,10 +175,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.dhcprate_6f52413edee9d4b4cab233342c11f62b import DhcpRate
-        if self._properties.get('DhcpRate', None) is not None:
-            return self._properties.get('DhcpRate')
-        else:
-            return DhcpRate(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('DhcpRate', None) is not None:
+                return self._properties.get('DhcpRate')
+        return DhcpRate(self)
 
     @property
     def Dhcpv6Rate(self):
@@ -190,10 +192,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.dhcpv6rate_b7650b06ef0db627654946a311cbc9bb import Dhcpv6Rate
-        if self._properties.get('Dhcpv6Rate', None) is not None:
-            return self._properties.get('Dhcpv6Rate')
-        else:
-            return Dhcpv6Rate(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Dhcpv6Rate', None) is not None:
+                return self._properties.get('Dhcpv6Rate')
+        return Dhcpv6Rate(self)
 
     @property
     def Dot1xCapacity(self):
@@ -207,10 +209,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.dot1xcapacity_060163d41bdfaa3d63e917d0fa7e7995 import Dot1xCapacity
-        if self._properties.get('Dot1xCapacity', None) is not None:
-            return self._properties.get('Dot1xCapacity')
-        else:
-            return Dot1xCapacity(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Dot1xCapacity', None) is not None:
+                return self._properties.get('Dot1xCapacity')
+        return Dot1xCapacity(self)
 
     @property
     def Dot1xRate(self):
@@ -224,10 +226,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.dot1xrate_d841037f3c95312f5d95e0c3e8e68e72 import Dot1xRate
-        if self._properties.get('Dot1xRate', None) is not None:
-            return self._properties.get('Dot1xRate')
-        else:
-            return Dot1xRate(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Dot1xRate', None) is not None:
+                return self._properties.get('Dot1xRate')
+        return Dot1xRate(self)
 
     @property
     def EventScheduler(self):
@@ -241,10 +243,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.eventscheduler_dbcc776816146a01a3385b4bdec9a524 import EventScheduler
-        if self._properties.get('EventScheduler', None) is not None:
-            return self._properties.get('EventScheduler')
-        else:
-            return EventScheduler(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('EventScheduler', None) is not None:
+                return self._properties.get('EventScheduler')
+        return EventScheduler(self)
 
     @property
     def FcoeMaxNoDropThroughput(self):
@@ -258,10 +260,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.fcoemaxnodropthroughput_caa036e4ea16b6d8490baab54a7a3377 import FcoeMaxNoDropThroughput
-        if self._properties.get('FcoeMaxNoDropThroughput', None) is not None:
-            return self._properties.get('FcoeMaxNoDropThroughput')
-        else:
-            return FcoeMaxNoDropThroughput(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('FcoeMaxNoDropThroughput', None) is not None:
+                return self._properties.get('FcoeMaxNoDropThroughput')
+        return FcoeMaxNoDropThroughput(self)
 
     @property
     def FcoeMaxNoPauseThroughput(self):
@@ -275,10 +277,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.fcoemaxnopausethroughput_5ad968ab4d3c9fe2bdf36264fc9140ae import FcoeMaxNoPauseThroughput
-        if self._properties.get('FcoeMaxNoPauseThroughput', None) is not None:
-            return self._properties.get('FcoeMaxNoPauseThroughput')
-        else:
-            return FcoeMaxNoPauseThroughput(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('FcoeMaxNoPauseThroughput', None) is not None:
+                return self._properties.get('FcoeMaxNoPauseThroughput')
+        return FcoeMaxNoPauseThroughput(self)
 
     @property
     def Globals(self):
@@ -292,10 +294,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.globals_605c8d39970b93a1aba6b6a97467871c import Globals
-        if self._properties.get('Globals', None) is not None:
-            return self._properties.get('Globals')
-        else:
-            return Globals(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Globals', None) is not None:
+                return self._properties.get('Globals')
+        return Globals(self)._select()
 
     @property
     def IptvChannelZapping(self):
@@ -309,10 +311,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.iptvchannelzapping_31de08f962d6589ac7f01ee268afa1f8 import IptvChannelZapping
-        if self._properties.get('IptvChannelZapping', None) is not None:
-            return self._properties.get('IptvChannelZapping')
-        else:
-            return IptvChannelZapping(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('IptvChannelZapping', None) is not None:
+                return self._properties.get('IptvChannelZapping')
+        return IptvChannelZapping(self)
 
     @property
     def L2tpRate(self):
@@ -326,10 +328,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.l2tprate_70b6ec9c1ab739f3e122bb9aa824287b import L2tpRate
-        if self._properties.get('L2tpRate', None) is not None:
-            return self._properties.get('L2tpRate')
-        else:
-            return L2tpRate(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('L2tpRate', None) is not None:
+                return self._properties.get('L2tpRate')
+        return L2tpRate(self)
 
     @property
     def OpenFlowFailoverPerformance(self):
@@ -343,10 +345,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.openflowfailoverperformance_50924ff459aa0f2719393c238b1c71a9 import OpenFlowFailoverPerformance
-        if self._properties.get('OpenFlowFailoverPerformance', None) is not None:
-            return self._properties.get('OpenFlowFailoverPerformance')
-        else:
-            return OpenFlowFailoverPerformance(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('OpenFlowFailoverPerformance', None) is not None:
+                return self._properties.get('OpenFlowFailoverPerformance')
+        return OpenFlowFailoverPerformance(self)
 
     @property
     def OpenFlowLayer2LearningRate(self):
@@ -360,10 +362,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.openflowlayer2learningrate_e5da985364765a56bf90bf997dc09d88 import OpenFlowLayer2LearningRate
-        if self._properties.get('OpenFlowLayer2LearningRate', None) is not None:
-            return self._properties.get('OpenFlowLayer2LearningRate')
-        else:
-            return OpenFlowLayer2LearningRate(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('OpenFlowLayer2LearningRate', None) is not None:
+                return self._properties.get('OpenFlowLayer2LearningRate')
+        return OpenFlowLayer2LearningRate(self)
 
     @property
     def OpenFlowLayer3LearningRate(self):
@@ -377,10 +379,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.openflowlayer3learningrate_24a64d34da695088e642bf2d3643974d import OpenFlowLayer3LearningRate
-        if self._properties.get('OpenFlowLayer3LearningRate', None) is not None:
-            return self._properties.get('OpenFlowLayer3LearningRate')
-        else:
-            return OpenFlowLayer3LearningRate(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('OpenFlowLayer3LearningRate', None) is not None:
+                return self._properties.get('OpenFlowLayer3LearningRate')
+        return OpenFlowLayer3LearningRate(self)
 
     @property
     def OpenFlowTableCapacity(self):
@@ -394,10 +396,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.openflowtablecapacity_9d1b2428e9419c5f88c445937490500d import OpenFlowTableCapacity
-        if self._properties.get('OpenFlowTableCapacity', None) is not None:
-            return self._properties.get('OpenFlowTableCapacity')
-        else:
-            return OpenFlowTableCapacity(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('OpenFlowTableCapacity', None) is not None:
+                return self._properties.get('OpenFlowTableCapacity')
+        return OpenFlowTableCapacity(self)
 
     @property
     def PppServerCapacity(self):
@@ -411,10 +413,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.pppservercapacity_979eb526d86ff91bb93b7632215d608e import PppServerCapacity
-        if self._properties.get('PppServerCapacity', None) is not None:
-            return self._properties.get('PppServerCapacity')
-        else:
-            return PppServerCapacity(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('PppServerCapacity', None) is not None:
+                return self._properties.get('PppServerCapacity')
+        return PppServerCapacity(self)
 
     @property
     def PppSessionRate(self):
@@ -428,10 +430,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.pppsessionrate_7133d4b47f948b84b4bce0cc33228436 import PppSessionRate
-        if self._properties.get('PppSessionRate', None) is not None:
-            return self._properties.get('PppSessionRate')
-        else:
-            return PppSessionRate(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('PppSessionRate', None) is not None:
+                return self._properties.get('PppSessionRate')
+        return PppSessionRate(self)
 
     @property
     def PtpBestMasterSelection(self):
@@ -445,10 +447,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.ptpbestmasterselection_6f10a38d2f306fac193108a7cedda79c import PtpBestMasterSelection
-        if self._properties.get('PtpBestMasterSelection', None) is not None:
-            return self._properties.get('PtpBestMasterSelection')
-        else:
-            return PtpBestMasterSelection(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('PtpBestMasterSelection', None) is not None:
+                return self._properties.get('PtpBestMasterSelection')
+        return PtpBestMasterSelection(self)
 
     @property
     def PtpCorrectionFactorError(self):
@@ -462,10 +464,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.ptpcorrectionfactorerror_a796fd71e51214e85d4e3efc9d23ff7c import PtpCorrectionFactorError
-        if self._properties.get('PtpCorrectionFactorError', None) is not None:
-            return self._properties.get('PtpCorrectionFactorError')
-        else:
-            return PtpCorrectionFactorError(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('PtpCorrectionFactorError', None) is not None:
+                return self._properties.get('PtpCorrectionFactorError')
+        return PtpCorrectionFactorError(self)
 
     @property
     def PtpSlaveScalability(self):
@@ -479,10 +481,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.ptpslavescalability_46be9cd153cad47ed0d8acb04a35bd60 import PtpSlaveScalability
-        if self._properties.get('PtpSlaveScalability', None) is not None:
-            return self._properties.get('PtpSlaveScalability')
-        else:
-            return PtpSlaveScalability(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('PtpSlaveScalability', None) is not None:
+                return self._properties.get('PtpSlaveScalability')
+        return PtpSlaveScalability(self)
 
     @property
     def Rfc2544back2back(self):
@@ -496,10 +498,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.rfc2544back2back_cfd3f40fbe677cc70482381fc445e21e import Rfc2544back2back
-        if self._properties.get('Rfc2544back2back', None) is not None:
-            return self._properties.get('Rfc2544back2back')
-        else:
-            return Rfc2544back2back(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Rfc2544back2back', None) is not None:
+                return self._properties.get('Rfc2544back2back')
+        return Rfc2544back2back(self)
 
     @property
     def Rfc2544frameLoss(self):
@@ -513,10 +515,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.rfc2544frameloss_868b9746dda2d0cfeed81516cf37d39d import Rfc2544frameLoss
-        if self._properties.get('Rfc2544frameLoss', None) is not None:
-            return self._properties.get('Rfc2544frameLoss')
-        else:
-            return Rfc2544frameLoss(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Rfc2544frameLoss', None) is not None:
+                return self._properties.get('Rfc2544frameLoss')
+        return Rfc2544frameLoss(self)
 
     @property
     def Rfc2544throughput(self):
@@ -530,10 +532,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.rfc2544throughput_86fc74b3228f97518d2513e6b33a3960 import Rfc2544throughput
-        if self._properties.get('Rfc2544throughput', None) is not None:
-            return self._properties.get('Rfc2544throughput')
-        else:
-            return Rfc2544throughput(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Rfc2544throughput', None) is not None:
+                return self._properties.get('Rfc2544throughput')
+        return Rfc2544throughput(self)
 
     @property
     def Rfc2889broadcastRate(self):
@@ -547,10 +549,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.rfc2889broadcastrate_1f8e1c7f7f9e4d711149db4a572058fb import Rfc2889broadcastRate
-        if self._properties.get('Rfc2889broadcastRate', None) is not None:
-            return self._properties.get('Rfc2889broadcastRate')
-        else:
-            return Rfc2889broadcastRate(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Rfc2889broadcastRate', None) is not None:
+                return self._properties.get('Rfc2889broadcastRate')
+        return Rfc2889broadcastRate(self)
 
     @property
     def Rfc2889congestionControl(self):
@@ -564,10 +566,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.rfc2889congestioncontrol_efe62c029fd5ff197d5d57687ac167a6 import Rfc2889congestionControl
-        if self._properties.get('Rfc2889congestionControl', None) is not None:
-            return self._properties.get('Rfc2889congestionControl')
-        else:
-            return Rfc2889congestionControl(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Rfc2889congestionControl', None) is not None:
+                return self._properties.get('Rfc2889congestionControl')
+        return Rfc2889congestionControl(self)
 
     @property
     def Rfc2889frameErrorFiltering(self):
@@ -581,10 +583,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.rfc2889frameerrorfiltering_56eb932020f20bf8144b92be8a4285f9 import Rfc2889frameErrorFiltering
-        if self._properties.get('Rfc2889frameErrorFiltering', None) is not None:
-            return self._properties.get('Rfc2889frameErrorFiltering')
-        else:
-            return Rfc2889frameErrorFiltering(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Rfc2889frameErrorFiltering', None) is not None:
+                return self._properties.get('Rfc2889frameErrorFiltering')
+        return Rfc2889frameErrorFiltering(self)
 
     @property
     def TrafficTest(self):
@@ -598,10 +600,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.traffictest_f399e685b29fd795590f27fffbfa469c import TrafficTest
-        if self._properties.get('TrafficTest', None) is not None:
-            return self._properties.get('TrafficTest')
-        else:
-            return TrafficTest(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('TrafficTest', None) is not None:
+                return self._properties.get('TrafficTest')
+        return TrafficTest(self)
 
     @property
     def Y1564(self):
@@ -615,10 +617,10 @@ class QuickTest(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.quicktest.y1564_9b70a4fc765ea18ca465ea775da0fa0b import Y1564
-        if self._properties.get('Y1564', None) is not None:
-            return self._properties.get('Y1564')
-        else:
-            return Y1564(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Y1564', None) is not None:
+                return self._properties.get('Y1564')
+        return Y1564(self)
 
     @property
     def RunningTest(self):
@@ -650,6 +652,48 @@ class QuickTest(Base):
         """
         return self._get_attribute(self._SDM_ATT_MAP['TestIds'])
 
+    def find(self, RunningTest=None, RunningTestObj=None, TestIds=None):
+        # type: (List[str], List[str], List[str]) -> QuickTest
+        """Finds and retrieves quickTest resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve quickTest resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all quickTest resources from the server.
+
+        Args
+        ----
+        - RunningTest (list(str[None | /api/v1/sessions/1/ixnetwork/quickTest/.../*])): Returns list containing the currently running QuickTest
+        - RunningTestObj (list(str[None | /api/v1/sessions/1/ixnetwork/quickTest/.../*])): Returns list containing the currently running QuickTest
+        - TestIds (list(str[None | /api/v1/sessions/1/ixnetwork/quickTest/.../*])): Returns list containing the QuickTest test in the configuration
+
+        Returns
+        -------
+        - self: This instance with matching quickTest resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of quickTest data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the quickTest resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def Apply(self, *args, **kwargs):
         # type: (*Any, **Any) -> None
         """Executes the apply operation on the server.
