@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from uhd_restpy.base import Base
 from uhd_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Actions(Base):
@@ -60,10 +62,10 @@ class Actions(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.topology.action_910bcbfd3b7898385321127395ab1bd5 import Action
-        if self._properties.get('Action', None) is not None:
-            return self._properties.get('Action')
-        else:
-            return Action(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Action', None) is not None:
+                return self._properties.get('Action')
+        return Action(self)
 
     @property
     def Count(self):
