@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from uhd_restpy.base import Base
 from uhd_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class IsisSpbSimRouter(Base):
@@ -69,10 +71,10 @@ class IsisSpbSimRouter(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.topology.connector_d0d942810e4010add7642d3914a1f29b import Connector
-        if self._properties.get('Connector', None) is not None:
-            return self._properties.get('Connector')
-        else:
-            return Connector(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Connector', None) is not None:
+                return self._properties.get('Connector')
+        return Connector(self)
 
     @property
     def SpbSimEdgeTopologyList(self):
@@ -86,10 +88,10 @@ class IsisSpbSimRouter(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.topology.spbsimedgetopologylist_5e9b551439bb252c1fa3e2c6948a1432 import SpbSimEdgeTopologyList
-        if self._properties.get('SpbSimEdgeTopologyList', None) is not None:
-            return self._properties.get('SpbSimEdgeTopologyList')
-        else:
-            return SpbSimEdgeTopologyList(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('SpbSimEdgeTopologyList', None) is not None:
+                return self._properties.get('SpbSimEdgeTopologyList')
+        return SpbSimEdgeTopologyList(self)._select()
 
     @property
     def Active(self):
