@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from uhd_restpy.base import Base
 from uhd_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class IsisSpbSimulatedTopologyConfig(Base):
@@ -60,10 +62,10 @@ class IsisSpbSimulatedTopologyConfig(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.topology.spbnodetopologylist_97764ea2c3708885007bc4d842895ee4 import SpbNodeTopologyList
-        if self._properties.get('SpbNodeTopologyList', None) is not None:
-            return self._properties.get('SpbNodeTopologyList')
-        else:
-            return SpbNodeTopologyList(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('SpbNodeTopologyList', None) is not None:
+                return self._properties.get('SpbNodeTopologyList')
+        return SpbNodeTopologyList(self)._select()
 
     @property
     def Active(self):
