@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from uhd_restpy.base import Base
 from uhd_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class IsisTrillSimulatedTopologyConfig(Base):
@@ -59,10 +61,10 @@ class IsisTrillSimulatedTopologyConfig(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.topology.trillnodetopologylist_4077d4c2167806db82745c07dd5d7357 import TrillNodeTopologyList
-        if self._properties.get('TrillNodeTopologyList', None) is not None:
-            return self._properties.get('TrillNodeTopologyList')
-        else:
-            return TrillNodeTopologyList(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('TrillNodeTopologyList', None) is not None:
+                return self._properties.get('TrillNodeTopologyList')
+        return TrillNodeTopologyList(self)._select()
 
     @property
     def Active(self):
