@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from uhd_restpy.base import Base
 from uhd_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class OspfPseudoInterface(Base):
@@ -88,10 +90,10 @@ class OspfPseudoInterface(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.topology.srlgvaluelist_355b617a5f46ce90d800290d21158418 import SrlgValueList
-        if self._properties.get('SrlgValueList', None) is not None:
-            return self._properties.get('SrlgValueList')
-        else:
-            return SrlgValueList(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('SrlgValueList', None) is not None:
+                return self._properties.get('SrlgValueList')
+        return SrlgValueList(self)
 
     @property
     def AdjSID(self):
