@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from uhd_restpy.base import Base
 from uhd_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Ospfv3PseudoRouter(Base):
@@ -68,10 +70,10 @@ class Ospfv3PseudoRouter(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.topology.externalroutes_1ced449f46e284c113ae2194af2ffb97 import ExternalRoutes
-        if self._properties.get('ExternalRoutes', None) is not None:
-            return self._properties.get('ExternalRoutes')
-        else:
-            return ExternalRoutes(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('ExternalRoutes', None) is not None:
+                return self._properties.get('ExternalRoutes')
+        return ExternalRoutes(self)
 
     @property
     def InterAreaPrefix(self):
@@ -85,10 +87,10 @@ class Ospfv3PseudoRouter(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.topology.interareaprefix_d5c1af5dfb80980a591c026bbf1a1217 import InterAreaPrefix
-        if self._properties.get('InterAreaPrefix', None) is not None:
-            return self._properties.get('InterAreaPrefix')
-        else:
-            return InterAreaPrefix(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('InterAreaPrefix', None) is not None:
+                return self._properties.get('InterAreaPrefix')
+        return InterAreaPrefix(self)
 
     @property
     def InterAreaRouter(self):
@@ -102,10 +104,10 @@ class Ospfv3PseudoRouter(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.topology.interarearouter_e3708b9636f21a071f8de5213e1653fb import InterAreaRouter
-        if self._properties.get('InterAreaRouter', None) is not None:
-            return self._properties.get('InterAreaRouter')
-        else:
-            return InterAreaRouter(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('InterAreaRouter', None) is not None:
+                return self._properties.get('InterAreaRouter')
+        return InterAreaRouter(self)
 
     @property
     def IntraAreaPrefix(self):
@@ -119,10 +121,10 @@ class Ospfv3PseudoRouter(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.topology.intraareaprefix_948ccdbed233cc17b5c5cd2caa82b61f import IntraAreaPrefix
-        if self._properties.get('IntraAreaPrefix', None) is not None:
-            return self._properties.get('IntraAreaPrefix')
-        else:
-            return IntraAreaPrefix(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('IntraAreaPrefix', None) is not None:
+                return self._properties.get('IntraAreaPrefix')
+        return IntraAreaPrefix(self)
 
     @property
     def LinkLsaRoutes(self):
@@ -136,10 +138,10 @@ class Ospfv3PseudoRouter(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.topology.linklsaroutes_a80c9071154775869e327a02125984ee import LinkLsaRoutes
-        if self._properties.get('LinkLsaRoutes', None) is not None:
-            return self._properties.get('LinkLsaRoutes')
-        else:
-            return LinkLsaRoutes(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('LinkLsaRoutes', None) is not None:
+                return self._properties.get('LinkLsaRoutes')
+        return LinkLsaRoutes(self)
 
     @property
     def NssaRoutes(self):
@@ -153,10 +155,10 @@ class Ospfv3PseudoRouter(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.topology.nssaroutes_ff8ecb21072a534ab3d887c03c4e1cc2 import NssaRoutes
-        if self._properties.get('NssaRoutes', None) is not None:
-            return self._properties.get('NssaRoutes')
-        else:
-            return NssaRoutes(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('NssaRoutes', None) is not None:
+                return self._properties.get('NssaRoutes')
+        return NssaRoutes(self)
 
     @property
     def Ospfv3SRGBRangeSubObjectsList(self):
@@ -170,10 +172,10 @@ class Ospfv3PseudoRouter(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.topology.ospfv3srgbrangesubobjectslist_be527e153c8e6d4e5c3f4321aa8409c4 import Ospfv3SRGBRangeSubObjectsList
-        if self._properties.get('Ospfv3SRGBRangeSubObjectsList', None) is not None:
-            return self._properties.get('Ospfv3SRGBRangeSubObjectsList')
-        else:
-            return Ospfv3SRGBRangeSubObjectsList(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Ospfv3SRGBRangeSubObjectsList', None) is not None:
+                return self._properties.get('Ospfv3SRGBRangeSubObjectsList')
+        return Ospfv3SRGBRangeSubObjectsList(self)
 
     @property
     def Active(self):
