@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from uhd_restpy.base import Base
 from uhd_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class SimInterface(Base):
@@ -58,10 +60,10 @@ class SimInterface(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.topology.isisl3pseudointerface_89754a450e3c5a1e7f9a873f3cd3b99a import IsisL3PseudoInterface
-        if self._properties.get('IsisL3PseudoInterface', None) is not None:
-            return self._properties.get('IsisL3PseudoInterface')
-        else:
-            return IsisL3PseudoInterface(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('IsisL3PseudoInterface', None) is not None:
+                return self._properties.get('IsisL3PseudoInterface')
+        return IsisL3PseudoInterface(self)
 
     @property
     def IsisPseudoInterface(self):
@@ -75,10 +77,10 @@ class SimInterface(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.topology.isispseudointerface_c1f1f37e55c1225f223c72b348d63875 import IsisPseudoInterface
-        if self._properties.get('IsisPseudoInterface', None) is not None:
-            return self._properties.get('IsisPseudoInterface')
-        else:
-            return IsisPseudoInterface(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('IsisPseudoInterface', None) is not None:
+                return self._properties.get('IsisPseudoInterface')
+        return IsisPseudoInterface(self)
 
     @property
     def SimInterfaceEthernetConfig(self):
@@ -92,10 +94,10 @@ class SimInterface(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.topology.siminterfaceethernetconfig_1d251364611e333123819f3a7098b591 import SimInterfaceEthernetConfig
-        if self._properties.get('SimInterfaceEthernetConfig', None) is not None:
-            return self._properties.get('SimInterfaceEthernetConfig')
-        else:
-            return SimInterfaceEthernetConfig(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('SimInterfaceEthernetConfig', None) is not None:
+                return self._properties.get('SimInterfaceEthernetConfig')
+        return SimInterfaceEthernetConfig(self)
 
     @property
     def SimInterfaceIPv4Config(self):
@@ -109,10 +111,10 @@ class SimInterface(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.topology.siminterfaceipv4config_e6c1aa40e073d14efc69d40d8efd0f6b import SimInterfaceIPv4Config
-        if self._properties.get('SimInterfaceIPv4Config', None) is not None:
-            return self._properties.get('SimInterfaceIPv4Config')
-        else:
-            return SimInterfaceIPv4Config(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('SimInterfaceIPv4Config', None) is not None:
+                return self._properties.get('SimInterfaceIPv4Config')
+        return SimInterfaceIPv4Config(self)
 
     @property
     def SimInterfaceIPv6Config(self):
@@ -126,10 +128,10 @@ class SimInterface(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.topology.siminterfaceipv6config_189f3bfbc365f2b105e35cd8b9d542d6 import SimInterfaceIPv6Config
-        if self._properties.get('SimInterfaceIPv6Config', None) is not None:
-            return self._properties.get('SimInterfaceIPv6Config')
-        else:
-            return SimInterfaceIPv6Config(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('SimInterfaceIPv6Config', None) is not None:
+                return self._properties.get('SimInterfaceIPv6Config')
+        return SimInterfaceIPv6Config(self)
 
     @property
     def Count(self):
