@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from uhd_restpy.base import Base
 from uhd_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class SimRouter(Base):
@@ -58,10 +60,10 @@ class SimRouter(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.topology.connector_d0d942810e4010add7642d3914a1f29b import Connector
-        if self._properties.get('Connector', None) is not None:
-            return self._properties.get('Connector')
-        else:
-            return Connector(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Connector', None) is not None:
+                return self._properties.get('Connector')
+        return Connector(self)
 
     @property
     def IsisL3PseudoRouter(self):
@@ -75,10 +77,10 @@ class SimRouter(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.topology.isisl3pseudorouter_eb611bec8e6885a729e2fa754f47907e import IsisL3PseudoRouter
-        if self._properties.get('IsisL3PseudoRouter', None) is not None:
-            return self._properties.get('IsisL3PseudoRouter')
-        else:
-            return IsisL3PseudoRouter(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('IsisL3PseudoRouter', None) is not None:
+                return self._properties.get('IsisL3PseudoRouter')
+        return IsisL3PseudoRouter(self)
 
     @property
     def LdpPseudoRouter(self):
@@ -92,10 +94,10 @@ class SimRouter(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.topology.ldppseudorouter_5f6f01cad846224121837f6b8e6bf015 import LdpPseudoRouter
-        if self._properties.get('LdpPseudoRouter', None) is not None:
-            return self._properties.get('LdpPseudoRouter')
-        else:
-            return LdpPseudoRouter(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('LdpPseudoRouter', None) is not None:
+                return self._properties.get('LdpPseudoRouter')
+        return LdpPseudoRouter(self)
 
     @property
     def OspfPseudoRouter(self):
@@ -109,10 +111,10 @@ class SimRouter(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.topology.ospfpseudorouter_12b3393450e65ec5e296c3ab57a0b3a5 import OspfPseudoRouter
-        if self._properties.get('OspfPseudoRouter', None) is not None:
-            return self._properties.get('OspfPseudoRouter')
-        else:
-            return OspfPseudoRouter(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('OspfPseudoRouter', None) is not None:
+                return self._properties.get('OspfPseudoRouter')
+        return OspfPseudoRouter(self)
 
     @property
     def Ospfv3PseudoRouter(self):
@@ -126,10 +128,10 @@ class SimRouter(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.topology.ospfv3pseudorouter_2655f161657257079fe67161054bb73b import Ospfv3PseudoRouter
-        if self._properties.get('Ospfv3PseudoRouter', None) is not None:
-            return self._properties.get('Ospfv3PseudoRouter')
-        else:
-            return Ospfv3PseudoRouter(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Ospfv3PseudoRouter', None) is not None:
+                return self._properties.get('Ospfv3PseudoRouter')
+        return Ospfv3PseudoRouter(self)
 
     @property
     def Tag(self):
@@ -143,10 +145,10 @@ class SimRouter(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.topology.tag_e30f24de79247381d4dfd423b2f6986d import Tag
-        if self._properties.get('Tag', None) is not None:
-            return self._properties.get('Tag')
-        else:
-            return Tag(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Tag', None) is not None:
+                return self._properties.get('Tag')
+        return Tag(self)
 
     @property
     def Count(self):
