@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from uhd_restpy.base import Base
 from uhd_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class RepeatableContainer(Base):
@@ -54,10 +56,10 @@ class RepeatableContainer(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.topology.tlvprofile.object_1ba6063c8cfb61359d0cafa499ed49e4 import Object
-        if self._properties.get('Object', None) is not None:
-            return self._properties.get('Object')
-        else:
-            return Object(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Object', None) is not None:
+                return self._properties.get('Object')
+        return Object(self)
 
     @property
     def IsEnabled(self):
