@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from uhd_restpy.base import Base
 from uhd_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Type(Base):
@@ -54,10 +56,10 @@ class Type(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.topology.tlvprofile.object_1ba6063c8cfb61359d0cafa499ed49e4 import Object
-        if self._properties.get('Object', None) is not None:
-            return self._properties.get('Object')
-        else:
-            return Object(self)
+        if len(self._object_properties) > 0:
+            if self._properties.get('Object', None) is not None:
+                return self._properties.get('Object')
+        return Object(self)
 
     @property
     def IsEditable(self):
@@ -116,3 +118,45 @@ class Type(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def find(self, IsEditable=None, IsRequired=None, Name=None):
+        # type: (bool, bool, str) -> Type
+        """Finds and retrieves type resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve type resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all type resources from the server.
+
+        Args
+        ----
+        - IsEditable (bool): Indicates whether this is editable or not
+        - IsRequired (bool): Indicates whether this is required or not
+        - Name (str): Name of the node
+
+        Returns
+        -------
+        - self: This instance with matching type resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of type data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the type resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
