@@ -19,9 +19,11 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE. 
+import sys
 from uhd_restpy.base import Base
 from uhd_restpy.files import Files
-from typing import List, Any, Union
+if sys.version_info >= (3, 5):
+    from typing import List, Any, Union
 
 
 class Capture(Base):
@@ -84,10 +86,10 @@ class Capture(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.vport.capture.currentpacket.currentpacket import CurrentPacket
-        if self._properties.get('CurrentPacket', None) is not None:
-            return self._properties.get('CurrentPacket')
-        else:
-            return CurrentPacket(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('CurrentPacket', None) is not None:
+                return self._properties.get('CurrentPacket')
+        return CurrentPacket(self)._select()
 
     @property
     def Filter(self):
@@ -101,10 +103,10 @@ class Capture(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.vport.capture.filter.filter import Filter
-        if self._properties.get('Filter', None) is not None:
-            return self._properties.get('Filter')
-        else:
-            return Filter(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Filter', None) is not None:
+                return self._properties.get('Filter')
+        return Filter(self)._select()
 
     @property
     def FilterPallette(self):
@@ -118,10 +120,10 @@ class Capture(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.vport.capture.filterpallette.filterpallette import FilterPallette
-        if self._properties.get('FilterPallette', None) is not None:
-            return self._properties.get('FilterPallette')
-        else:
-            return FilterPallette(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('FilterPallette', None) is not None:
+                return self._properties.get('FilterPallette')
+        return FilterPallette(self)._select()
 
     @property
     def Trigger(self):
@@ -135,10 +137,10 @@ class Capture(Base):
         - ServerError: The server has encountered an uncategorized error condition
         """
         from uhd_restpy.testplatform.sessions.ixnetwork.vport.capture.trigger.trigger import Trigger
-        if self._properties.get('Trigger', None) is not None:
-            return self._properties.get('Trigger')
-        else:
-            return Trigger(self)._select()
+        if len(self._object_properties) > 0:
+            if self._properties.get('Trigger', None) is not None:
+                return self._properties.get('Trigger')
+        return Trigger(self)._select()
 
     @property
     def AfterTriggerFilter(self):
@@ -493,6 +495,71 @@ class Capture(Base):
         """
         return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
 
+    def find(self, AfterTriggerFilter=None, BeforeTriggerFilter=None, CaptureMode=None, ContinuousFilters=None, ControlActiveCapture=None, ControlBufferBehaviour=None, ControlBufferSize=None, ControlCaptureFilter=None, ControlCaptureState=None, ControlCaptureTrigger=None, ControlCapturedPacketCounter=None, ControlCaptures=None, ControlDecodeAsCurrentFilter=None, ControlInterfaceType=None, ControlPacketCounter=None, ControlSliceSize=None, DecodeAsLinkProtocols=None, DecodeAsNetworkProtocols=None, DecodeAsTransportProtocols=None, DisplayFiltersControlCapture=None, HardwareEnabled=None, IsCaptureRunning=None, IsControlCaptureRunning=None, SliceSize=None, SoftwareEnabled=None, TriggerPosition=None):
+        # type: (str, str, str, str, str, str, int, str, str, str, int, str, str, str, int, int, List[str], List[str], List[str], str, bool, bool, bool, int, bool, int) -> Capture
+        """Finds and retrieves capture resources from the server.
+
+        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve capture resources from the server.
+        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
+        By default the find method takes no parameters and will retrieve all capture resources from the server.
+
+        Args
+        ----
+        - AfterTriggerFilter (str(captureAfterTriggerAll | captureAfterTriggerConditionFilter | captureAfterTriggerFilter)): Controls the capture of data after triggering when operating in triggered mode.
+        - BeforeTriggerFilter (str(captureBeforeTriggerAll | captureBeforeTriggerFilter | captureBeforeTriggerNone)): Controls the capture of data prior to triggering when operating in triggered mode
+        - CaptureMode (str(captureContinuousMode | captureTriggerMode)): Controls whether data capture is performed in a continuous or triggered mode.
+        - ContinuousFilters (str(captureContinuousAll | captureContinuousFilter)): Controls the circular buffer behaviour: continuous capture of all received packets or continuous capture of received packets which match the filter conditions applied.
+        - ControlActiveCapture (str): The name of the active control capture (if any).The active control capture is the last one made on the port by default; but the user can change it using this attribute.
+        - ControlBufferBehaviour (str(bufferAfterStopCircular | bufferAfterStopNonCircular | bufferLiveCircular | bufferLiveNonCircular)): Sets the control capture buffer behavior.
+        - ControlBufferSize (number): Sets the size(%) of the ports memory used by the control capture.
+        - ControlCaptureFilter (str): Controls the dividing line within the capture buffer between before trigger dataand post trigger data. This control is only useful in triggered mode.
+        - ControlCaptureState (str(notReady | ready)): Current state of the control capture (if there are packets uploading in GUI or not).
+        - ControlCaptureTrigger (str): This is the control Trigger string.
+        - ControlCapturedPacketCounter (number): 
+        - ControlCaptures (str): The list of control captures which are available for the port.
+        - ControlDecodeAsCurrentFilter (str): The control capture decode as filter used by last decode as operation (if any).
+        - ControlInterfaceType (str(anyInterface | specificInterface)): Enables control capture on the desired interfaces.
+        - ControlPacketCounter (number): Shows the number of control capture packets.
+        - ControlSliceSize (number): Sets the size of the control capture slices.
+        - DecodeAsLinkProtocols (list(str)): List with link protocols available for capture decode as operation. Need to have an active capture to retrieve the property.
+        - DecodeAsNetworkProtocols (list(str)): List with network protocols available for capture decode as operation. Need to have an active capture to retrieve the property.
+        - DecodeAsTransportProtocols (list(str)): List with transport protocols available for capture decode as operation. Need to have an active capture to retrieve the property.
+        - DisplayFiltersControlCapture (str): Displays the packet filter set inside the control capture that is used to filter the already captured packets
+        - HardwareEnabled (bool): If true, enables the capture of data plane traffic. Note that in order for data traffic to be captured, the vport attritbute -rxMode must be set to capture.
+        - IsCaptureRunning (bool): Indicates if the capture is running.
+        - IsControlCaptureRunning (bool): Indicates if the control capture is running.
+        - SliceSize (number): The size of the capture slice.
+        - SoftwareEnabled (bool): If true, enables the capture of control plane traffic. Note that in order for data traffic to be captured, the vport attritbute -rxMode must be set to capture.
+        - TriggerPosition (number): Controls the dividing line within the capture buffer between before trigger data and post trigger data. This control is only useful in triggered mode.
+
+        Returns
+        -------
+        - self: This instance with matching capture resources retrieved from the server available through an iterator or index
+
+        Raises
+        ------
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))
+
+    def read(self, href):
+        """Retrieves a single instance of capture data from the server.
+
+        Args
+        ----
+        - href (str): An href to the instance to be retrieved
+
+        Returns
+        -------
+        - self: This instance with the capture resources from the server available through an iterator or index
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        return self._read(href)
+
     def DecodeAsApply(self, *args, **kwargs):
         # type: (*Any, **Any) -> None
         """Executes the decodeAsApply operation on the server.
